@@ -20,21 +20,24 @@ AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 #ifndef DCOPSERVER_H
-#define DCOPSERVER_H "$Id: dcopserver.h,v 1.28 2001/06/22 18:19:37 waba Exp $"
+#define DCOPSERVER_H "$Id: dcopserver.h,v 1.33 2002/01/04 11:03:18 lunakl Exp $"
 
 #include <qobject.h>
 #include <qstring.h>
 #include <qsocketnotifier.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qvaluelist.h>
 #include <qcstring.h>
 #include <qdict.h>
 #include <qptrdict.h>
+#include <qintdict.h>
 #include <qapplication.h>
 
 #define INT32 QINT32
+#ifdef Q_WS_X11
 #include <X11/Xlib.h>
 #include <X11/Xmd.h>
+#endif
 #include <KDE-ICE/ICElib.h>
 extern "C" {
 #include <KDE-ICE/ICEutil.h>
@@ -84,9 +87,9 @@ public:
      * This allows us to do proper bookkeeping in case client A, client B 
      * or both unregister during the call.
      */
-    QList <_IceConn> waitingOnReply;
-    QList <_IceConn> waitingForReply;
-    QList <_IceConn> waitingForDelayedReply;
+    QPtrList <_IceConn> waitingOnReply;
+    QPtrList <_IceConn> waitingForReply;
+    QPtrList <_IceConn> waitingForDelayedReply;
     DCOPSignalConnectionList *_signalConnectionList;
     bool daemon;
     bool outputBlocked;
@@ -132,6 +135,8 @@ private slots:
     void slotOutputReady(int socket );
 
 private:
+    void broadcastApplicationRegistration( DCOPConnection* conn, const QCString type,
+        const QString& data );
     bool suicide;
     int majorOpcode;
     int currentClientNumber;
@@ -139,11 +144,11 @@ private:
     DCOPSignals *dcopSignals;
     QTimer *m_timer;
     QTimer *m_deadConnectionTimer;
-    QList<DCOPListener> listener;
+    QPtrList<DCOPListener> listener;
     QAsciiDict<DCOPConnection> appIds; // index on app id
     QPtrDict<DCOPConnection> clients; // index on iceConn
     QIntDict<DCOPConnection> fd_clients; // index on fd
-    QList<_IceConn> deadConnections;
+    QPtrList<_IceConn> deadConnections;
 };
 
 extern DCOPServer* the_server;
