@@ -18,16 +18,18 @@
     Boston, MA 02111-1307, USA.
 */
 
-#include <qtimer.h>
 #include <qfile.h>
 #include <qregexp.h>
+#include <qtimer.h>
 
 #include <kapplication.h>
-#include <kstandarddirs.h>
 #include <kdebug.h>
+#include <kglobal.h>
+#include <kinstance.h>
+#include <klocale.h>
+#include <kstandarddirs.h>
 
-#include "simpleformat.h"
-#include "vcardformat.h"
+#include "errorhandler.h"
 #include "resource.h"
 
 #include "addressbook.h"
@@ -38,6 +40,11 @@ using namespace KABC;
 struct AddressBook::AddressBookData
 {
   Addressee::List mAddressees;
+  Addressee::List mRemovedAddressees;
+  Field::List mAllFields;
+  QPtrList<Resource> mResources;
+  ErrorHandler *mErrorHandler;
+  Resource *mStandardResource;
 };
 
 struct AddressBook::Iterator::IteratorData
@@ -83,6 +90,11 @@ Addressee &AddressBook::Iterator::operator*()
   return *(d->mIt);
 }
 
+Addressee *AddressBook::Iterator::operator->()
+{
+  return &(*(d->mIt));
+}
+
 AddressBook::Iterator &AddressBook::Iterator::operator++()
 {
   (d->mIt)++;
@@ -141,10 +153,16 @@ AddressBook::ConstIterator::~ConstIterator()
   delete d;
 }
 
-const Addressee & AddressBook::ConstIterator::operator*() const
+const Addressee &AddressBook::ConstIterator::operator*() const
 {
   return *(d->mIt);
 }
+
+const Addressee* AddressBook::ConstIterator::operator->() const
+{
+  return &(*(d->mIt));
+}
+
 AddressBook::ConstIterator &AddressBook::ConstIterator::operator++()
 {
   (d->mIt)++;
@@ -183,20 +201,19 @@ bool AddressBook::ConstIterator::operator!=( const ConstIterator &it )
 AddressBook::AddressBook()
 {
   d = new AddressBookData;
+  d->mResources.setAutoDelete( true );
+  d->mErrorHandler = 0;
+  d->mStandardResource = 0;
 }
 
 AddressBook::~AddressBook()
 {
+  d->mResources.clear();
+  d->mStandardResource = 0;
+  delete d->mErrorHandler;
   delete d;
 }
 
-bool AddressBook::addResource( Resource *resource )
-{
-  if ( !resource->open() ) return false;
-  mResources.append( resource );
-  return true;
-}
-
 bool AddressBook::load()
 {
   kdDebug(5700) << "AddressBook::load()" << endl;
@@ -204,12 +221,19 @@ bool AddressBook::load()
   clear();
 
   Resource *r;
-  for( r = mResources.first(); r; r = mResources.next() ) {
-      // kdDebug() << " Tick" << endl;
-    if ( !r->load( this ) ) return false;
-  }
+  bool ok = true;
+  for( r = d->mResources.first(); r; r = d->mResources.next() )
+    if ( !r->load() ) {
+      error( i18n("Unable to load resource '%1'").arg( r->name() ) );
+      ok = false;
+    }
 
-  return true;
+  // mark all addressees as unchanged
+  Addressee::List::Iterator it;
+  for ( it = d->mAddressees.begin(); it != d->mAddressees.end(); ++it )
+    (*it).setChanged( false );
+
+  return ok;
 }
 
 bool AddressBook::save( Ticket *ticket )
@@ -217,6 +241,7 @@ bool AddressBook::save( Ticket *ticket )
   kdDebug(5700) << "AddressBook::save()"<< endl;
 
   if ( ticket->resource() ) {
+    deleteRemovedAddressees();
     return ticket->resource()->save( ticket );
   }
 
@@ -260,27 +285,45 @@ Ticket *AddressBook::requestSaveTicket( Resource *resource )
 {
   kdDebug(5700) << "AddressBook::requestSaveTicket()" << endl;
 
-  if ( !resource ) {
-    resource = mResources.first();
-  }
+  if ( !resource )
+    resource = standardResource();
 
-  if ( mResources.find( resource ) < 0 ) {
+  if ( d->mResources.find( resource ) < 0 ) {
     return 0;
   } else {
-    return resource->requestSaveTicket();
+    if ( resource->readOnly() )
+      return 0;
+    else
+      return resource->requestSaveTicket();
   }
 }
 
 void AddressBook::insertAddressee( const Addressee &a )
 {
-  Iterator it;
-  for ( it = begin(); it != end(); ++it ) {
+  Addressee::List::Iterator it;
+  for ( it = d->mAddressees.begin(); it != d->mAddressees.end(); ++it ) {
     if ( a.uid() == (*it).uid() ) {
+      bool changed = false;
+      Addressee addr = a;
+      if ( addr != (*it) )
+        changed = true;
+
       (*it) = a;
+      if ( (*it).resource() == 0 )
+        (*it).setResource( standardResource() );
+
+      if ( changed ) {
+        (*it).setRevision( QDateTime::currentDateTime() );
+        (*it).setChanged( true ); 
+      }
       return;
     }
   }
   d->mAddressees.append( a );
+  Addressee& addr = d->mAddressees.last();
+  if ( addr.resource() == 0 )
+    addr.setResource( standardResource() );
+  addr.setChanged( true );
 }
 
 void AddressBook::removeAddressee( const Addressee &a )
@@ -296,6 +339,7 @@ void AddressBook::removeAddressee( const Addressee &a )
 
 void AddressBook::removeAddressee( const Iterator &it )
 {
+  d->mRemovedAddressees.append( (*it) );
   d->mAddressees.remove( it.d->mIt );
 }
 
@@ -338,11 +382,15 @@ Addressee::List AddressBook::findByName( const QString &name )
 Addressee::List AddressBook::findByEmail( const QString &email )
 {
   Addressee::List results;
+  QStringList mailList;
 
   Iterator it;
   for ( it = begin(); it != end(); ++it ) {
-    if ( email == (*it).preferredEmail() ) {
-      results.append( *it );
+    mailList = (*it).emails();    
+    for ( QStringList::Iterator ite = mailList.begin(); ite != mailList.end(); ++ite ) {
+      if ( email == (*ite) ) {
+        results.append( *it );
+      }
     }
   }
 
@@ -377,5 +425,136 @@ void AddressBook::dump() const
 
 QString AddressBook::identifier()
 {
-  return "NoIdentifier";
+  QString identifier;
+
+    for ( uint i = 0; i < d->mResources.count(); ++i ) {
+      Resource *resource = d->mResources.at( i );
+      identifier += ( i == 0 ? "" : ":" ) + resource->identifier();
+    }
+
+  return identifier;
+}
+
+Field::List AddressBook::fields( int category )
+{
+  if ( d->mAllFields.isEmpty() ) {
+    d->mAllFields = Field::allFields();
+  }
+  
+  if ( category == Field::All ) return d->mAllFields;
+  
+  Field::List result;
+  Field::List::ConstIterator it;
+  for( it = d->mAllFields.begin(); it != d->mAllFields.end(); ++it ) {
+    if ( (*it)->category() & category ) result.append( *it );
+  }
+  
+  return result;
+}
+
+bool AddressBook::addCustomField( const QString &label, int category,
+                                  const QString &key, const QString &app )
+{
+  if ( d->mAllFields.isEmpty() ) {
+    d->mAllFields = Field::allFields();
+  }
+  
+  QString a = app.isNull() ? KGlobal::instance()->instanceName() : app;
+  QString k = key.isNull() ? label : key;
+
+  Field *field = Field::createCustomField( label, category, k, a );
+
+  if ( !field ) return false;
+
+  d->mAllFields.append( field );
+
+  return true;
+}
+
+QDataStream &KABC::operator<<( QDataStream &s, const AddressBook &ab )
+{
+  if (!ab.d) return s;
+
+  return s << ab.d->mAddressees;
+}
+
+QDataStream &KABC::operator>>( QDataStream &s, AddressBook &ab )
+{
+  if (!ab.d) return s;
+
+  s >> ab.d->mAddressees;
+
+  return s;
+}
+
+bool AddressBook::addResource( Resource *resource )
+{
+  if ( !resource->open() ) {
+    kdDebug(5700) << "AddressBook::addResource(): can't add resource" << endl;
+    return false;
+  }
+
+  d->mResources.append( resource );
+  return true;
+}
+
+bool AddressBook::removeResource( Resource *resource )
+{
+  if ( resource == standardResource() )
+    setStandardResource( 0 );
+
+  return d->mResources.remove( resource );
+}
+
+QPtrList<Resource> AddressBook::resources()
+{
+    return d->mResources;
+}
+
+void AddressBook::setErrorHandler( ErrorHandler *handler )
+{
+    delete d->mErrorHandler;
+    d->mErrorHandler = handler;
+}
+
+void AddressBook::error( const QString& msg )
+{
+  if ( !d->mErrorHandler ) // create default error handler
+    d->mErrorHandler = new ConsoleErrorHandler;
+
+  if ( d->mErrorHandler )
+    d->mErrorHandler->error( msg );
+  else
+    kdError(5700) << "no error handler defined" << endl;
+}
+
+void AddressBook::deleteRemovedAddressees()
+{
+  Addressee::List::Iterator it;
+  for ( it = d->mRemovedAddressees.begin(); it != d->mRemovedAddressees.end(); ++it ) {
+    Resource *resource = (*it).resource();
+    if ( resource && !resource->readOnly() )
+      resource->removeAddressee( *it );
+  }
+
+  d->mRemovedAddressees.clear();
+}
+
+void AddressBook::setStandardResource( Resource *resource )
+{
+  d->mStandardResource = resource;
+}
+
+Resource *AddressBook::standardResource()
+{
+  return d->mStandardResource;
+}
+
+void AddressBook::cleanUp()
+{
+  for ( uint i = 0; i < d->mResources.count(); ++i ) {
+    Resource *resource = d->mResources.at( i );
+    if ( !resource->readOnly() )
+      resource->cleanUp();
+  }
 }
