@@ -21,7 +21,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: addresslineedit.cpp,v 1.6.2.3 2003/01/31 14:45:47 pfeiffer Exp $
+// $Id: addresslineedit.cpp,v 1.6.2.5 2003/07/22 06:28:05 deller Exp $
 
 #include "addresslineedit.h"
 
@@ -296,30 +296,9 @@ void AddressLineEdit::doCompletion(bool ctrlT)
     if ( s_addressesDirty )
         loadAddresses();
 
-    QString match;
-    int curPos = cursorPosition();
-    if ( mode != KGlobalSettings::CompletionNone )
-    {
-        match = s_completion->makeCompletion( s );
-        if (match.isNull() && mode == KGlobalSettings::CompletionPopup)
-          match = s_completion->makeCompletion( "\"" + s );
-        if (match.isNull() && mode == KGlobalSettings::CompletionPopup)
-          match = s_completion->makeCompletion( "$$" + s );
-    }
-
-    kdDebug() << "** completion for: " << s << " : " << match << endl;
-
     if ( ctrlT )
     {
-        QStringList addresses = s_completion->items();
-        QStringList::Iterator it = addresses.begin();
-        QStringList completions;
-        for (; it != addresses.end(); ++it)
-        {
-            if ((*it).find(s,0,false) >= 0)
-                completions.append( *it );
-        }
-
+        QStringList completions = s_completion->substringCompletion( s );
         if (completions.count() > 1) {
             m_previousAddresses = prevAddr;
             box->setItems( completions );
@@ -339,36 +318,45 @@ void AddressLineEdit::doCompletion(bool ctrlT)
     {
         case KGlobalSettings::CompletionPopup:
         {
-            if ( !match.isNull() )
-            {
                 m_previousAddresses = prevAddr;
 		QStringList items = s_completion->allMatches( s );
                 items += s_completion->allMatches( "\"" + s );
 		items += s_completion->substringCompletion( '<' + s );
+            uint beforeDollarCompletionCount = items.count();
+            
 		if( !s.contains( ' ' )) // one word, possibly given name
 		    items += s_completion->allMatches( "$$" + s );
+            
+            if ( items.isEmpty() )
+                box->hide();
+            else
+            {
+                if ( items.count() > beforeDollarCompletionCount )
+                {
+                    // remove the '$$whatever$' part                    
     		for( QStringList::Iterator it = items.begin();
 		     it != items.end();
 		     ++it )
-		{ // remove the '$$whatever$' part
+                    { 
 		    int pos = (*it).find( '$', 2 );
 		    if( pos < 0 ) // ???
 		        continue;
 		    (*it)=(*it).mid( pos + 1 );
 		}
+                }
+                
 		items = removeMailDupes( items );
 		box->setItems( items );
                 box->setCancelledText( text() );
                 box->popup();
             }
-            else
-                box->hide();
 
             break;
         }
 
         case KGlobalSettings::CompletionShell:
         {
+            QString match = s_completion->makeCompletion( s );
             if ( !match.isNull() && match != s )
             {
                 slotSetTextAsEdited( prevAddr + match );
@@ -380,9 +368,11 @@ void AddressLineEdit::doCompletion(bool ctrlT)
         case KGlobalSettings::CompletionMan: // Short-Auto in fact
         case KGlobalSettings::CompletionAuto:
         {
+            QString match = s_completion->makeCompletion( s );
             if ( !match.isNull() && match != s )
             {
                 QString adds = prevAddr + match;
+                int curPos = cursorPosition();
                 validateAndSet( adds, curPos, curPos, adds.length() );
             }
             break;
@@ -463,8 +453,17 @@ void AddressLineEdit::slotLDAPSearchData( const QStringList& adrs )
         return;
     for( QStringList::ConstIterator it = adrs.begin();
 	 it != adrs.end();
-	 ++it )
-	addAddress( *it );
+	 ++it ) {
+	QString name(*it);
+	int pos = name.find( " <" );
+	int pos_comma = name.find( ',' );
+	// put name in quotes, if we have a comma in the name
+	if (pos>0 && pos_comma>0 && pos_comma<pos) {
+		name.insert(pos, '\"');
+		name.prepend('\"');
+	}
+	addAddress( name );
+    }
     if( hasFocus() || completionBox()->hasFocus())
     {
         if( completionMode() != KGlobalSettings::CompletionNone )
@@ -545,7 +544,7 @@ QStringList AddressLineEdit::addresses()
     n = n.simplifyWhiteSpace();
 
     QRegExp needQuotes("[^ 0-9A-Za-z\\x0080-\\xFFFF]");
-    QString endQuote = "\" ";
+    QString endQuote("\" ");
     QString empty = "";
     QStringList::ConstIterator mit;
     QString addr, email;
