@@ -31,7 +31,8 @@ class AddressBook;
 
   This class provides an abstract interface for address book file formats.
 */
-class Format {
+class Format
+{
   public:
     /**
       Load addressbook from file.
