@@ -1,7 +1,7 @@
 #include <qwidget.h>
 
 #include <kaboutdata.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
@@ -49,7 +49,8 @@ int main(int argc,char **argv)
       new DistributionListEditor( StdAddressBook::self(), 0 );
 
   editor->show();
-
+  app.setMainWidget(editor);
+  
   QObject::connect( &app, SIGNAL( lastWindowClosed() ), &app, SLOT( quit() ) );
 
   app.exec();
