@@ -18,6 +18,8 @@
     Boston, MA 02111-1307, USA.
 */
 
+#include <qdatastream.h>
+
 #include "timezone.h"
 
 using namespace KABC;
@@ -50,12 +52,34 @@ bool TimeZone::isValid() const
 
 bool TimeZone::operator==( const TimeZone &t ) const
 {
+  if ( !t.isValid() && !isValid() ) return true;
   if ( !t.isValid() || !isValid() ) return false;
   if ( t.mOffset == mOffset ) return true;
   return false;
 }
 
+bool TimeZone::operator!=( const TimeZone &t ) const
+{
+  if ( !t.isValid() && !isValid() ) return false;
+  if ( !t.isValid() || !isValid() ) return true;
+  if ( t.mOffset != mOffset ) return true;
+  return false;
+}
+
 QString TimeZone::asString() const
 {
   return QString::number( mOffset );
 }
+
+QDataStream &KABC::operator<<( QDataStream &s, const TimeZone &zone )
+{
+    return s << zone.mOffset;
+}
+
+QDataStream &KABC::operator>>( QDataStream &s, TimeZone &zone )
+{
+    s >> zone.mOffset;
+    zone.mValid = true;
+
+    return s;
+}
