@@ -36,10 +36,24 @@ VCardFormat::~VCardFormat()
 
 bool VCardFormat::load( AddressBook *addressBook, const QString &fileName )
 {
-  return mImpl->load( addressBook, fileName );
+  QFile f( fileName );
+  if ( !f.open( IO_ReadOnly ) ) return false;
+  
+  bool result = mImpl->loadAll( addressBook, 0, &f );
+  
+  f.close();
+  
+  return result;
 }
 
 bool VCardFormat::save( AddressBook *addressBook, const QString &fileName )
 {
-  return mImpl->save( addressBook, fileName );
+  QFile f( fileName );
+  if ( !f.open( IO_WriteOnly ) ) return false;
+  
+  mImpl->saveAll( addressBook, 0, &f );
+  
+  f.close();
+  
+  return true;
 }
