@@ -16,23 +16,43 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
-*/
+*/                                                           
+
+// Copyright (c) 2000-2001 Charles Samuels <charles@kde.org>
+// Copyright (c) 2000-2001 Neil Stevens <multivac@fcmail.com>
+// 
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to deal
+// in the Software without restriction, including without limitation the rights
+// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+// copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+// 
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+// 
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+// AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIAB\ILITY, WHETHER IN
+// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
 
 #ifndef KATE_DIALOGS_H
 #define KATE_DIALOGS_H
 
-#include "kateglobal.h"
-#include "katesyntaxdocument.h"
 #include "katehighlight.h"
 #include "katedocument.h"
+#include "../interfaces/document.h"
 
 #include <kdialog.h>
 #include <kdialogbase.h>
-#include <klistview.h>
 #include <qtabwidget.h>
 #include <kcolorbutton.h>
-#include <qcolor.h>
-#include <qlistview.h>
+#include <qcolor.h>       
+#include <ktrader.h>
+  
 
 class QWidgetStack;
 class QVBox;
@@ -43,7 +63,86 @@ class QCheckBox;
 
 #define HlEUnknown 0
 #define HlEContext 1
-#define HlEItem 2
+#define HlEItem 2     
+                     
+#include <qvbox.h>  
+
+#define private protected
+#include <qlistview.h>
+#undef private 
+
+#include <klistview.h>
+
+class QListBoxItem;      
+
+class PluginListItem : public QCheckListItem
+{
+public:
+	PluginListItem(const bool _exclusive, bool _checked, Kate::PluginInfo *_info, QListView *_parent);
+	Kate::PluginInfo *info() const { return mInfo; }
+
+	// This will toggle the state without "emitting" the stateChange
+	void setChecked(bool);
+
+protected:	
+	virtual void stateChange(bool);
+	virtual void paintCell(QPainter *, const QColorGroup &, int, int, int);
+   
+private:
+	Kate::PluginInfo *mInfo;
+	bool silentStateChange;
+	bool exclusive;
+};
+
+class PluginListView : public KListView
+{
+Q_OBJECT
+
+friend class PluginListItem;
+
+public:
+	PluginListView(QWidget *_parent = 0, const char *_name = 0);
+	PluginListView(unsigned _min, QWidget *_parent = 0, const char *_name = 0);
+	PluginListView(unsigned _min, unsigned _max, QWidget *_parent = 0, const char *_name = 0);
+
+	virtual void clear();
+
+signals:
+	void stateChange(PluginListItem *, bool);
+
+private:
+	void stateChanged(PluginListItem *, bool);
+	
+	bool hasMaximum;
+	unsigned max, min;
+	unsigned count;
+};
+
+class PluginConfigPage : public Kate::ConfigPage
+{
+  Q_OBJECT
+
+  public:
+    PluginConfigPage (QWidget *parent, class KateDocument *doc);
+    ~PluginConfigPage ();
+
+  private:
+    KateDocument *m_doc;
+    
+  private slots:
+    void stateChange(PluginListItem *, bool); 
+    
+  private slots:
+    void loadPlugin (PluginListItem *);
+    void unloadPlugin (PluginListItem *);
+
+  public slots:
+    void apply () {};
+    void reload () {};   
+    void reset () {};
+    void defaults () {};
+};
+
 
 /*
     QListViewItem subclass to display/edit a style, bold/italic is check boxes,
@@ -59,7 +158,7 @@ class QCheckBox;
 class StyleListItem : public QListViewItem {
   public:
     StyleListItem( QListView *parent=0, const QString & stylename=0,
-                   ItemStyle *defaultstyle=0, ItemData *data=0 );
+                   class ItemStyle *defaultstyle=0, class ItemData *data=0 );
     ~StyleListItem() {};
 
     /* mainly for readability */
@@ -74,12 +173,12 @@ class StyleListItem : public QListViewItem {
     /* style context name */
     QString contextName() { return text(0); };
     /* only true for a hl mode item using it's default style */
-    bool defStyle() { return st && st->defStyle; };
+    bool defStyle();
     /* true for default styles */
-    bool isDefault() { return st ? false : true; };
+    bool isDefault();
     /* whichever style is active (st for hl mode styles not using
        the default style, ds otherwise) */
-    ItemStyle* style() { return is; };
+    class ItemStyle* style() { return is; };
   protected:
     /* reimp */
     void paintCell(QPainter *p, const QColorGroup& cg, int col, int width, int align);
@@ -94,9 +193,9 @@ class StyleListItem : public QListViewItem {
        when a property is changed and we are using default style. */
     void setCustStyle();
 
-    ItemStyle *is, // the style currently in use
+    class ItemStyle *is, // the style currently in use
               *ds; // default style for hl mode contexts and default styles
-    ItemData *st;  // itemdata for hl mode contexts
+    class ItemData *st;  // itemdata for hl mode contexts
 };
 
 /*
@@ -182,11 +281,15 @@ class HlConfigPage : public Kate::ConfigPage
   Q_OBJECT
 
   public:
-    HlConfigPage (QWidget *parent, KateDocument *doc);
+    HlConfigPage (QWidget *parent, class KateDocument *doc);
     ~HlConfigPage ();
 
+  protected:
+    void showEvent ( QShowEvent * );  
+    
   private:
-    KateDocument *myDoc;
+    bool m_ready;
+    KateDocument *m_doc;
     class HighlightDialogPage *page;
     class HlManager *hlManager;
     HlDataList hlDataList;
@@ -194,7 +297,9 @@ class HlConfigPage : public Kate::ConfigPage
 
   public slots:
     void apply ();
-    void reload ();
+    void reload ();   
+    void reset () {};
+    void defaults () {};
 };
 
 class HighlightDialogPage : public QTabWidget
