@@ -16,7 +16,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kateexportaction.cpp,v 1.5 2002/01/12 13:47:12 cullmann Exp $
+// $Id: kateexportaction.cpp,v 1.6 2002/05/20 20:35:58 cullmann Exp $
 
 #include "kateexportaction.h"
 #include "kateexportaction.moc"
@@ -30,17 +30,17 @@ void KateExportAction::init()
 	filter<<QString("kate_html_export");
 	popupMenu()->insertItem (i18n("&HTML..."),0);
 	connect(popupMenu(),SIGNAL(activated(int)),this,SLOT(filterChoosen(int)));
-	myDoc=0L;
+	m_doc=0L;
 }
 
 void KateExportAction::updateMenu (Kate::Document *doc)
 {
-  myDoc = doc;
+  m_doc = doc;
 }
 
 void KateExportAction::filterChoosen(int id)
 {
-  Kate::Document *doc = myDoc;
+  Kate::Document *doc = m_doc;
 
   if (!doc)
     return;
