@@ -1,6 +1,8 @@
 /* This file is part of the KDE libraries
    Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
    Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+   
+   Based on KHTML Factory from Simon Hausmann <hausmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,9 +22,8 @@
 #ifndef __kate_factory_h__
 #define __kate_factory_h__
 
-#include "kateglobal.h"
-
 #include <kparts/factory.h>
+#include <ktrader.h>
 
 class KInstance;
 class KAboutData;
@@ -31,17 +32,35 @@ class KateFactory : public KParts::Factory
 {
   Q_OBJECT
 public:
-  KateFactory();
+  KateFactory( bool clone = false );
   virtual ~KateFactory();
 
   virtual KParts::Part *createPartObject( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *classname, const QStringList &args );
 
-  static const KAboutData *aboutData();
   static KInstance *instance();
-
+  
+  static void registerDocument ( class KateDocument *doc );
+  static void deregisterDocument ( class KateDocument *doc );
+  
+  static void registerView ( class KateView *view );
+  static void deregisterView ( class KateView *view );
+  
+  static KTrader::OfferList *plugins ();
+  
 private:
+  static void ref();
+  static void deref();
+
+  static unsigned long s_refcnt;
+  static KateFactory *s_self;
+  
+  static QPtrList<class KateDocument> *s_documents;
+  static QPtrList<class KateView> *s_views;
+  
   static KInstance *s_instance;
-  static KAboutData *s_aboutData;
+  static KAboutData *s_about;
+  
+  static KTrader::OfferList *s_plugins;
 };
 
 #endif
