@@ -19,7 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kateview.cpp,v 1.221.2.1 2003/01/19 07:17:30 wheeler Exp $
+// $Id: kateview.cpp,v 1.221.2.2 2003/02/01 05:10:12 rodda Exp $
 
 #include "kateview.h"
 #include "kateview.moc"
@@ -121,7 +121,7 @@ KateView::KateView( KateDocument *doc, QWidget *parent, const char * name )
 
   // update the enabled state of the undo/redo actions...
   slotNewUndo();
-  
+
   m_viewInternal->show ();
 }
 
@@ -245,7 +245,7 @@ void KateView::setupActions()
   a=new KAction(i18n("Decrease Font Sizes"), "viewmag-", 0, this, SLOT(slotDecFontSizes()), ac, "decFontSizes");
   a->setWhatsThis(i18n("This decreases the display font size."));
 
-  a=new KAction(i18n("T&oggle Block Selection"), Key_F4, m_doc, SLOT(toggleBlockSelectionMode()), ac, "set_verticalSelect");
+  a=new KAction(i18n("T&oggle Block Selection"), CTRL + SHIFT + Key_B, m_doc, SLOT(toggleBlockSelectionMode()), ac, "set_verticalSelect");
   a->setWhatsThis(i18n("This command allows switching between the normal (line based) selection mode and the block selection mode."));
 
   a=new KAction(i18n("Toggle &Insert"), Key_Insert, this, SLOT(toggleInsert()), ac, "set_insert" );
@@ -547,6 +547,11 @@ void KateView::slotStatusMsg ()
   emit viewStatusMsg (" " + s1 + " " + s2 + " " + ovrstr + " " + blockstr+ " " + modstr);
 }
 
+void KateView::slotSelectionTypeChanged()
+{
+  emit newStatus();
+}
+
 void KateView::reloadFile()
 {
   // save cursor position
