@@ -20,57 +20,30 @@
 #ifndef _KATE_VIEWDIALOG_H_
 #define _KATE_VIEWDIALOG_H_
 
-#include "kateglobal.h"
+#include "katesearch.h"
+#include "../interfaces/document.h"
 
+#include <kdialogbase.h>
+
+class KAccel;
+class KColorButton;
+class KComboBox;
+class KIntNumInput;
+class KKeyButton;
+class KKeyChooser;
+class KMainWindow;
+class KPushButton;
+class KRegExpDialog;
+
+class QButtonGroup;
 class QCheckBox;
 class QLineEdit;
 class QPushButton;
 class QRadioButton;
 class QSpinBox;
-class KColorButton;
-class KIntNumInput;
-class KComboBox;
-class KRegExpDialog;
-class KKeyButton;
-class KPushButton;
-class KMainWindow;
-class KAccel;
-class KKeyChooser;
-class KSpellConfig;
 
-#include <kdialogbase.h>
-#include "kateview.h"
-#include "katedocument.h"
-
-class SearchDialog : public KDialogBase
-{
-  Q_OBJECT
-
-  public:
-    SearchDialog( QWidget *parent, QStringList &searchFor, QStringList &replaceWith, int flags );
-    QString getSearchFor();
-    QString getReplaceWith();
-    int getFlags();
-    void setSearchText( const QString &searchstr );
-
-  protected slots:
-    void slotOk();
-    void selectedStateChanged (int);
-    void slotEditRegExp();
-    void slotSearchTextChanged( const QString & );
-
-  protected:
-    KComboBox *m_search;
-    KComboBox *m_replace;
-    QCheckBox *m_opt1;
-    QCheckBox *m_opt2;
-    QCheckBox *m_opt3;
-    QCheckBox *m_optRegExp;
-    QCheckBox *m_opt4;
-    QCheckBox *m_opt5;
-    QCheckBox *m_opt6;
-    QDialog *m_regExpDialog;
-};
+class KateDocument;
+class KateView;
 
 class ReplacePrompt : public KDialogBase
 {
@@ -117,15 +90,17 @@ class IndentConfigTab : public Kate::ConfigPage
     void getData(KateDocument *);
 
   protected:
-    KateDocument *myDoc;
+    KateDocument *m_doc;
 
     enum { numFlags = 6 };
     static const int flags[numFlags];
     QCheckBox *opt[numFlags];
-    
+
   public slots:
     void apply ();
     void reload ();
+        void reset () {};
+    void defaults () {};
 };
 
 class SelectConfigTab : public Kate::ConfigPage
@@ -136,7 +111,7 @@ class SelectConfigTab : public Kate::ConfigPage
 
     SelectConfigTab(QWidget *parent, KateDocument *);
     void getData(KateDocument *);
-    KateDocument *myDoc;
+    KateDocument *m_doc;
 
   protected:
 
@@ -147,6 +122,8 @@ class SelectConfigTab : public Kate::ConfigPage
   public slots:
     void apply ();
     void reload ();
+        void reset () {};
+    void defaults () {};
 };
 
 class EditConfigTab : public Kate::ConfigPage
@@ -167,11 +144,40 @@ class EditConfigTab : public Kate::ConfigPage
     KIntNumInput *e1;
     KIntNumInput *e2;
     KIntNumInput *e3;
-    KateDocument *myDoc;
-  
+    KateDocument *m_doc;
+
   public slots:
     void apply ();
     void reload ();
+        void reset () {};
+    void defaults () {};
+
+  protected slots:
+    void wordWrapToggled();
+};
+
+class ViewDefaultsConfig : public Kate::ConfigPage
+{
+  Q_OBJECT
+
+public:
+  ViewDefaultsConfig( QWidget *parent = 0, const char *name = 0, KateDocument *doc=0 );
+  ~ViewDefaultsConfig();
+
+private:
+  KateDocument *m_doc;
+
+  QCheckBox *m_line;
+  QCheckBox *m_folding;
+  QCheckBox *m_icons;
+  QCheckBox *m_dynwrap;
+  QButtonGroup *m_bmSort;
+
+public slots:
+ void apply ();
+ void reload ();
+ void reset ();
+ void defaults ();
 };
 
 class ColorConfig : public Kate::ConfigPage
@@ -187,14 +193,18 @@ public:
   void getColors( QColor * );
 
 private:
-  KateDocument *myDoc;
+  KateDocument *m_doc;
 
   KColorButton *m_back;
   KColorButton *m_selected;
+  KColorButton *m_current;
+  KColorButton *m_bracket;
 
   public slots:
     void apply ();
     void reload ();
+        void reset () {};
+    void defaults () {};
 };
 
 class FontConfig : public Kate::ConfigPage
@@ -212,12 +222,12 @@ public:
   void setFontPrint ( const QFont &font );
   QFont getFontPrint ( ) { return myFontPrint; };
 
-  private:
+ private:
     class KFontChooser *m_fontchooser;
     class KFontChooser *m_fontchooserPrint;
     QFont myFont;
     QFont myFontPrint;
-    KateDocument *myDoc;
+    KateDocument *m_doc;
 
   private slots:
     void slotFontSelected( const QFont &font );
@@ -226,45 +236,31 @@ public:
   public slots:
     void apply ();
     void reload ();
+    void reset () {};
+    void defaults () {};
 };
 
 
 class EditKeyConfiguration: public Kate::ConfigPage
-{
-	Q_OBJECT
-public:
-	EditKeyConfiguration(QWidget *parent=0, const char *name=0);
-	~EditKeyConfiguration();
-	void save();
-private:
-	KMainWindow *tmpWin;
-	KAccel *m_editAccels;
-	KKeyChooser *chooser;
-	void setupEditKeys();
-protected slots:
-	void dummy();
-  
-  public slots:
-    void apply ();
-    void reload ();
-};
-
-
-class KSpellConfigPage : public Kate::ConfigPage
 {
   Q_OBJECT
 
   public:
-    KSpellConfigPage (QWidget *parent, KateDocument *doc);
-    ~KSpellConfigPage ();
-
-  private:
-    KateDocument *myDoc;
-    class KSpellConfig *ksc;
-
+    EditKeyConfiguration( QWidget* parent, KateDocument* doc );
+    
   public slots:
-    void apply ();
-    void reload ();
+    void apply();
+    void reload()   {};
+    void reset()    {};
+    void defaults() {};
+
+  protected:
+    void showEvent ( QShowEvent * );  
+    
+  private:
+    bool m_ready;
+    class KateDocument *m_doc;
+    KKeyChooser* m_keyChooser;
 };
 
 #endif
