@@ -25,7 +25,7 @@
    pattern is non-optimal it might waste some memory while running.  E.g.
    allocating many small things at once, and then deallocating only every
    second one, there is a high chance, that actually no memory is freed.  */
-// $Id: kallocator.cpp,v 1.5 2002/03/07 16:38:57 matz Exp $
+// $Id: kallocator.cpp,v 1.8 2002/08/29 07:13:08 cumming Exp $
 
 #include "kallocator.h"
 #include <kdebug.h>
@@ -51,7 +51,9 @@ KZoneAllocator::KZoneAllocator(unsigned long _blockSize)
 {
   while (blockSize < _blockSize)
     blockSize <<= 1, log2++;
-  blockOffset = blockSize;
+  /* Make sure, that a block is allocated at the first time allocate()
+     is called (even with a 0 size).  */
+  blockOffset = blockSize + 1;
 }
 
 KZoneAllocator::~KZoneAllocator()
@@ -60,7 +62,7 @@ KZoneAllocator::~KZoneAllocator()
   if (hashList) {
     /* No need to maintain the different lists in hashList[] anymore.
        I.e. no need to use delBlock().  */
-    for (int i = 0; i < hashSize; i++)
+    for (unsigned int i = 0; i < hashSize; i++)
       delete hashList[i];
     delete [] hashList;
     hashList = 0;
@@ -111,7 +113,7 @@ void KZoneAllocator::addBlock(MemBlock *b)
 void KZoneAllocator::initHash()
 {
   if (hashList) {
-    for (int i = 0; i < hashSize; i++)
+    for (unsigned int i = 0; i < hashSize; i++)
       delete hashList[i];
     delete [] hashList;
     hashList = 0;
@@ -175,7 +177,7 @@ KZoneAllocator::allocate(size_t _size)
    if ((unsigned long) _size + blockOffset > blockSize)
    {
       if (_size > blockSize) {
-	qDebug("KZoneAllocator: allocating more than %u bytes", blockSize);
+	qDebug("KZoneAllocator: allocating more than %lu bytes", blockSize);
 	return 0;
       }
       addBlock(new MemBlock(blockSize));
