@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
         */
 
-// $Id: kapplication.cpp,v 1.545.2.12 2003/04/02 09:33:34 waba Exp $
+// $Id: kapplication.cpp,v 1.545.2.20 2003/07/09 03:10:22 bmeyer Exp $
 
 #include "config.h"
 
@@ -1788,20 +1788,31 @@ void KApplication::installKDEPropertyMap()
 #ifndef QT_NO_SQL
     // QSqlPropertyMap takes ownership of the new default map.
     QSqlPropertyMap *kdeMap = new QSqlPropertyMap;
+    kdeMap->insert( "KColorButton", "color" );
     kdeMap->insert( "KComboBox", "currentItem" );
-    kdeMap->insert( "KDatePicker", "getDate" );
+    kdeMap->insert( "KDatePicker", "date" );
     kdeMap->insert( "KEditListBox", "currentItem" );
-    kdeMap->insert( "KFontCombo", "currentFont" );
+    kdeMap->insert( "KFontCombo", "family" );
+    kdeMap->insert( "KFontRequester", "font" );
     kdeMap->insert( "KHistoryCombo", "currentItem" );
     kdeMap->insert( "KListBox", "currentItem" );
     kdeMap->insert( "KLineEdit", "text" );
-    kdeMap->insert( "KPasswordEdit", "text" );
     kdeMap->insert( "KRestrictedLine", "text" );
     kdeMap->insert( "KSqueezedTextLabel", "text" );
     kdeMap->insert( "KTextBrowser", "source" );
+    kdeMap->insert( "KTextEdit", "text" );
     kdeMap->insert( "KURLRequester", "url" );
+    kdeMap->insert( "KPasswordEdit", "password" );
+    kdeMap->insert( "KIntNumInput", "value" );
+    kdeMap->insert( "KDoubleNumInput", "value" );
+    //#if QT_VERSION < 0x030300
+      // Temp til fixed in QT then enable ifdef with the correct version number
+      kdeMap->insert( "QRadioButton", "checked" );
+      kdeMap->insert( "QTabWidget", "currentPage" );
+    //#endif
     QSqlPropertyMap::installDefaultMap( kdeMap );
 #endif
+
 }
 
 void KApplication::invokeHelp( const QString& anchor,
@@ -1892,7 +1903,7 @@ void KApplication::invokeMailer(const QString &to, const QString &cc, const QStr
 {
    KConfig config("emaildefaults");
    config.setGroup( QString::fromLatin1("PROFILE_Default") );
-   QString command = config.readEntry("EmailClient");
+   QString command = config.readPathEntry("EmailClient");
 
    if (command.isEmpty() || command == QString::fromLatin1("kmail")
        || command.right(6) == "/kmail")
@@ -2018,6 +2029,9 @@ startServiceInternal( const QCString &function,
    if (qt_xdisplay()) {
        QCString dpystring(XDisplayString(qt_xdisplay()));
        envs.append( QCString("DISPLAY=") + dpystring );
+   } else if( getenv( "DISPLAY" )) {
+       QCString dpystring( getenv( "DISPLAY" ));
+       envs.append( QCString("DISPLAY=") + dpystring );
    }
 #endif
    stream << envs;
@@ -2388,6 +2402,10 @@ void KApplication::initUrlActionRestrictions()
   ("redirect", QString::null, QString::null, QString::null, "ftp", QString::null, QString::null, true));
   d->urlActionRestrictions.append( new KApplicationPrivate::URLActionRule
   ("redirect", QString::null, QString::null, QString::null, "mailto", QString::null, QString::null, true));
+  d->urlActionRestrictions.append( new KApplicationPrivate::URLActionRule
+  ("redirect", QString::null, QString::null, QString::null, "rtsp", QString::null, QString::null, true));
+  d->urlActionRestrictions.append( new KApplicationPrivate::URLActionRule
+  ("redirect", QString::null, QString::null, QString::null, "mms", QString::null, QString::null, true));
 
   // We allow redirections to file: but not from http:, redirecting to file:
   // is very popular among io-slaves and we don't want to break them
@@ -2404,6 +2422,10 @@ void KApplication::initUrlActionRestrictions()
   d->urlActionRestrictions.append( new KApplicationPrivate::URLActionRule
   ("redirect", "lan", QString::null, QString::null, QString::null, QString::null, QString::null, true));
 
+  // info:/ kioslave may redirect to help:/
+  d->urlActionRestrictions.append( new KApplicationPrivate::URLActionRule
+  ("redirect", "info", QString::null, QString::null, "help", QString::null, QString::null, true));
+
   d->urlActionRestrictions.append( new KApplicationPrivate::URLActionRule
   ("redirect", QString::null, QString::null, QString::null, "about", QString::null, QString::null, true));
   d->urlActionRestrictions.append( new KApplicationPrivate::URLActionRule
@@ -2439,6 +2461,11 @@ void KApplication::initUrlActionRestrictions()
     else if (urlPath.startsWith("~"))
        urlPath.replace(0, 1, QDir::homeDirPath());
 
+    if (refPath.startsWith("$TMP"))
+       refPath.replace(0, 4, KGlobal::dirs()->saveLocation("tmp"));
+    if (urlPath.startsWith("$TMP"))
+       urlPath.replace(0, 4, KGlobal::dirs()->saveLocation("tmp"));
+
     d->urlActionRestrictions.append(new KApplicationPrivate::URLActionRule
     	( action, refProt, refHost, refPath, urlProt, urlHost, urlPath, bEnabled));
   }
