@@ -19,7 +19,7 @@
   Boston, MA 02111-1307, USA.
 */
 
-// $Id: kconfig.cpp,v 1.66 2002/03/03 21:20:25 lunakl Exp $
+// $Id: kconfig.cpp,v 1.69 2002/08/06 22:46:58 waba Exp $
 
 #include <config.h>
 
@@ -42,7 +42,7 @@
 
 KConfig::KConfig( const QString& fileName,
                  bool bReadOnly, bool bUseKderc, const char *resType )
-  : KConfigBase(), bGroupImmutable(false), bFileImmutable(false), 
+  : KConfigBase(), bGroupImmutable(false), bFileImmutable(false),
     bForceGlobal(false)
 {
   // set the object's read-only status.
@@ -97,9 +97,9 @@ QStringList KConfig::groupList() const
 {
   QStringList retList;
 
-  KEntryMapConstIterator aIt;
+  KEntryMapConstIterator aIt = aEntryMap.begin();
   KEntryMapConstIterator aEnd = aEntryMap.end();
-  for (aIt = aEntryMap.begin(); aIt != aEnd; ++aIt)
+  for (; aIt != aEnd; ++aIt)
   {
     while(aIt.key().mKey.isEmpty())
     {
@@ -115,7 +115,8 @@ QStringList KConfig::groupList() const
 
          if (!aIt.key().bDefault && !(*aIt).bDeleted)
          {
-            retList.append(QString::fromUtf8(group));
+            if (group != "$Version") // Special case!
+               retList.append(QString::fromUtf8(group));
             break; // Grou is non-empty, added, next gropup
          }
          ++aIt;
@@ -129,12 +130,10 @@ QStringList KConfig::groupList() const
 QMap<QString, QString> KConfig::entryMap(const QString &pGroup) const
 {
   QCString pGroup_utf = pGroup.utf8();
-  QMap<QString, QString> tmpMap;
-  KEntryMapConstIterator aIt;
-  KEntry aEntry;
   KEntryKey groupKey( pGroup_utf, 0 );
+  QMap<QString, QString> tmpMap;
 
-  aIt = aEntryMap.find(groupKey);
+  KEntryMapConstIterator aIt = aEntryMap.find(groupKey);
   if (aIt == aEntryMap.end())
      return tmpMap;
   ++aIt; // advance past special group entry marker
@@ -222,9 +221,7 @@ void KConfig::putData(const KEntryKey &_key, const KEntry &_data, bool _checkGro
 
 KEntry KConfig::lookupData(const KEntryKey &_key) const
 {
-  KEntryMapConstIterator aIt;
-
-  aIt = aEntryMap.find(_key);
+  KEntryMapConstIterator aIt = aEntryMap.find(_key);
   if (aIt != aEntryMap.end())
   {
     const KEntry &entry = *aIt;
@@ -264,6 +261,22 @@ void KConfig::setFileWriteMode(int mode)
   backEnd->setFileWriteMode(mode);
 }
 
+void KConfig::checkUpdate(const QString &id, const QString &updateFile)
+{
+  QString oldGroup = group();
+  setGroup("$Version");
+  QString cfg_id = updateFile+":"+id;
+  QStringList ids = readListEntry("update_info");
+  if (!ids.contains(cfg_id))
+  {
+     QStringList args;
+     args << "--check" << updateFile;
+     KApplication::kdeinitExecWait("kconf_update", args);
+     reparseConfiguration();
+  }
+  setGroup(oldGroup);
+}
+
 void KConfig::virtual_hook( int id, void* data )
 { KConfigBase::virtual_hook( id, data ); }
 
