@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kiconloader.cpp,v 1.207.2.1 2003/01/04 08:57:47 dmacvicar Exp $
+ * $Id: kiconloader.cpp,v 1.207.2.3 2003/06/26 07:39:21 staikos Exp $
  *
  * This file is part of the KDE project, module kdecore.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -705,8 +705,10 @@ QPixmap KIconLoader::loadIcon(const QString& _name, KIcon::Group group, int size
 	if(ext != "SVG" && ext != "VGZ")
 	{
 	    img = new QImage(icon.path, ext.latin1());
-	    if (img->isNull())
+	    if (img->isNull()) {
+                delete img;
 		return pix;
+            }
 	}
 #ifdef HAVE_LIBART
 	else
@@ -795,8 +797,15 @@ QPixmap KIconLoader::loadIcon(const QString& _name, KIcon::Group group, int size
         if (pix.mask())
         {
             QBitmap mask = *pix.mask();
-            bitBlt(&mask, x, y,
-                   favIcon.mask() ? const_cast<QBitmap *>(favIcon.mask()) : &favIcon,
+            QBitmap fmask;
+            if (favIcon.mask())
+		fmask = *favIcon.mask();
+	    else {
+		// expensive, but works
+		fmask = favIcon.createHeuristicMask();
+	    }
+		
+            bitBlt(&mask, x, y, &fmask,
                    0, 0, favIcon.width(), favIcon.height(),
                    favIcon.mask() ? Qt::OrROP : Qt::SetROP);
             pix.setMask(mask);
@@ -1120,7 +1129,7 @@ KIconFactory::KIconFactory( const QString& iconName_P, KIcon::Group group_P,
     : iconName( iconName_P ), group( group_P ), size( size_P ), loader( loader_P )
 {
     setAutoDelete( true );
-};
+}
 
 QPixmap* KIconFactory::createPixmap( const QIconSet&, QIconSet::Size, QIconSet::Mode mode_P, QIconSet::State )
     {
