@@ -37,7 +37,7 @@ class KMimeSourceFactory;
  * @ref KGlobal.
  *
  * @author Torben Weis
- * @version $Id: kinstance.h,v 1.22 2002/03/03 21:20:26 lunakl Exp $
+ * @version $Id: kinstance.h,v 1.26 2002/09/28 12:28:47 tjansen Exp $
  */
 class KInstance
 {
@@ -45,21 +45,20 @@ class KInstance
 
  public:
     /**
-     *  Constructor
+     *  Constructor.
      *  @param instanceName the name of the instance
      */
     KInstance( const QCString& instanceName) ;
 
     /**
-     *  Constructor
-     *  @param aboutData data about this instance (see @ref KAboutData)
-     *
+     *  Constructor.
      *  When building a KInstance that is not your KApplication,
      *  make sure that the KAboutData and the KInstance have the same life time.
      *  You have to destroy both, since the instance doesn't own the about data.
      *  Don't build a KAboutData on the stack in this case !
      *  Building a KAboutData on the stack is only ok for usage with
      *  KCmdLineArgs and KApplication (not destroyed until the app exits).
+     *  @param aboutData data about this instance (see @ref KAboutData)
      */
     KInstance( const KAboutData * aboutData );
 
@@ -77,17 +76,20 @@ class KInstance
     virtual ~KInstance();
 
     /**
-     *  Returns the application standard dirs object.
+     * Returns the application standard dirs object.
+     * @return The KStandardDirs of the application.
      */
     KStandardDirs	*dirs() const;
 
     /**
-     *  Returns the general config object.
+     * Returns the general config object ("appnamerc").
+     * @return the KConfig object for the instance.
      */
     KConfig            *config() const;
 
     /**
      *  Returns an iconloader object.
+     * @return the iconloader object.
      */
     KIconLoader	       *iconLoader() const;
 
@@ -101,18 +103,22 @@ class KInstance
     /**
      *  Returns the about data of this instance
      *  Warning, can be 0L
+     * @return the about data of the instance, or 0 if it has 
+     *         not been set yet
      */
     const KAboutData *aboutData() const;
 
     /**
-     * @return the instance name
+     * Returns the name of the instance
+     * @return the instance name, can be null if the KInstance has been 
+     *         created with a null name
      */
     QCString          instanceName() const;
 
     /**
-     * @return the KMimeSourceFactory set as default for this application.
-     *
+     * Returns the @ref KMimeSourceFactory of the instance.
      * Mainly added for API completeness and future extensibility.
+     * @return the KMimeSourceFactory set as default for this application.
      */
     KMimeSourceFactory* mimeSourceFactory () const;
 
@@ -122,6 +128,13 @@ protected:
      */
     KInstance( const KInstance& );
 
+    /**
+     * Set name of default config file.
+     * @param name the name of the default config file
+     * @since 3.1
+     */
+    void setConfigName(const QString &name);
+
 private:
     mutable KStandardDirs       *_dirs;
 
