@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (C) 1997 Torben Weis (weis@kde.org)
  *
- *  $Id: ksock.cpp,v 1.85 2002/03/14 00:35:26 thiago Exp $
+ *  $Id: ksock.cpp,v 1.86 2002/07/31 20:57:27 coolo Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -202,6 +202,8 @@ bool KSocket::connect( const QString& _host, unsigned short int _port, int _time
   return sock >= 0;
 }
 
+// only for doxygen - the define is always true as defined above
+#ifdef KSOCK_NO_BROKEN
 unsigned long KSocket::ipv4_addr()
 {
   unsigned long retval = 0;
@@ -253,6 +255,8 @@ bool KSocket::initSockaddr (ksockaddr_in *server_name, const char *hostname, uns
   return true;
 }
 
+#endif
+
 KSocket::~KSocket()
 {
   // Coolo says delete 0 is ok :) -thiago
@@ -327,7 +331,7 @@ bool KServerSocket::bindAndListen()
   if (d == NULL || d->ks == NULL)
     return false;
 
-  
+
   int ret = d->ks->listen( SOMAXCONN );
   if (ret < 0)
     {
