@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (C) 2000-2002 Thiago Macieira <thiagom@mail.com>
  *
- *  $Id: ksockaddr.cpp,v 1.27 2002/03/03 21:20:26 lunakl Exp $
+ *  $Id: ksockaddr.cpp,v 1.28 2002/08/13 09:27:24 mhunter Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -850,7 +850,7 @@ QString KUnixSocketAddress::pretty() const
 {
   QCString pname = pathname();
   if (pname.isEmpty())
-    return i18n("<empty Unix socket>");
+    return i18n("<empty UNIX socket>");
   return QFile::decodeName(pathname());
 }
 
