@@ -1,6 +1,6 @@
 /****************************************************************************
 
- $Id: kstartupinfo.h,v 1.15 2002/09/16 20:47:12 tjansen Exp $
+ $Id: kstartupinfo.h,v 1.15.2.4 2003/02/25 08:05:13 lunakl Exp $
 
  Copyright (C) 2001 Lubos Lunak        <l.lunak@kde.org>
 
@@ -58,13 +58,38 @@ class KStartupInfoPrivate;
  * @see KStartupInfoData
  *
  * @author Lubos Lunak <l.lunak@kde.org>
- * @version $Id: kstartupinfo.h,v 1.15 2002/09/16 20:47:12 tjansen Exp $
+ * @version $Id: kstartupinfo.h,v 1.15.2.4 2003/02/25 08:05:13 lunakl Exp $
  */
 class KStartupInfo
     : public QObject
     {
     Q_OBJECT
     public:
+	enum {
+	    CleanOnCantDetect		= 1 << 0,
+	    DisableKWinModule		= 1 << 1,
+	    AnnounceSilenceChanges	= 1 << 2
+	    };
+	
+	/**
+	 * Creates an instance that will receive the startup notifications.
+	 * The various flags passed may be
+	 * @li CleanOnCantDetect - when a new unknown window appears, all startup
+	 *     notifications for applications that are not compliant with
+	 *     the startup protocol are removed
+	 * @li DisableKWinModule - KWinModule, which is normally used to detect
+	 *     new windows, is disabled. With this flag, checkStartup() must be
+	 *     called in order to check newly mapped windows
+	 * @li AnnounceSilenceChanges - normally, startup notifications are
+	 *     "removed" when they're silenced, and "recreated" when they're resumed.
+	 *     With this flag, the change is normally announced with gotStartupChange().
+	 *
+	 * @param flags OR-ed combination of flags
+	 * @param parent the parent of this QObject (can be 0 for no parent)
+	 * @param name the name of the QObject (can be 0 for no name)
+	 *
+	 */
+	KStartupInfo( int flags, QObject* parent = NULL, const char* name = NULL );
 	/**
 	 * Creates an instance that will receive the startup notifications.
 	 *
@@ -73,6 +98,8 @@ class KStartupInfo
 	 *  with the app startup protocol
 	 * @param parent the parent of this QObject (can be 0 for no parent)
 	 * @param name the name of the QObject (can be 0 for no name)
+	 *
+	 * @obsolete
 	 */
         KStartupInfo( bool clean_on_cantdetect, QObject* parent = 0, const char* name = 0 );
         virtual ~KStartupInfo();
@@ -183,7 +210,8 @@ class KStartupInfo
         enum startup_t { NoMatch, Match, CantDetect };
 	/**
 	 * Checks if the given windows matches any existing startup notification. If yes,
-	 * the startup notification is removed.
+	 * the startup notification is removed. Prevents emitting gotRemoveStartup()
+         * for the window if the window matches.
 	 * @param w the window id to check
 	 * @return the result of the operation
 	 */
@@ -191,6 +219,7 @@ class KStartupInfo
 	/**
 	 * Checks if the given windows matches any existing startup notification, and
 	 * if yes, returns the identification in id, and removes the startup notification.
+         * Prevents emitting gotRemoveStartup() for the window if the window matches.
 	 * @param w the window id to check
 	 * @param id if found, the id of the startup notification will be written here
 	 * @return the result of the operation
@@ -199,7 +228,8 @@ class KStartupInfo
 	/**
 	 * Checks if the given windows matches any existing startup notification, and
 	 * if yes, returns the notification data in data, and removes the startup
-	 * notification.
+	 * notification. Prevents emitting gotRemoveStartup() for the window
+         * if the window matches.
 	 * @param w the window id to check
 	 * @param data if found, the data of the startup notification will be written here
 	 * @return the result of the operation
@@ -208,7 +238,8 @@ class KStartupInfo
 	/**
 	 * Checks if the given windows matches any existing startup notification, and
 	 * if yes, returns the identification in id and notification data in data,
-	 * and removes the startup notification.
+	 * and removes the startup notification. Prevents emitting gotRemoveStartup()
+         * for the window if the window matches.
 	 * @param w the window id to check
 	 * @param id if found, the id of the startup notification will be written here
 	 * @param data if found, the data of the startup notification will be written here
@@ -266,6 +297,7 @@ class KStartupInfo
         void window_added( WId w );
 	void slot_window_added( WId w );
     private:
+        void init( int flags );
         friend class KStartupInfoPrivate;
         void got_startup_info( const QString& msg_P, bool update_only_P );
         void got_remove_startup_info( const QString& msg_P );
@@ -286,7 +318,7 @@ class KStartupInfo
         static QCString get_window_hostname( WId w_P );
         void startups_cleanup_internal( bool age_P );
         void clean_all_noncompliant();
-        bool clean_on_cantdetect;
+        bool clean_on_cantdetect_; // KDE4 remove unused
         unsigned int timeout;
         KStartupInfoPrivate* d;
     };
@@ -303,7 +335,7 @@ class KStartupInfoIdPrivate;
  * @see KStartupInfoData
  *
  * @author Lubos Lunak <l.lunak@kde.org>
- * @version $Id: kstartupinfo.h,v 1.15 2002/09/16 20:47:12 tjansen Exp $
+ * @version $Id: kstartupinfo.h,v 1.15.2.4 2003/02/25 08:05:13 lunakl Exp $
  */
 class KStartupInfoId
     {
@@ -371,7 +403,7 @@ class KStartupInfoDataPrivate;
  * @see KStartupInfoId
  *
  * @author Lubos Lunak <l.lunak@kde.org>
- * @version $Id: kstartupinfo.h,v 1.15 2002/09/16 20:47:12 tjansen Exp $
+ * @version $Id: kstartupinfo.h,v 1.15.2.4 2003/02/25 08:05:13 lunakl Exp $
  */
 class KStartupInfoData
     {
@@ -481,10 +513,27 @@ class KStartupInfoData
 	 * @return the hostname
 	 */
         const QCString& hostname() const;
+	
+	enum TriState { Yes, No, Unknown };
+	
+	/**
+	 * Sets whether the visual feedback for this startup notification
+	 * should be silenced (temporarily suspended).
+	 * @since 3.1.1
+	 */
+	void setSilent( TriState state );
+	
+	/**
+	 * Return the silence status for the startup notification.
+	 * @return KStartupInfoData::Yes if visual feedback is silenced
+	 * @since 3.1.1
+	 */
+	TriState silent() const;
+
 	/**
 	 * Updates the notification data from the given data. Some data, such as the desktop
 	 * or the name, won't be rewritten if already set.
-	 * @param data the data t update
+	 * @param data the data to update
 	 */
         void update( const KStartupInfoData& data );
 	/**
