@@ -23,7 +23,7 @@
 #include "cupsdpage.h"
 
 class QDirLineEdit;
-class KIntNumInput;
+class SizeWidget;
 class QComboBox;
 
 class CupsdLogPage : public CupsdPage
@@ -38,7 +38,7 @@ public:
 private:
 	QDirLineEdit	*accesslog_, *errorlog_, *pagelog_;
 	QComboBox	*loglevel_;
-	KIntNumInput	*maxlogsize_;
+	SizeWidget	*maxlogsize_;
 };
 
 #endif
