@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kcupsprinterimpl.cpp,v 1.15 2002/07/01 22:48:16 gioele Exp $
+ *  $Id: kcupsprinterimpl.cpp,v 1.15.2.1 2003/05/20 06:10:41 staikos Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -53,7 +53,7 @@ bool KCupsPrinterImpl::setupCommand(QString& cmd, KPrinter *printer)
 	cmd = QString::fromLatin1("cupsdoprint -P %1 -J %3 -H %2").arg(quote(printer->printerName())).arg(quote(hoststr)).arg(quote(printer->docName()));
 	if (!CupsInfos::self()->login().isEmpty())
 	{
-		QString	userstr(CupsInfos::self()->realLogin());
+		QString	userstr(CupsInfos::self()->login());
 		if (!CupsInfos::self()->password().isEmpty())
 			userstr += (":" + CupsInfos::self()->password());
 		cmd.append(" -U ").append(quote(userstr));
