@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmwippselect.cpp,v 1.5 2002/03/19 10:56:59 goffioul Exp $
+ *  $Id: kmwippselect.cpp,v 1.8 2002/08/14 12:36:27 faure Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -35,7 +35,7 @@ KMWIppSelect::KMWIppSelect(QWidget *parent, const char *name)
 : KMWizardPage(parent,name)
 {
 	m_ID = KMWizard::IPPSelect;
-	m_title = i18n("Remote IPP printer selection");
+	m_title = i18n("Remote IPP Printer Selection");
 	m_nextpage = KMWizard::Driver;
 
 	m_list = new KListBox(this);
@@ -48,7 +48,7 @@ bool KMWIppSelect::isValid(QString& msg)
 {
 	if (m_list->currentItem() == -1)
 	{
-		msg = i18n("You must select a printer !");
+		msg = i18n("You must select a printer!");
 		return false;
 	}
 	return true;
@@ -106,5 +106,5 @@ void KMWIppSelect::updatePrinter(KMPrinter *p)
 	path.prepend("/printers/");
 	url.setPath(path);
 	p->setDevice(url);
-kdDebug() << url.url() << endl;
+kdDebug(500) << url.url() << endl;
 }
