@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmfactory.cpp,v 1.33 2002/06/18 10:14:56 faure Exp $
+ *  $Id: kmfactory.cpp,v 1.33.2.1 2003/04/07 13:52:59 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -31,6 +31,7 @@
 
 #include <qdir.h>
 #include <qfile.h>
+#include <qsettings.h>
 
 #include <klibloader.h>
 #include <kconfig.h>
@@ -101,6 +102,13 @@ KMFactory::KMFactory()
 	qt_generate_epsf( false );
 #endif
 
+	// By default, embed PS fonts
+	bool ok = false;
+	QSettings settings;
+	settings.readBoolEntry( "/qt/embedFonts", true, &ok );
+	if ( !ok )
+		settings.writeEntry( "/qt/embedFonts", true );
+
 	KGlobal::iconLoader()->addAppDir("kdeprint");
 
 	// create DCOP signal connection
