@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmfactory.h,v 1.15 2002/03/02 18:35:39 future Exp $
+ *  $Id: kmfactory.h,v 1.18 2002/06/18 10:14:56 faure Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -42,23 +42,24 @@ class KLibFactory;
 class KConfig;
 class KPReloadObject;
 
-struct PluginInfo
-{
-	QString		name;
-	QString		comment;
-	QStringList	detectUris;
-	int		detectPrecedence;
-	QStringList	mimeTypes;
-	QString		primaryMimeType;
-};
-
 class KMFactory : public QObject, public DCOPObject
 {
 	Q_OBJECT
 	K_DCOP
 
 public:
+	struct PluginInfo
+	{
+		QString		name;
+		QString		comment;
+		QStringList	detectUris;
+		int		detectPrecedence;
+		QStringList	mimeTypes;
+		QString		primaryMimeType;
+	};
+
 	static KMFactory* self();
+        static bool exists();
 	static void release();
 
 	KMFactory();
@@ -71,7 +72,7 @@ public:
 	KMSpecialManager* specialManager();
 	KXmlCommandManager* commandManager();
 	KPrinterImpl* printerImplementation();
-	KConfig* printConfig();
+	KConfig* printConfig(const QString& group = QString::null);
 	QString printSystem();
 	QValueList<PluginInfo> pluginList();
 	PluginInfo pluginInfo(const QString& name);
