@@ -18,21 +18,20 @@
  **/
 
 #include "kpfilterpage.h"
-#include "kprintfilter.h"
 #include "kmfactory.h"
 #include "kxmlcommand.h"
 
 #include <qpushbutton.h>
 #include <qheader.h>
-#include <qinputdialog.h>
 #include <qtooltip.h>
 #include <qlayout.h>
-#include <qtextview.h>
 #include <klistview.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
+#include <kactivelabel.h>
 #include <kdebug.h>
+#include <kapplication.h>
 
 KPFilterPage::KPFilterPage(QWidget *parent, const char *name)
 : KPrintDialogPage(parent,name)
@@ -71,8 +70,11 @@ KPFilterPage::KPFilterPage(QWidget *parent, const char *name)
 	connect(m_configure,SIGNAL(clicked()),SLOT(slotConfigureClicked()));
 	connect(m_view,SIGNAL(doubleClicked(QListViewItem*)),SLOT(slotConfigureClicked()));
 
-	m_info = new QTextView(this);
-	m_info->setPaper(colorGroup().background());
+	m_info = new KActiveLabel(this);
+	m_info->setVScrollBarMode( QScrollView::Auto );
+	m_info->setHScrollBarMode( QScrollView::Auto );
+	m_info->setFrameStyle( QFrame::Panel|QFrame::Sunken );
+	m_info->setMinimumSize( QSize( 240, 100 ) );
 
 	QGridLayout	*l1 = new QGridLayout(this, 2, 2, 0, 10);
 	l1->setColStretch(0, 1);
@@ -109,25 +111,12 @@ void KPFilterPage::updateButton()
 
 void KPFilterPage::slotAddClicked()
 {
-	if (m_filters.count() == 0)
-	{
-		m_filters = KXmlCommandManager::self()->commandListWithDescription();
-	}
-	QStringList	l;
-	for (int i=0;i<(int)m_filters.count();i+=2)
-		if (m_activefilters.find(m_filters[i]) == 0)
-			l.append(m_filters[i+1]);
-	if (l.count() == 0)
-	{
-		KMessageBox::error(this,i18n("No more available filters."));
-		return;
-	}
 	bool	ok;
-	QString	choice = QInputDialog::getItem(i18n("Add Filter"),i18n("Select the filter to add"),l,0,false,&ok,this);
+	QString choice = KXmlCommandManager::self()->selectCommand( this );
+	ok = !choice.isEmpty();
 	if (ok)
 	{
-		int		index = m_filters.findIndex(choice)-1;
-		KXmlCommand	*cmd = KXmlCommandManager::self()->loadCommand(m_filters[index]);
+		KXmlCommand	*cmd = KXmlCommandManager::self()->loadCommand(choice);
 		QStringList	filters = activeList();
 		int		pos = KXmlCommandManager::self()->insertCommand(filters, cmd->name());
 		QListViewItem	*prev(0);
@@ -138,7 +127,7 @@ void KPFilterPage::slotAddClicked()
 				prev = prev->nextSibling();
 		}
 		m_activefilters.insert(cmd->name(), cmd);
-		QListViewItem	*item = new QListViewItem(m_view, prev, choice, cmd->name());
+		QListViewItem	*item = new QListViewItem(m_view, prev, cmd->description(), cmd->name());
 		item->setPixmap(0, SmallIcon("filter"));
 		checkFilterChain();
 	}
@@ -319,6 +308,8 @@ void KPFilterPage::updateInfo()
 		txt.append(templ.arg(i18n("Requirements")).arg(f->requirements().join(", ")));
 		txt.append(templ.arg(i18n("Input")).arg(f->inputMimeTypes().join(", ")));
 		txt.append(templ.arg(i18n("Output")).arg(f->mimeType()));
+		if ( !f->comment().isEmpty() )
+			txt.append( "<br>" ).append( f->comment() );
 	}
 	m_info->setText(txt);
 }
