@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kpqtpage.cpp,v 1.16 2002/02/13 22:49:50 goffioul Exp $
+ *  $Id: kpqtpage.cpp,v 1.22 2002/09/30 14:42:09 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -23,6 +23,7 @@
 #include "kprinter.h"
 #include "kxmlcommand.h"
 #include "driver.h"
+#include "util.h"
 
 #include <qcombobox.h>
 #include <qbuttongroup.h>
@@ -47,51 +48,6 @@
 
 void radioCursor(QButtonGroup*);
 
-static struct pagesizestruct
-{
-	const char*	text;
-	int 	ID;
-} page_sizes[] =
-{
-	{ "A0", KPrinter::A0 },
-	{ "A1", KPrinter::A1 },
-	{ "A2", KPrinter::A2 },
-	{ "A3", KPrinter::A3 },
-	{ "A4", KPrinter::A4 },
-	{ "A5", KPrinter::A5 },
-	{ "A6", KPrinter::A6 },
-	{ "A7", KPrinter::A7 },
-	{ "A8", KPrinter::A8 },
-	{ "A9", KPrinter::A9 },
-	{ "B1", KPrinter::B1 },
-	{ "B10", KPrinter::B10 },
-	{ "B2", KPrinter::B2 },
-	{ "B3", KPrinter::B3 },
-	{ "B4", KPrinter::B4 },
-	{ "B5", KPrinter::B5 },
-	{ "B6", KPrinter::B6 },
-	{ "B7", KPrinter::B7 },
-	{ "B8", KPrinter::B8 },
-	{ "B9", KPrinter::B9 },
-	{ I18N_NOOP("Envelope C5"), KPrinter::C5E },
-	{ I18N_NOOP("Envelope DL"), KPrinter::DLE },
-	{ I18N_NOOP("Envelope US #10"), KPrinter::Comm10E },
-	{ I18N_NOOP("Executive"), KPrinter::Executive },
-	{ I18N_NOOP("Folio"), KPrinter::Folio },
-	{ I18N_NOOP("Ledger"), KPrinter::Ledger },
-	{ I18N_NOOP("Tabloid"), KPrinter::Tabloid },
-	{ I18N_NOOP("US Legal"), KPrinter::Legal },
-	{ I18N_NOOP("US Letter"), KPrinter::Letter }
-};
-
-int findIndex(int ID)
-{
-	for (int i=0; i<KPrinter::NPageSize-1; i++)
-		if (page_sizes[i].ID == ID)
-			return i;
-	return 4;
-}
-
 //*****************************************************************************************************
 
 KPQtPage::KPQtPage(QWidget *parent, const char *name)
@@ -120,7 +76,7 @@ void KPQtPage::init()
 	m_pagesizelabel->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 	m_pagesizelabel->setBuddy(m_pagesize);
 	m_orientbox = new QButtonGroup(0, Qt::Vertical, i18n("Orientation"), this);
-	m_colorbox = new QButtonGroup(0, Qt::Vertical, i18n("Color mode"), this);
+	m_colorbox = new QButtonGroup(0, Qt::Vertical, i18n("Color Mode"), this);
 	QRadioButton	*m_portrait = new QRadioButton(i18n("&Portrait"), m_orientbox);
 	QRadioButton	*m_landscape = new QRadioButton(i18n("&Landscape"), m_orientbox);
 	m_orientpix = new QLabel(m_orientbox);
@@ -129,11 +85,11 @@ void KPQtPage::init()
 	QRadioButton	*m_grayscale = new QRadioButton(i18n("&Grayscale"), m_colorbox);
 	m_colorpix = new QLabel(m_colorbox);
 	m_colorpix->setAlignment(Qt::AlignCenter);
-	m_nupbox = new QButtonGroup(0, Qt::Vertical, i18n("Pages per sheet"), this);
+	m_nupbox = new QButtonGroup(0, Qt::Vertical, i18n("Pages per Sheet"), this);
 	QRadioButton	*m_nup1 = new QRadioButton("&1", m_nupbox);
 	QRadioButton	*m_nup2 = new QRadioButton("&2", m_nupbox);
 	QRadioButton	*m_nup4 = new QRadioButton("&4", m_nupbox);
-	QRadioButton	*m_nupother = new QRadioButton(i18n("&Other"), m_nupbox);
+	QRadioButton	*m_nupother = new QRadioButton(i18n("Ot&her"), m_nupbox);
 	m_nuppix = new QLabel(m_nupbox);
 	m_nuppix->setAlignment(Qt::AlignCenter);
 
@@ -174,7 +130,8 @@ void KPQtPage::init()
 
 	if (!KXmlCommandManager::self()->checkCommand("psnup"))
 		m_nupbox->setEnabled(false);
-	if (KPrinter::applicationType() != KPrinter::Dialog)
+	if (KPrinter::applicationType() != KPrinter::Dialog
+			&& KPrinter::applicationType() >= 0 )
 	{
 		m_orientbox->setEnabled(false);
 		m_colorbox->setEnabled(false);
@@ -267,6 +224,11 @@ void KPQtPage::setOptions(const QMap<QString,QString>& opts)
 	}
 	m_nupbox->setButton(ID);
 	slotNupChanged(ID);
+	
+	if ( m_orientbox->isEnabled() )
+		m_orientbox->setDisabled( opts[ "kde-orientation-fixed" ] == "1" );
+	if ( m_pagesize->isEnabled() )
+		m_pagesize->setDisabled( opts[ "kde-pagesize-fixed" ] == "1" );
 }
 
 void KPQtPage::getOptions(QMap<QString,QString>& opts, bool incldef)
