@@ -24,11 +24,13 @@ class KPReloadObject
 {
 friend class KMFactory;
 public:
-	KPReloadObject();
+	KPReloadObject(bool priority = false);
 	virtual ~KPReloadObject();
 
 protected:
 	virtual void reload() = 0;
+	virtual void aboutToReload() {}
+	virtual void configChanged() {}
 };
 
 #endif
