@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kprinter.h,v 1.24 2002/02/25 16:33:08 goffioul Exp $
+ *  $Id: kprinter.h,v 1.28 2002/08/23 12:05:35 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -460,6 +460,11 @@ public:
 	 * @see realPageSize()
 	 */
 	void setRealPageSize(QSize p);
+
+	void setRealDrawableArea( const QRect& r );
+	QRect realDrawableArea() const;
+	void margins( uint *top, uint *left, uint *bottom, uint *right ) const;
+
 	/**
 	 * Returns the page list to be printed, correpsonding to the options selected by the user. This
 	 * takes into account collate, page order, page set, ranges, ... This is useful when the
@@ -492,6 +497,21 @@ public:
 	 * @see setPreviewOnly()
 	 */
 	bool previewOnly() const;
+	/**
+	 * Set the resolution of the current KPrinter object. The resolution is given in DPI. This
+	 * resolution mainly affects the accuracy for object positionning on the paint device, and
+	 * does not influence the real resolution that will be used by the printer (this should be
+	 * set in the driver settings). The resolution is usually defined in the constructor.
+	 * @param dpi the resolution in DPI
+	 * @see KPrinter(), resolution()
+	 */
+	void setResolution(int dpi);
+	/**
+	 * Resturns the resolution of the current KPrinter object. The resolution is given in DPI.
+	 * @returns resolution in DPI
+	 * @see setResolution(), KPrinter()
+	 */
+	int resolution() const;
 
 	/**
 	 * For internal use only.
@@ -682,6 +702,21 @@ public:
 	 * @see setDocFileName()
 	 */
 	QString docFileName() const;
+	/**
+	 * Set the default document directory. This directory will be used as
+	 * the default location for any output file. If not set, $HOME directory
+	 * is used instead.
+	 * @param dir the new default output directory
+	 * @see docDirectory()
+	 */
+	void setDocDirectory( const QString& dir );
+	/**
+	 * Get the default document directory, that is the directory used for
+	 * any output file. By default, it is the $HOME directory.
+	 * @returns the default output directory
+	 * @see setDocDirectory
+	 */
+	QString docDirectory() const;
 
 protected:
 	virtual bool cmd(int, QPainter*, QPDevCmdParam*);
@@ -693,6 +728,7 @@ protected:
 	void finishPrinting();
 	void reload();
 	void init(bool restore = true, QPrinter::PrinterMode m = QPrinter::ScreenResolution);
+	bool doPreview(const QString& file);
 
 protected:
 	KPrinterPrivate		*d;
