@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kprinterimpl.h,v 1.13 2002/05/15 13:58:33 goffioul Exp $
+ *  $Id: kprinterimpl.h,v 1.13.2.1 2003/02/09 14:09:59 rnolden Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@
 #include <qobject.h>
 #include <qstringlist.h>
 #include <qmap.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class KPrinter;
 class KMPrinter;
