@@ -33,7 +33,7 @@ public:
 	int actions();
 
 protected:
-	bool listJobs(const QString&, JobType);
+	bool listJobs(const QString&, JobType, int = 0);
 	LpcHelper* lpcHelper();
 	bool sendCommandSystemJob(const QPtrList<KMJob>&, int, const QString& = QString::null);
 
