@@ -26,6 +26,8 @@
 #include "kmconfigpreview.h"
 #include "kmconfigcommand.h"
 #include "kmconfigfilter.h"
+#include "kmconfigfonts.h"
+#include "kmconfigjobs.h"
 
 #include <qlayout.h>
 #include <klocale.h>
@@ -33,13 +35,15 @@
 #include <kconfig.h>
 
 KMConfigDialog::KMConfigDialog(QWidget *parent, const char *name)
-: KDialogBase(KDialogBase::IconList,i18n("KDE Print Configuration"),KDialogBase::Ok|KDialogBase::Cancel,KDialogBase::Ok,parent,name,true,false)
+: KDialogBase(IconList,i18n("KDE Print Configuration"),Ok|Cancel,Ok,parent,name,true,true)
 {
 	m_pages.setAutoDelete(false);
 	addConfigPage(new KMConfigGeneral(this));
 	addConfigPage(new KMConfigPreview(this));
+	addConfigPage(new KMConfigFonts(this));
 	addConfigPage(new KMConfigCommand(this));
 	addConfigPage(new KMConfigFilter(this));
+	addConfigPage(new KMConfigJobs(this));
 	KMFactory::self()->uiManager()->setupConfigDialog(this);
 
 	// initialize pages
@@ -56,7 +60,13 @@ void KMConfigDialog::addConfigPage(KMConfigPage *page)
 {
 	if (page)
 	{
-		QFrame	*frame = addPage(page->pageName(),page->pageHeader(),DesktopIcon(page->pagePixmap()));
+		QPixmap icon = KGlobal::instance()->iconLoader()->loadIcon(
+		                                                           page->pagePixmap(),
+		                                                           KIcon::NoGroup,
+                        	                                           KIcon::SizeMedium
+		                                                          );
+
+		QFrame	*frame = addPage(page->pageName(),page->pageHeader(),icon);
 		page->reparent(frame,QPoint(0,0));
 		QVBoxLayout	*lay = new QVBoxLayout(frame, 0, 0);
 		lay->addWidget(page);
