@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmiconview.cpp,v 1.8 2001/10/05 15:11:36 goffioul Exp $
+ *  $Id: kmiconview.cpp,v 1.12 2002/08/30 09:50:27 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -24,6 +24,7 @@
 
 #include <qpainter.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 
 KMIconViewItem::KMIconViewItem(QIconView *parent, KMPrinter *p)
 : QIconViewItem(parent)
@@ -31,6 +32,7 @@ KMIconViewItem::KMIconViewItem(QIconView *parent, KMPrinter *p)
 	m_state = 0;
 	m_mode = parent->itemTextPos();
 	m_pixmap = QString::null;
+	m_isclass = false;
 	updatePrinter(p, m_mode);
 }
 
@@ -46,38 +48,75 @@ void KMIconViewItem::paintItem(QPainter *p, const QColorGroup& cg)
 	QIconViewItem::paintItem(p,cg);
 }
 
-void KMIconViewItem::updatePrinter(KMPrinter *p, int mode)
+void KMIconViewItem::calcRect(const QString&)
 {
-	// if p is NULL, just keep the previous printer settings
-	if (p) m_printer = p;
+	QRect	ir(rect()), pr, tr;
 
-	bool	update(false);
-	if (m_printer)
+	// pixmap rect
+	pr.setWidth(pixmap()->width());
+	pr.setHeight(pixmap()->height());
+
+	// text rect
+	QFont	f(iconView()->font());
+	if (m_state & 0x1) f.setBold(true);
+	if (m_state & 0x2) f.setItalic(true);
+	QFontMetrics	fm(f);
+	if (m_mode == QIconView::Bottom)
+		tr = fm.boundingRect(0, 0, iconView()->maxItemWidth(), 0xFFFFFF, AlignHCenter|AlignTop|WordBreak|BreakAnywhere, text());
+	else
+		tr = fm.boundingRect(0, 0, 0xFFFFFF, 0xFFFFFF, AlignLeft|AlignTop, text()+"X");
+
+	// item rect
+	if (m_mode == QIconView::Bottom)
 	{
-		int	oldstate = m_state;
-		m_state = ((m_printer->isHardDefault() ? 0x1 : 0x0) | (m_printer->ownSoftDefault() ? 0x2 : 0x0) | (m_printer->isValid() ? 0x4 : 0x0));
-		update = (oldstate != m_state);
-		if (m_printer->name() != text() || update)
-		{
-			setText(m_printer->name());
-		}
-		if (mode != m_mode || ((oldstate&0x4) != (m_state&0x4)) || m_printer->pixmap() != m_pixmap)
-		{
-			int	iconstate = (m_printer->isValid() ? (int)KIcon::DefaultState : (int)KIcon::LockOverlay);
-			m_pixmap = m_printer->pixmap();
-			m_mode = mode;
-			if (mode == QIconView::Bottom)
-				setPixmap(DesktopIcon(m_pixmap, 0, iconstate));
-			else
-				setPixmap(SmallIcon(m_pixmap, 0, iconstate));
-		}
-		setKey(QString::fromLatin1("%1_%2").arg((m_printer->isSpecial() ? "special" : (m_printer->isClass(false) ? "class" : "printer"))).arg(m_printer->name()));
+		ir.setHeight(pr.height() + tr.height() + 15);
+		ir.setWidth(QMAX(pr.width(), tr.width()) + 10);
+		pr = QRect((ir.width()-pr.width())/2, 5, pr.width(), pr.height());
+		tr = QRect((ir.width()-tr.width())/2, 10+pr.height(), tr.width(), tr.height());
 	}
 	else
 	{
-		setKey(QString::fromLatin1("aaa"));
+		ir.setHeight(QMAX(pr.height(), tr.height()) + 4);
+		ir.setWidth(pr.width() + tr.width() + 6);
+		pr = QRect(2, (ir.height()-pr.height())/2, pr.width(), pr.height());
+		tr = QRect(4+pr.width(), (ir.height()-tr.height())/2, tr.width(), tr.height());
 	}
-	if (update) repaint();
+
+	// set rects
+	setItemRect(ir);
+	setTextRect(tr);
+	setPixmapRect(pr);
+}
+
+void KMIconViewItem::updatePrinter(KMPrinter *p, int mode)
+{
+	bool	update(false);
+	int	oldstate = m_state;
+	if (p)
+	{
+		m_state = ((p->isHardDefault() ? 0x1 : 0x0) | (p->ownSoftDefault() ? 0x2 : 0x0) | (p->isValid() ? 0x4 : 0x0));
+		update = (oldstate != m_state);
+		if (p->name() != text() || update)
+		{
+			setText(QString::null);
+			setText(p->name());
+		}
+		setKey(QString::fromLatin1("%1_%2").arg((p->isSpecial() ? "special" : (p->isClass(false) ? "class" : "printer"))).arg(p->name()));
+		m_isclass = p->isClass(false);
+	}
+	if (mode != m_mode || ((oldstate&0x4) != (m_state&0x4)) || (p && p->pixmap() != m_pixmap))
+	{
+		int	iconstate = (m_state&0x4 ? (int)KIcon::DefaultState : (int)KIcon::LockOverlay);
+		if (p)
+			m_pixmap = p->pixmap();
+		m_mode = mode;
+		if (m_mode == QIconView::Bottom)
+			setPixmap(DesktopIcon(m_pixmap, 0, iconstate));
+		else
+			setPixmap(SmallIcon(m_pixmap, 0, iconstate));
+	}
+	//if (update)
+	//	repaint();
 	setDiscarded(false);
 }
 
@@ -92,7 +131,7 @@ KMIconView::KMIconView(QWidget *parent, const char *name)
 	m_items.setAutoDelete(false);
 	setViewMode(KMIconView::Big);
 
-	connect(this,SIGNAL(rightButtonClicked(QIconViewItem*,const QPoint&)),SLOT(slotRightButtonClicked(QIconViewItem*,const QPoint&)));
+	connect(this,SIGNAL(contextMenuRequested(QIconViewItem*,const QPoint&)),SLOT(slotRightButtonClicked(QIconViewItem*,const QPoint&)));
 	connect(this,SIGNAL(selectionChanged()),SLOT(slotSelectionChanged()));
 }
 
@@ -106,8 +145,8 @@ KMIconViewItem* KMIconView::findItem(KMPrinter *p)
 	{
 		QPtrListIterator<KMIconViewItem>	it(m_items);
 		for (;it.current();++it)
-			if (it.current()->printer() && it.current()->printer()->name() == p->name()
-			    && it.current()->printer()->isClass() == p->isClass())
+			if (it.current()->text() == p->name()
+			    && it.current()->isClass() == p->isClass())
 				return it.current();
 	}
 	return 0;
@@ -167,29 +206,34 @@ void KMIconView::setViewMode(ViewMode m)
 	setArrangement((big ? QIconView::LeftToRight : QIconView::TopToBottom));
 	setItemTextPos((QIconView::ItemTextPos)mode);
 	//setGridX((big ? 60 : -1));
-	setWordWrapIconText(big);
+	setWordWrapIconText(true);
 }
 
 void KMIconView::slotRightButtonClicked(QIconViewItem *item, const QPoint& p)
 {
-	KMIconViewItem	*citem = dynamic_cast<KMIconViewItem*>(item);
-	emit rightButtonClicked((citem ? citem->printer() : NULL),p);
+	emit rightButtonClicked(item ? item->text() : QString::null, p);
 }
 
 void KMIconView::slotSelectionChanged()
 {
-	KMIconViewItem	*item = (KMIconViewItem*)currentItem();
-	emit printerSelected((item && !item->isDiscarded() ? item->printer() : NULL));
+	KMIconViewItem	*item = static_cast<KMIconViewItem*>(currentItem());
+	emit printerSelected((item && !item->isDiscarded() && item->isSelected() ? item->text() : QString::null));
+}
+
+void KMIconView::setPrinter(const QString& prname)
+{
+	QPtrListIterator<KMIconViewItem>	it(m_items);
+	for (; it.current(); ++it)
+		if (it.current()->text() == prname)
+		{
+			setSelected(it.current(), true);
+			break;
+		}
 }
 
 void KMIconView::setPrinter(KMPrinter *p)
 {
-	QPtrListIterator<KMIconViewItem>	it(m_items);
-	for (;it.current();++it)
-		if (it.current()->printer() == p)
-		{
-			setSelected(it.current(),true);
-			break;
-		}
+	setPrinter(p ? p->name() : QString::null);
 }
+
 #include "kmiconview.moc"
