@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmiconview.h,v 1.4 2001/09/23 12:19:16 mueller Exp $
+ *  $Id: kmiconview.h,v 1.6 2002/04/12 09:52:47 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -33,17 +33,18 @@ class KMIconViewItem : public QIconViewItem, public KMObject
 {
 public:
 	KMIconViewItem(QIconView *parent, KMPrinter *p);
-	KMPrinter* printer() const	{ return m_printer; }
 	void updatePrinter(KMPrinter *printer = 0, int mode = QIconView::Bottom);
+	bool isClass() const	{ return m_isclass; }
 
 protected:
 	virtual void paintItem(QPainter*, const QColorGroup&);
+	virtual void calcRect(const QString& text_ = QString::null);
 
 private:
-	KMPrinter	*m_printer;
 	int		m_mode;
 	QString		m_pixmap;
 	char		m_state;
+	bool		m_isclass;
 };
 
 class KMIconView : public KIconView
@@ -56,12 +57,13 @@ public:
 	~KMIconView();
 
 	void setPrinterList(QPtrList<KMPrinter> *list);
+	void setPrinter(const QString&);
 	void setPrinter(KMPrinter*);
 	void setViewMode(ViewMode);
 
 signals:
-	void rightButtonClicked(KMPrinter*, const QPoint&);
-	void printerSelected(KMPrinter*);
+	void rightButtonClicked(const QString&, const QPoint&);
+	void printerSelected(const QString&);
 
 protected slots:
 	void slotRightButtonClicked(QIconViewItem*, const QPoint&);
