@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kminfopage.cpp,v 1.10.6.1 2003/01/14 14:34:31 goffioul Exp $
+ *  $Id: kminfopage.cpp,v 1.10.6.2 2003/02/19 18:34:30 mueller Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -43,7 +43,7 @@ KMInfoPage::KMInfoPage(QWidget *parent, const char *name)
 	m_model = new QLabel(this);
 	m_uri = new QLabel(this);
 	m_device = new QLabel(this);
-	QLabel	*m_loclabel = new QLabel(i18n("Location:"), this);
+	QLabel	*m_loclabel = new QLabel(i18n("Phys. Location", "Location:"), this);
 	m_loclabel->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 	QLabel	*m_desclabel = new QLabel(i18n("Description:"), this);
 	m_desclabel->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
