@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kminstancepage.cpp,v 1.21 2002/02/20 14:40:41 goffioul Exp $
+ *  $Id: kminstancepage.cpp,v 1.26 2002/09/17 20:33:09 binner Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -29,11 +29,11 @@
 #include "kmtimer.h"
 
 #include <qlayout.h>
-#include <qinputdialog.h>
 #include <qregexp.h>
 #include <qwhatsthis.h>
 #include <qpushbutton.h>
 #include <kmessagebox.h>
+#include <klineeditdlg.h>
 #include <klistbox.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -86,14 +86,14 @@ void KMInstancePage::addButton(const QString& txt, const QString& pixmap, const
 
 void KMInstancePage::initActions()
 {
-	addButton(i18n("New"), "filenew", SLOT(slotNew()));
-	addButton(i18n("Copy"), "editcopy", SLOT(slotCopy()));
+	addButton(i18n("New..."), "filenew", SLOT(slotNew()));
+	addButton(i18n("Copy..."), "editcopy", SLOT(slotCopy()));
 	addButton(i18n("Remove"), "edittrash", SLOT(slotRemove()));
 	m_buttons.append(0);
-	addButton(i18n("Set as default"), "exec", SLOT(slotDefault()));
-	addButton(i18n("Settings"), "configure", SLOT(slotSettings()));
+	addButton(i18n("Set as Default"), "exec", SLOT(slotDefault()));
+	addButton(i18n("Settings..."), "configure", SLOT(slotSettings()));
 	m_buttons.append(0);
-	addButton(i18n("Test"), "fileprint", SLOT(slotTest()));
+	addButton(i18n("Test..."), "fileprint", SLOT(slotTest()));
 }
 
 void KMInstancePage::setPrinter(KMPrinter *p)
@@ -102,7 +102,8 @@ void KMInstancePage::setPrinter(KMPrinter *p)
 
 	m_view->clear();
 	m_printer = p;
-	bool	ok = (p && !p->isSpecial());
+	//bool	ok = (p && !p->isSpecial());
+	bool	ok = (p != 0);
 	if (ok)
 	{
 		QPtrList<KMPrinter>	list;
@@ -135,8 +136,8 @@ void KMInstancePage::slotNew()
 	KMTimer::self()->hold();
 
 	bool	ok(false);
-	QString	name = QInputDialog::getText(i18n("Instance name"),i18n("Enter name for new instance (leave untouched for default):"),
-			                     QLineEdit::Normal,i18n("(Default)"),&ok,this);
+	QString	name = KLineEditDlg::getText(i18n("Instance Name"),i18n("Enter name for new instance (leave untouched for default):"),
+			                     i18n("(Default)"),&ok,this);
 	if (ok)
 	{
 		if (name.find(QRegExp("\\s")) != -1)
@@ -180,8 +181,8 @@ void KMInstancePage::slotCopy()
 	if (!src.isEmpty())
 	{
 		bool	ok(false);
-		QString	name = QInputDialog::getText(i18n("Instance name"),i18n("Enter name for new instance (leave untouched for default):"),
-				                     QLineEdit::Normal,i18n("(Default)"),&ok,this);
+		QString	name = KLineEditDlg::getText(i18n("Instance Name"),i18n("Enter name for new instance (leave untouched for default):"),
+				                     i18n("(Default)"),&ok,this);
 		if (ok)
 		{
 			if (name.find(QRegExp("\\s")) != -1)
@@ -210,10 +211,12 @@ void KMInstancePage::slotSettings()
 	{
 		if (src == i18n("(Default)")) src = QString::null;
 		KMPrinter	*pr = KMFactory::self()->virtualManager()->findInstance(m_printer,src);
-		if (pr && KMFactory::self()->manager()->completePrinterShort(pr))
+		if (pr && (pr->isSpecial() || KMFactory::self()->manager()->completePrinterShort(pr)))
 		{
-			KPrinter::setApplicationType(KPrinter::StandAlone);
+			int oldAppType = KMFactory::self()->settings()->application;
+			KMFactory::self()->settings()->application = -1;
 			KPrinterPropertyDialog::setupPrinter(pr, this);
+			KMFactory::self()->settings()->application = oldAppType;
 			if (pr->isEdited())
 			{ // printer edited, need to save changes
 				pr->setDefaultOptions(pr->editedOptions());
