@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmpages.cpp,v 1.7 2002/02/23 23:07:47 danimo Exp $
+ *  $Id: kmpages.cpp,v 1.8 2002/05/06 12:23:43 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -43,7 +43,7 @@ KMPages::~KMPages()
 void KMPages::setPrinter(KMPrinter *p)
 {
 	QPtrListIterator<KMPrinterPage>	it(m_pages);
-	for (;it.current();++it)
+	for (int i=0;it.current();++it,i++)
 		it.current()->setPrinter(p);
 }
 
