@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmtimer.h,v 1.2 2001/03/24 07:27:49 waba Exp $
+ *  $Id: kmtimer.h,v 1.4 2001/12/14 09:42:51 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,17 +22,31 @@
 #ifndef KMTIMER_H
 #define KMTIMER_H
 
-class KMMainView;
+#include <qtimer.h>
 
-class KMTimer
+class KMTimer : public QTimer
 {
+	Q_OBJECT
 public:
-	static void blockTimer();
-	static void releaseTimer(bool refresh = false);
-	static void setMainView(KMMainView*);
+	void delay(int t);
+	~KMTimer();
+
+public slots:
+	void hold();
+	void release();
+	void release(bool do_emit);
+
+	static KMTimer* self();
+
+private slots:
+	void slotTimeout();
+
 private:
-	static KMMainView	*m_view;
-	static int		m_count;
+	static KMTimer	*m_self;
+	int	m_count;
+	KMTimer(QObject *parent = 0, const char *name = 0);
+	void releaseTimer(bool do_emit = false);
+	void startTimer(int delay = -1);
 };
 
 #endif
