@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmwclass.cpp,v 1.5 2001/09/23 12:19:16 mueller Exp $
+ *  $Id: kmwclass.cpp,v 1.7 2002/08/12 19:38:47 binner Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -36,7 +36,7 @@ KMWClass::KMWClass(QWidget *parent, const char *name)
 : KMWizardPage(parent,name)
 {
 	m_ID = KMWizard::Class;
-	m_title = i18n("Class composition");
+	m_title = i18n("Class Composition");
 	m_nextpage = KMWizard::Name;
 
 	m_list1 = new KListBox(this);
@@ -51,8 +51,8 @@ KMWClass::KMWClass(QWidget *parent, const char *name)
 	connect(add,SIGNAL(clicked()),SLOT(slotAdd()));
 	connect(remove,SIGNAL(clicked()),SLOT(slotRemove()));
 
-	QLabel	*l1 = new QLabel(i18n("Available printers"), this);
-	QLabel	*l2 = new QLabel(i18n("Class printers"), this);
+	QLabel	*l1 = new QLabel(i18n("Available printers:"), this);
+	QLabel	*l2 = new QLabel(i18n("Class printers:"), this);
 
         QHBoxLayout	*lay1 = new QHBoxLayout(this, 0, 15);
         QVBoxLayout	*lay2 = new QVBoxLayout(0, 0, 20);
@@ -78,7 +78,7 @@ bool KMWClass::isValid(QString& msg)
 {
 	if (m_list2->count() == 0)
 	{
-		msg = i18n("You must select at least one printer !");
+		msg = i18n("You must select at least one printer!");
 		return false;
 	}
 	return true;
