@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmwdriver.cpp,v 1.3 2002/02/28 12:10:33 goffioul Exp $
+ *  $Id: kmwdriver.cpp,v 1.6 2002/10/28 13:54:28 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -23,6 +23,7 @@
 #include "kmwizard.h"
 #include "kmprinter.h"
 #include "kmdriverdbwidget.h"
+#include "kmdriverdb.h"
 
 #include <qlayout.h>
 #include <klocale.h>
@@ -31,7 +32,7 @@ KMWDriver::KMWDriver(QWidget *parent, const char *name)
 : KMWizardPage(parent,name)
 {
 	m_ID = KMWizard::Driver;
-	m_title = i18n("Printer model selection");
+	m_title = i18n("Printer Model Selection");
 	m_nextpage = KMWizard::DriverTest;
 
 	m_widget = new KMDriverDbWidget(this);
@@ -44,7 +45,26 @@ void KMWDriver::initPrinter(KMPrinter *p)
 {
 	m_widget->init();
 	if (p)
+	{
+		QString autoDetect = p->option( "kde-autodetect" );
+		if ( !autoDetect.isEmpty() )
+		{
+			// use auto-detection info instead: split the string
+			// into make/model pair at the first space character
+			int p = autoDetect.find( ' ' );
+			if ( p != -1 )
+			{
+				QString manu = autoDetect.left( p ), model = autoDetect.mid( p+1 );
+				KMDBEntryList *l = KMDriverDB::self()->findPnpEntry( manu, model );
+				if ( l && l->count() > 0 )
+				{
+					m_widget->setDriver( l->getFirst()->manufacturer, l->getFirst()->model );
+					return;
+				}
+			}
+		}
 		m_widget->setDriver(p->manufacturer(),p->model());
+	}
 }
 
 void KMWDriver::updatePrinter(KMPrinter *p)
@@ -92,7 +112,7 @@ bool KMWDriver::isValid(QString& msg)
 		return true;
 	else
 	{
-		msg = i18n("Internal error: unable to locate the driver !");
+		msg = i18n("Internal error: unable to locate the driver!");
 		return false;
 	}
 }
