@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmwlpd.cpp,v 1.16 2002/03/01 01:24:35 goffioul Exp $
+ *  $Id: kmwlpd.cpp,v 1.18.2.1 2002/12/07 16:53:20 waba Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -40,7 +40,7 @@ KMWLpd::KMWLpd(QWidget *parent, const char *name)
 : KMWInfoBase(2,parent,name)
 {
 	m_ID = KMWizard::LPD;
-	m_title = i18n("LPD queue information");
+	m_title = i18n("LPD Queue Information");
 	m_nextpage = KMWizard::Driver;
 
 	setInfo(i18n("<p>Enter the information concerning the remote LPD queue. "
@@ -53,7 +53,7 @@ bool KMWLpd::isValid(QString& msg)
 {
 	if (text(0).isEmpty() || text(1).isEmpty())
 	{
-		msg = i18n("Some information is missing !");
+		msg = i18n("Some information is missing!");
 		return false;
 	}
 
@@ -87,12 +87,12 @@ bool checkLpdQueue(const char *host, const char *queue)
 		return false;
 	
 	char	buf[1024] = {0};
-	int	n, tot(0);
+	int	n, tot(1);
 	while ((n = sock.readBlock(res, 63)) > 0)
 	{
 		res[n] = 0;
 		tot += n;
-		if (tot > 1024)
+		if (tot >= 1024)
 			break;
 		else
 			strcat(buf, res);
