@@ -27,12 +27,14 @@ class QComboBox;
 class QLineEdit;
 class QCheckBox;
 class QLabel;
+class QPushButton;
+class KDialogBase;
 
 class KXmlCommandSelector : public QWidget
 {
 	Q_OBJECT
 public:
-	KXmlCommandSelector(bool canBeNull = true, QWidget *parent = 0, const char *name = 0);
+	KXmlCommandSelector(bool canBeNull = true, QWidget *parent = 0, const char *name = 0, KDialogBase *dlg = 0);
 
 	void setCommand(const QString&);
 	QString command() const;
@@ -45,6 +47,11 @@ protected slots:
 	void slotEditCommand();
 	void slotBrowse();
 	void slotCommandSelected(int);
+	void slotHelpCommand();
+	void slotXmlCommandToggled( bool );
+
+signals:
+	void commandValid( bool );
 
 private:
 	QComboBox	*m_cmd;
@@ -52,6 +59,8 @@ private:
 	QCheckBox	*m_usefilter;
 	QStringList	m_cmdlist;
 	QLabel		*m_shortinfo;
+	QPushButton *m_helpbtn;
+	QString m_help;
 };
 
 #endif
