@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdesu_pty.cpp,v 2.9.2.2 2002/05/09 21:48:55 leitner Exp $
+ * $Id: kdesu_pty.cpp,v 2.12 2002/09/30 20:15:02 garbanzo Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -20,7 +20,9 @@
 #define _GNU_SOURCE   /* Needed for getpt, ptsname in glibc 2.1.x systems */
 #endif
 
-#if !defined(_XOPEN_SOURCE) && !defined(__osf__)
+// This should probably be a check for glibc, rather than a check for 
+// every system it breaks which is most everything else
+#if !defined(_XOPEN_SOURCE) && !defined(__osf__) && !defined(__FreeBSD__) && !defined(__NetBSD__)
 #define _XOPEN_SOURCE /* Needed for grantpt, unlockpt in glibc 2.1.x      */
 #endif
 
