@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: process.cpp,v 1.31.4.1 2003/01/06 23:13:36 espie Exp $
+ * $Id: process.cpp,v 1.31.4.2 2003/02/24 16:09:43 lunakl Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -105,6 +105,11 @@ void PtyProcess::setEnvironment( const QCStringList &env )
     d->env = env;
 }
 
+const QCStringList& PtyProcess::environment() const
+{
+    return d->env;
+}
+
 /*
  * Read one line of input. The terminal is in canonical mode, so you always
  * read a line at at time, but it's possible to receive multiple lines in
