@@ -12,17 +12,20 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
+   You should have received a copy of the GNU Lesser General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 */
 
+#include <stdlib.h>
+
 #include <qclipboard.h>
 #include <qlistbox.h>
 #include <qpopupmenu.h>
+#include <qapplication.h>
 
 #include <kcompletionbox.h>
 #include <kcursor.h>
@@ -65,7 +68,8 @@ KComboBox::KComboBox( bool rw, QWidget *parent, const char *name )
 {
     init();
 
-    if ( rw ) {
+    if ( rw )
+    {
         KLineEdit *edit = new KLineEdit( this, "combo lineedit" );
         setLineEdit( edit );
     }
@@ -83,13 +87,6 @@ void KComboBox::init()
     // Permanently set some parameters in the parent object.
     QComboBox::setAutoCompletion( false );
 
-    // Initialize enable popup menu to false.
-    // Below it will be enabled if the widget
-    // is editable.
-    m_bEnableMenu = false;
-
-    m_trapReturnKey = false;
-
     // Enable context menu by default if widget
     // is editable.
     setContextMenuEnabled( true );
@@ -97,7 +94,10 @@ void KComboBox::init()
     // for wheelscrolling
     installEventFilter( this );
     if ( lineEdit() )
-        lineEdit()->installEventFilter( this );
+    {
+        connect( lineEdit(), SIGNAL( returnPressed() ),
+                 this, SIGNAL( returnPressed() ));
+    }
 }
 
 
@@ -106,7 +106,8 @@ bool KComboBox::contains( const QString& _text ) const
     if ( _text.isEmpty() )
         return false;
 
-    for (int i = 0; i < count(); i++ ) {
+    for (int i = 0; i < count(); i++ )
+    {
         if ( text(i) == _text )
             return true;
     }
@@ -133,10 +134,7 @@ void KComboBox::setAutoCompletion( bool autocomplete )
 void KComboBox::setContextMenuEnabled( bool showMenu )
 {
     if( d->klineEdit )
-    {
         d->klineEdit->setContextMenuEnabled( showMenu );
-        m_bEnableMenu = showMenu;
-    }
 }
 
 
@@ -175,9 +173,8 @@ void KComboBox::makeCompletion( const QString& text )
             return;
 
         int index = listBox()->index( listBox()->findItem( text ) );
-        if( index >= 0 ) {
+        if( index >= 0 )
             setCurrentItem( index );
-        }
     }
 }
 
@@ -187,72 +184,23 @@ void KComboBox::rotateText( KCompletionBase::KeyBindingType type )
         d->klineEdit->rotateText( type );
 }
 
+// not needed anymore
 bool KComboBox::eventFilter( QObject* o, QEvent* ev )
 {
-    QLineEdit *edit = lineEdit();
-
-    int type = ev->type();
-
-    if ( o == edit )
-    {
-        KCursor::autoHideEventFilter( edit, ev );
-
-        if ( type == QEvent::KeyPress )
-        {
-            QKeyEvent *e = static_cast<QKeyEvent *>( ev );
-
-            if ( e->key() == Key_Return || e->key() == Key_Enter)
-            {
-                // On Return pressed event, emit both
-                // returnPressed(const QString&) and returnPressed() signals
-                emit returnPressed();
-                emit returnPressed( currentText() );
-                if ( d->klineEdit && d->klineEdit->completionBox(false) &&
-                     d->klineEdit->completionBox()->isVisible() )
-                    d->klineEdit->completionBox()->hide();
-
-                return m_trapReturnKey;
-            }
-        }
-    }
-
-
-    // wheel-scrolling changes the current item
-    if ( type == QEvent::Wheel ) {
-        if ( !listBox() || listBox()->isHidden() ) {
-            QWheelEvent *e = static_cast<QWheelEvent*>( ev );
-            static const int WHEEL_DELTA = 120;
-            int skipItems = e->delta() / WHEEL_DELTA;
-            if ( e->state() & ControlButton ) // fast skipping
-                skipItems *= 10;
-
-            int newItem = currentItem() - skipItems;
-
-            if ( newItem < 0 )
-                newItem = 0;
-            else if ( newItem >= count() )
-                newItem = count() -1;
-
-            setCurrentItem( newItem );
-            if ( !text( newItem ).isNull() )
-                emit activated( text( newItem ) );
-            emit activated( newItem );
-            e->accept();
-            return true;
-        }
-    }
-
     return QComboBox::eventFilter( o, ev );
 }
 
 void KComboBox::setTrapReturnKey( bool grab )
 {
-    m_trapReturnKey = grab;
+    if ( d->klineEdit )
+        d->klineEdit->setTrapReturnKey( grab );
+    else
+        qWarning("KComboBox::setTrapReturnKey not supported with a non-KLineEdit.");
 }
 
 bool KComboBox::trapReturnKey() const
 {
-    return m_trapReturnKey;
+    return d->klineEdit && d->klineEdit->trapReturnKey();
 }
 
 
@@ -301,21 +249,55 @@ void KComboBox::create( WId id, bool initializeWindow, bool destroyOldWindow )
     KCursor::setAutoHideCursor( lineEdit(), true, true );
 }
 
+void KComboBox::wheelEvent( QWheelEvent *ev )
+{
+    // Not necessary anymore
+    QComboBox::wheelEvent( ev );
+}
+
 void KComboBox::setLineEdit( QLineEdit *edit )
 {
+    if ( !editable() && edit &&
+         qstrcmp( edit->className(), "QLineEdit" ) == 0 )
+    {
+        // uic generates code that creates a read-only QComboBox and then
+        // calls combo->setEditable( true ), which causes QComboBox to set up
+        // a dumb QLineEdit instead of our nice KLineEdit.
+        // As some KComboBox features rely on the KLineEdit, we reject
+        // this order here.
+        delete edit;
+        edit = new KLineEdit( this, "combo edit" );
+    }
+
     QComboBox::setLineEdit( edit );
     d->klineEdit = dynamic_cast<KLineEdit*>( edit );
     setDelegate( d->klineEdit );
 
-    // forward some signals. We only emit returnPressed() ourselves.
-    if ( d->klineEdit ) {
+    // forward some signals.
+    if ( edit )
+        connect( edit, SIGNAL( returnPressed() ), SIGNAL( returnPressed() ));
+
+    if ( d->klineEdit )
+    {
+        // someone calling KComboBox::setEditable( false ) destroys our
+        // lineedit without us noticing. And KCompletionBase::delegate would
+        // be a dangling pointer then, so prevent that. Note: only do this
+        // when it is a KLineEdit!
+        connect( edit, SIGNAL( destroyed() ), SLOT( lineEditDeleted() ));
+        
+        connect( d->klineEdit, SIGNAL( returnPressed( const QString& )),
+                 SIGNAL( returnPressed( const QString& ) ));
+
         connect( d->klineEdit, SIGNAL( completion( const QString& )),
                  SIGNAL( completion( const QString& )) );
+
         connect( d->klineEdit, SIGNAL( substringCompletion( const QString& )),
                  SIGNAL( substringCompletion( const QString& )) );
+
         connect( d->klineEdit,
                  SIGNAL( textRotation( KCompletionBase::KeyBindingType )),
                  SIGNAL( textRotation( KCompletionBase::KeyBindingType )) );
+
         connect( d->klineEdit,
                  SIGNAL( completionModeChanged( KGlobalSettings::Completion )),
                  SIGNAL( completionModeChanged( KGlobalSettings::Completion)));
@@ -323,33 +305,26 @@ void KComboBox::setLineEdit( QLineEdit *edit )
         connect( d->klineEdit,
                  SIGNAL( aboutToShowContextMenu( QPopupMenu * )),
                  SIGNAL( aboutToShowContextMenu( QPopupMenu * )) );
+
+        connect( d->klineEdit,
+                 SIGNAL( completionBoxActivated( const QString& )),
+                 SIGNAL( activated( const QString& )) );
     }
 }
 
-// Temporary functions until QT3 appears. - Seth Chaiklin 20 may 2001
-void KComboBox::deleteWordForward()
-{
-    lineEdit()->cursorWordForward(TRUE);
-    if ( lineEdit()->hasSelectedText() )
-        lineEdit()->del();
-}
-
-void KComboBox::deleteWordBack()
-{
-    lineEdit()->cursorWordBackward(TRUE);
-    if ( lineEdit()->hasSelectedText() )
-        lineEdit()->del();
-}
-
 void KComboBox::setCurrentItem( const QString& item, bool insert, int index )
 {
     int sel = -1;
+
     for (int i = 0; i < count(); ++i)
+    {
         if (text(i) == item)
         {
             sel = i;
             break;
         }
+    }
+
     if (sel == -1 && insert)
     {
         insertItem(item, index);
@@ -361,6 +336,18 @@ void KComboBox::setCurrentItem( const QString& item, bool insert, int index )
     setCurrentItem(sel);
 }
 
+void KComboBox::lineEditDeleted()
+{
+    // yes, we need those ugly casts due to the multiple inheritance
+    // sender() is guaranteed to be a KLineEdit (see the connect() to the
+    // destroyed() signal
+    const KCompletionBase *base = static_cast<const KCompletionBase*>( static_cast<const KLineEdit*>( sender() ));
+
+    // is it our delegate, that is destroyed?
+    if ( base == delegate() )
+        setDelegate( 0L );
+}
+
 // *********************************************************************
 // *********************************************************************
 
@@ -390,6 +377,11 @@ void KHistoryCombo::init( bool useCompletion )
     myRotated = false;
     myPixProvider = 0L;
 
+    // obey HISTCONTROL setting
+    QCString histControl = getenv("HISTCONTROL");
+    if ( histControl == "ignoredups" || histControl == "ignoreboth" )
+        setDuplicatesEnabled( false );
+
     connect( this, SIGNAL(aboutToShowContextMenu(QPopupMenu*)),
              SLOT(addContextMenuItems(QPopupMenu*)) );
     connect( this, SIGNAL( activated(int) ), SLOT( slotReset() ));
@@ -450,14 +442,19 @@ void KHistoryCombo::addContextMenuItems( QPopupMenu* menu )
 
 void KHistoryCombo::addToHistory( const QString& item )
 {
-    if ( item.isEmpty() || (count() > 0 && item == text(0) ))
+    if ( item.isEmpty() || (count() > 0 && item == text(0) )) {
         return;
+    }
 
+    bool wasCurrent = false;
     // remove all existing items before adding
     if ( !duplicatesEnabled() ) {
         for ( int i = 0; i < count(); i++ ) {
-            if ( text( i ) == item )
+            if ( text( i ) == item ) {
+                if ( !wasCurrent )
+                  wasCurrent = ( i == currentItem() );
                 removeItem( i );
+            }
         }
     }
 
@@ -467,6 +464,9 @@ void KHistoryCombo::addToHistory( const QString& item )
     else
         insertItem( item, 0 );
 
+    if ( wasCurrent )
+        setCurrentItem( 0 );
+
     int last;
     QString rmItem;
 
@@ -507,74 +507,104 @@ bool KHistoryCombo::removeFromHistory( const QString& item )
     return removed;
 }
 
-void KHistoryCombo::keyPressEvent( QKeyEvent *e )
+void KHistoryCombo::rotateUp()
 {
     // save the current text in the lineedit
     if ( myIterateIndex == -1 )
         myText = currentText();
 
-    // going up in the history, rotating when reaching QListBox::count()
-    if ( KStdAccel::isEqual( e, KStdAccel::rotateUp() ) ) {
+    myIterateIndex++;
+
+    // skip duplicates/empty items
+    while ( myIterateIndex < count()-1 &&
+            (currentText() == text( myIterateIndex ) ||
+             text( myIterateIndex ).isEmpty()) )
         myIterateIndex++;
 
-        // skip duplicates/empty items
-        while ( myIterateIndex < count()-1 &&
-                (currentText() == text( myIterateIndex ) ||
-                text( myIterateIndex ).isEmpty()) )
-            myIterateIndex++;
+    if ( myIterateIndex >= count() ) {
+        myRotated = true;
+        myIterateIndex = -1;
 
-        if ( myIterateIndex >= count() ) {
-            myRotated = true;
-            myIterateIndex = -1;
+        // if the typed text is the same as the first item, skip the first
+        if ( myText == text(0) )
+            myIterateIndex = 0;
 
-            // if the typed text is the same as the first item, skip the first
-            if ( myText == text(0) )
-                myIterateIndex = 0;
-
-            setEditText( myText );
-        }
-        else
-            setEditText( text( myIterateIndex ));
+        setEditText( myText );
     }
+    else
+        setEditText( text( myIterateIndex ));
+}
+
+void KHistoryCombo::rotateDown()
+{
+    // save the current text in the lineedit
+    if ( myIterateIndex == -1 )
+        myText = currentText();
+
+    myIterateIndex--;
+
+    // skip duplicates/empty items
+    while ( myIterateIndex >= 0 &&
+            (currentText() == text( myIterateIndex ) ||
+             text( myIterateIndex ).isEmpty()) )
+        myIterateIndex--;
 
 
+    if ( myIterateIndex < 0 ) {
+        if ( myRotated && myIterateIndex == -2 ) {
+            myRotated = false;
+            myIterateIndex = count() - 1;
+            setEditText( text(myIterateIndex) );
+        }
+        else { // bottom of history
+            if ( myIterateIndex == -2 ) {
+                KNotifyClient::event( KNotifyClient::notification,
+                                      i18n("No further item in the history."));
+            }
+
+            myIterateIndex = -1;
+            if ( currentText() != myText )
+                setEditText( myText );
+        }
+    }
+    else
+        setEditText( text( myIterateIndex ));
+
+}
+
+void KHistoryCombo::keyPressEvent( QKeyEvent *e )
+{
+    // going up in the history, rotating when reaching QListBox::count()
+    if ( KStdAccel::isEqual( e, KStdAccel::rotateUp() ) ) {
+        rotateUp();
+    }
     // going down in the history, no rotation possible. Last item will be
     // the text that was in the lineedit before Up was called.
     else if ( KStdAccel::isEqual( e, KStdAccel::rotateDown() ) ) {
-        myIterateIndex--;
-
-        // skip duplicates/empty items
-        while ( myIterateIndex >= 0 &&
-                (currentText() == text( myIterateIndex ) ||
-                text( myIterateIndex ).isEmpty()) )
-            myIterateIndex--;
-
-
-        if ( myIterateIndex < 0 ) {
-            if ( myRotated && myIterateIndex == -2 ) {
-                myRotated = false;
-                myIterateIndex = count() - 1;
-                setEditText( text(myIterateIndex) );
-            }
-            else { // bottom of history
-                if ( myIterateIndex == -2 ) {
-                    KNotifyClient::event( KNotifyClient::notification,
-                                      i18n("No further item in the history."));
-                }
-
-                myIterateIndex = -1;
-                if ( currentText() != myText )
-                    setEditText( myText );
-            }
-        }
-        else
-            setEditText( text( myIterateIndex ));
+        rotateDown();
     }
-
     else
         KComboBox::keyPressEvent( e );
 }
 
+void KHistoryCombo::wheelEvent( QWheelEvent *ev )
+{
+    // Pass to poppable listbox if it's up
+    QListBox *lb = listBox();
+    if ( lb && lb->isVisible() )
+    {
+        QApplication::sendEvent( lb, ev );
+        return;
+    }
+    // Otherwise make it change the text without emitting activated
+    if ( ev->delta() > 0 ) {
+        rotateUp();
+    } else {
+        rotateDown();
+    }
+    ev->accept();
+}
+
 void KHistoryCombo::slotReset()
 {
     myIterateIndex = -1;
