@@ -38,7 +38,7 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <knotifyclient.h>
-#include "kdatepik.h"
+#include "kdatepicker.h"
 #include "kdatetbl.h"
 #include <qdatetime.h>
 #include <qstring.h>
@@ -92,7 +92,7 @@ KDateTable::KDateTable(QWidget *parent, QDate date_, const char* name, WFlags f)
   setNumCols(7); // 7 days a week
   setHScrollBarMode(AlwaysOff);
   setVScrollBarMode(AlwaysOff);
-  viewport()->setEraseColor(lightGray);
+  viewport()->setEraseColor(KGlobalSettings::baseColor());
   setDate(date_); // this initializes firstday, numdays, numDaysPrevMonth
 }
 
@@ -105,50 +105,50 @@ KDateTable::paintCell(QPainter *painter, int row, int col)
   int w=cellWidth();
   int h=cellHeight();
   int pos;
-  QBrush brushBlue(blue);
-  QBrush brushLightblue(lightGray);
+  QBrush brushBlue(KGlobalSettings::activeTitleColor());
+  QBrush brushLightblue(KGlobalSettings::baseColor());
   QFont font=KGlobalSettings::generalFont();
   // -----
   font.setPointSize(fontsize);
+  int firstWeekDay = KGlobal::locale()->weekStartDay();
   if(row==0)
     { // we are drawing the headline
       font.setBold(true);
       painter->setFont(font);
       bool normalday = true;
       QString daystr;
-      if (KGlobal::locale()->weekStartsMonday())
-        {
-          daystr = KGlobal::locale()->weekDayName(col+1, true);
-          if (col == 5 || col == 6)
-              normalday = false;
-        } else {
-          daystr = KGlobal::locale()->weekDayName(col==0? 7 : col, true);
-          if (col == 0 || col == 6)
-              normalday = false;
-        }
+      if ( col+firstWeekDay < 8 )
+          daystr = KGlobal::locale()->weekDayName(col+firstWeekDay, true);
+      else
+          daystr = KGlobal::locale()->weekDayName(col+firstWeekDay-7, true);
+      if ( daystr==i18n("Sunday", "Sun") || daystr==i18n("Saturday", "Sat") )
+          normalday=false;
+
       if (!normalday)
         {
-          painter->setPen(lightGray);
+          painter->setPen(KGlobalSettings::baseColor());
           painter->setBrush(brushLightblue);
           painter->drawRect(0, 0, w, h);
-          painter->setPen(blue);
+          painter->setPen(KGlobalSettings::activeTitleColor());
         } else {
-          painter->setPen(blue);
+          painter->setPen(KGlobalSettings::activeTitleColor());
           painter->setBrush(brushBlue);
           painter->drawRect(0, 0, w, h);
-          painter->setPen(white);
+          painter->setPen(KGlobalSettings::activeTextColor());
         }
       painter->drawText(0, 0, w, h-1, AlignCenter,
                         daystr, -1, &rect);
-      painter->setPen(black);
+      painter->setPen(KGlobalSettings::textColor());
       painter->moveTo(0, h-1);
       painter->lineTo(w-1, h-1);
       // ----- draw the weekday:
     } else {
       painter->setFont(font);
       pos=7*(row-1)+col;
-      if (KGlobal::locale()->weekStartsMonday())
-          pos++;
+      if ( firstWeekDay < 4 )
+          pos += firstWeekDay;
+      else
+          pos += firstWeekDay - 7;
       if(pos<firstday || (firstday+numdays<=pos))
         { // we are either
           //  painting a day of the previous month or
@@ -162,7 +162,7 @@ KDateTable::paintCell(QPainter *painter, int row, int col)
           painter->setPen(gray);
         } else { // paint a day of the current month
           text.setNum(pos-firstday+1);
-          painter->setPen(black);
+          painter->setPen(KGlobalSettings::textColor());
         }
 
       pen=painter->pen();
@@ -170,25 +170,25 @@ KDateTable::paintCell(QPainter *painter, int row, int col)
         {
           if(hasFocus())
             { // draw the currently selected date
-              painter->setPen(red);
-              painter->setBrush(darkRed);
+              painter->setPen(KGlobalSettings::highlightColor());
+              painter->setBrush(KGlobalSettings::highlightColor());
               pen=white;
             } else {
-              painter->setPen(darkGray);
-              painter->setBrush(darkGray);
+              painter->setPen(KGlobalSettings::calculateAlternateBackgroundColor(KGlobalSettings::highlightColor()));
+              painter->setBrush(KGlobalSettings::calculateAlternateBackgroundColor(KGlobalSettings::highlightColor()));
               pen=white;
             }
         } else {
-          painter->setBrush(lightGray);
-          painter->setPen(lightGray);
+          painter->setBrush(KGlobalSettings::baseColor());
+          painter->setPen(KGlobalSettings::baseColor());
         }
 
       QDate cur_date = QDate::currentDate();
       if ( (date.year()  == cur_date.year()) &&
-           (date.month() == cur_date.month()) && 
+           (date.month() == cur_date.month()) &&
            (firstday+cur_date.day()-1 == pos) )
       {
-         painter->setPen(black);
+         painter->setPen(KGlobalSettings::textColor());
       }
 
       painter->drawRect(0, 0, w, h);
@@ -227,13 +227,13 @@ KDateTable::keyPressEvent( QKeyEvent *e )
         if ( date.day() > 1 ) {
             setDate(date.addDays(-1));
             return;
-    }
+        }
     }
     if ( e->key() == Qt::Key_Right ) {
         if ( date.day() < date.daysInMonth() ) {
             setDate(date.addDays(1));
             return;
-    }
+        }
     }
 
     if ( e->key() == Qt::Key_Minus ) {
@@ -284,6 +284,13 @@ KDateTable::setFontSize(int size)
   maxCell.setHeight(QMAX(maxCell.height()+4, rect.height()));
 }
 
+void
+KDateTable::wheelEvent ( QWheelEvent * e )
+{
+    setDate(date.addMonths( -(int)(e->delta()/120)) );
+    e->accept();
+}
+
 void
 KDateTable::contentsMousePressEvent(QMouseEvent *e)
 {
@@ -297,7 +304,8 @@ KDateTable::contentsMousePressEvent(QMouseEvent *e)
       return;
     }
 
-  int dayoff = KGlobal::locale()->weekStartsMonday() ? 1 : 0;
+  //int dayoff = KGlobal::locale()->weekStartsMonday() ? 1 : 0;
+  int dayoff = KGlobal::locale()->weekStartDay();
   // -----
   int row, col, pos, temp;
   QPoint mouseCoord;
@@ -305,23 +313,37 @@ KDateTable::contentsMousePressEvent(QMouseEvent *e)
   mouseCoord = e->pos();
   row=rowAt(mouseCoord.y());
   col=columnAt(mouseCoord.x());
-  if(row<0 || col<0)
+  if(row<1 || col<0)
     { // the user clicked on the frame of the table
       return;
     }
-  pos=7*(row-1)+col+1;
-  if(pos+dayoff<=firstday)
+
+  // Rows and columns are zero indexed.  The (row - 1) below is to avoid counting 
+  // the row with the days of the week in the calculation.  We however want pos
+  // to be "1 indexed", hence the "+ 1" at the end of the sum.
+
+  pos = (7 * (row - 1)) + col + 1;
+
+  // This gets pretty nasty below.  firstday is a locale independant index for 
+  // the first day of the week.  dayoff is the day of the week that the week
+  // starts with for the selected locale.  Monday = 1 .. Sunday = 7
+  // Strangely, in some cases dayoff is in fact set to 8, hence all of the
+  // "dayoff % 7" sections below.
+  
+  if(pos + dayoff % 7 <= firstday)
     { // this day is in the previous month
-      KNotifyClient::beep();
+      setDate(date.addDays(-1 * (date.day() + firstday - pos - dayoff % 7)));
       return;
     }
-  if(firstday+numdays<pos+dayoff)
+  if(firstday + numdays < pos + dayoff % 7)
     { // this date is in the next month
-      KNotifyClient::beep();
+      setDate(date.addDays(pos - firstday - date.day() + dayoff % 7));
       return;
     }
-  temp=firstday+date.day()-dayoff-1;
-  setDate(QDate(date.year(), date.month(), pos-firstday+dayoff));
+  temp = firstday + date.day() - dayoff % 7 - 1;
+
+  setDate(QDate(date.year(), date.month(), pos - firstday + dayoff % 7));
+
   updateCell(temp/7+1, temp%7); // Update the previously selected cell
   updateCell(row, col); // Update the selected cell
   // assert(QDate(date.year(), date.month(), pos-firstday+dayoff).isValid());
@@ -369,15 +391,16 @@ KDateTable::getDate() const
   return date;
 }
 
+// what are those repaintContents() good for? (pfeiffer)
 void KDateTable::focusInEvent( QFocusEvent *e )
 {
-    repaintContents(false);
+//    repaintContents(false);
     QGridView::focusInEvent( e );
 }
 
 void KDateTable::focusOutEvent( QFocusEvent *e )
 {
-    repaintContents(false);
+//    repaintContents(false);
     QGridView::focusOutEvent( e );
 }
 
@@ -394,6 +417,54 @@ KDateTable::sizeHint() const
     }
 }
 
+KDateInternalWeekSelector::KDateInternalWeekSelector
+(int fontsize, QWidget* parent, const char* name)
+  : QLineEdit(parent, name),
+    val(new QIntValidator(this)),
+    result(0)
+{
+  QFont font;
+  // -----
+  font=KGlobalSettings::generalFont();
+  font.setPointSize(fontsize);
+  setFont(font);
+  setFrameStyle(QFrame::NoFrame);
+  val->setRange(1, 53);
+  setValidator(val);
+  connect(this, SIGNAL(returnPressed()), SLOT(weekEnteredSlot()));
+}
+
+void
+KDateInternalWeekSelector::weekEnteredSlot()
+{
+  bool ok;
+  int week;
+  // ----- check if this is a valid week:
+  week=text().toInt(&ok);
+  if(!ok)
+    {
+      KNotifyClient::beep();
+      return;
+    }
+  result=week;
+  emit(closeMe(1));
+}
+
+int
+KDateInternalWeekSelector::getWeek()
+{
+  return result;
+}
+
+void
+KDateInternalWeekSelector::setWeek(int week)
+{
+  QString temp;
+  // -----
+  temp.setNum(week);
+  setText(temp);
+}
+
 KDateInternalMonthPicker::KDateInternalMonthPicker
 (int fontsize, QWidget* parent, const char* name)
   : QGridView(parent, name),
@@ -414,7 +485,7 @@ KDateInternalMonthPicker::KDateInternalMonthPicker
   setNumCols(3);
   // enable to find drawing failures:
   // setTableFlags(Tbl_clipCellPainting);
-  viewport()->setEraseColor(lightGray); // for consistency with the datepicker
+  viewport()->setEraseColor(KGlobalSettings::baseColor()); // for consistency with the datepicker
   // ----- find the preferred size
   //       (this is slow, possibly, but unfortunatly it is needed here):
   QFontMetrics metrics(font);
@@ -443,7 +514,7 @@ KDateInternalMonthPicker::getResult() const
 void
 KDateInternalMonthPicker::setupPainter(QPainter *p)
 {
-  p->setPen(black);
+  p->setPen(KGlobalSettings::textColor());
 }
 
 void
