@@ -25,10 +25,37 @@
 #include <qlineedit.h>
 #include <qdatetime.h>
 
+/** Week selection widget.
+* @internal
+* @version $Id: kdatetbl.h,v 1.31 2002/07/25 13:26:37 lukas Exp $
+* @author Stephan Binner
+*/
+class KDateInternalWeekSelector : public QLineEdit
+{
+  Q_OBJECT
+protected:
+  QIntValidator *val;
+  int result;
+public slots:
+  void weekEnteredSlot();
+signals:
+  void closeMe(int);
+public:
+  KDateInternalWeekSelector(int fontsize,
+			    QWidget* parent=0,
+			    const char* name=0);
+  int getWeek();
+  void setWeek(int week);
+
+private:
+  class KDateInternalWeekPrivate;
+  KDateInternalWeekPrivate *d;
+};
+
 /**
 * A table containing month names. It is used to pick a month directly.
 * @internal
-* @version $Id: kdatetbl.h,v 1.27.2.1 2002/05/09 09:37:22 pfeiffer Exp $
+* @version $Id: kdatetbl.h,v 1.31 2002/07/25 13:26:37 lukas Exp $
 * @author Tim Gilman, Mirko Boehm
 */
 class KDateInternalMonthPicker : public QGridView
@@ -97,7 +124,7 @@ private:
 
 /** Year selection widget.
 * @internal
-* @version $Id: kdatetbl.h,v 1.27.2.1 2002/05/09 09:37:22 pfeiffer Exp $
+* @version $Id: kdatetbl.h,v 1.31 2002/07/25 13:26:37 lukas Exp $
 * @author Tim Gilman, Mirko Boehm
 */
 class KDateInternalYearSelector : public QLineEdit
@@ -125,7 +152,7 @@ private:
 /**
  * Frame with popup menu behaviour.
  * @author Tim Gilman, Mirko Boehm
- * @version $Id: kdatetbl.h,v 1.27.2.1 2002/05/09 09:37:22 pfeiffer Exp $
+ * @version $Id: kdatetbl.h,v 1.31 2002/07/25 13:26:37 lukas Exp $
  */
 class KPopupFrame : public QFrame
 {
@@ -212,7 +239,7 @@ public:
  * dateSelected(QDate)
  *
  * @internal
- * @version $Id: kdatetbl.h,v 1.27.2.1 2002/05/09 09:37:22 pfeiffer Exp $
+ * @version $Id: kdatetbl.h,v 1.31 2002/07/25 13:26:37 lukas Exp $
  * @author Tim Gilman, Mirko Boehm
  */
 class KDateTable : public QGridView
@@ -257,6 +284,7 @@ protected:
      * React on mouse clicks that select a date.
      */
     virtual void contentsMousePressEvent(QMouseEvent *);
+    virtual void wheelEvent( QWheelEvent * e );
     virtual void keyPressEvent( QKeyEvent *e );
     virtual void focusInEvent( QFocusEvent *e );
     virtual void focusOutEvent( QFocusEvent *e );
@@ -282,6 +310,7 @@ protected:
     int numDaysPrevMonth;
     /**
      * unused
+     * ### remove in KDE 4.0
      */
     bool unused_hasSelection;
     /**
