@@ -106,7 +106,7 @@ class KDialogBaseTile;
  * the @ref KJanusWidget class internally to accomplish this. If you
  * use TreeList, Tabbed or IconList mode, then add pages with @ref addPage().
  *
- * Pages that have been added can be removed again by simply deleting 
+ * Pages that have been added can be removed again by simply deleting
  * the page.
  *
  * If you want complete control of how the dialog contents should look,
@@ -146,7 +146,8 @@ class KDialogBaseTile;
  * <pre>
  * UrlDlg::UrlDlg( QWidget *parent, const QString& caption,
  *                 const QString& urltext)
- *   : KDialogBase( parent, "urldialog", true, caption, Ok|Cancel, Ok, true )
+ *   : KDialogBase( parent, "urldialog", true, caption,
+ *		    KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
  * {
  *   QWidget *page = new QWidget( this );
  *   setMainWidget(page);
@@ -169,7 +170,8 @@ class KDialogBaseTile;
  * <pre>
  * UrlDlg::UrlDlg( QWidget *parent, const QString& caption,
  *		const QString& urltext)
- * : KDialogBase( parent, "urldialog", true, caption, Ok|Cancel, Ok, true )
+ * : KDialogBase( parent, "urldialog", true, caption,
+		  KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
  * {
  *   QVBox *page = makeVBoxMainWidget();
  *   QLabel *label = new QLabel( caption, page, "caption" );
@@ -242,7 +244,7 @@ class KDialogBase : public KDialog
      *  @li @p TreeList - A dialog with a tree on the left side and a
      *                    representation of the contents on the right side.
      *  @li @p Tabbed -   A dialog using a @ref QTabWidget.
-     *  @li @p Plain -    A normal dialog.
+     *  @li @p Plain -    A normal dialog. Use @ref plainPage() as parent for widgets.
      *  @li @p Swallow
      *  @li @p IconList - A dialog with an iconlist on the left side and a
      *                    representation of the contents on the right side.
@@ -363,16 +365,6 @@ class KDialogBase : public KDialog
      */
     ~KDialogBase();
 
-    /**
-     * Destruct the Dialog delayed.
-     *
-     * You can call this function from
-     * slots like @ref closeClicked() and @ref hidden().
-     * You should not use the dialog any more after
-     * calling this function.
-     */
-    void delayedDestruct();
-
     /**
      * Sets the orientation of the button box.
      *
@@ -449,7 +441,7 @@ class KDialogBase : public KDialog
      * @return The page widget which must be used as the toplevel widget for
      *         the page.
      */
-    QFrame  *addPage( const QString &item,
+    QFrame  *addPage( const QString &itemName,
                       const QString &header=QString::null,
 		      const QPixmap &pixmap=QPixmap() );
 
@@ -556,9 +548,9 @@ class KDialogBase : public KDialog
      * toplevel widget for this particular page. The widget contains a
      * @ref QGridLayout layout so the widget children are  positioned in a grid.
      *
-     * @param n Specifies the number of columns if @p dir is @ref Qt::Horizontal
-     *          or the number of rows if @p dir is @ref Qt::Vertical.
-     * @param dir Can be @ref Qt::Horizontal or @ref Qt::Vertical.
+     * @param n Specifies the number of columns if @p dir is Qt::Horizontal
+     *          or the number of rows if @p dir is Qt::Vertical.
+     * @param dir Can be Qt::Horizontal or Qt::Vertical.
      * @param itemName String used in the list or as tab item name.
      * @param header Header text use in the list modes @p Ignored in @p Tabbed
      *        mode. If empty, the item text is used instead.
@@ -822,13 +814,13 @@ class KDialogBase : public KDialog
     * save the dialogs size dependant on the screen dimension either to the
     * global or application config file.
     *
-    * @param The group to which the dialogs size is saved. @see configDialogSize
+    * @param The group to which the dialogs size is saved. See @ref configDialogSize
     * to read the size.
     * @param global Set to true if the entry should go to the global config rather
     *        than to the applications config. Default is false.
     */
    void saveDialogSize( const QString& groupName, bool global=false );
-   
+
     /**
      * Sets the text of the OK button.
      *
@@ -1095,6 +1087,17 @@ class KDialogBase : public KDialog
      */
     void enableLinkedHelp( bool state );
 
+    /**
+     * Destruct the Dialog delayed.
+     *
+     * You can call this function from
+     * slots like @ref closeClicked() and @ref hidden().
+     * You should not use the dialog any more after
+     * calling this function.
+     * @since 3.1
+     */
+    void delayedDestruct();
+
     /**
      * Sets the text that is shown as the linked text.
      *
@@ -1139,6 +1142,16 @@ class KDialogBase : public KDialog
      */
     void updateBackground();
 
+    /**
+     * Force closing the dialog, setting its result code to the one Esc would set.
+     * You shouldn't use this, generally (let the user make his choice!)
+     * but it can be useful when you need to make a choice after a timeout
+     * has happened, or when the parent widget has to go somewhere else
+     * (e.g. html redirections).
+     * @since 3.1
+     */
+    void cancel();
+
   signals:
     /**
      * The Help button was pressed. This signal is only emitted if
@@ -1254,7 +1267,7 @@ class KDialogBase : public KDialog
      * to call setDetailsWidget if you haven't done so yet.
      */
     void aboutToShowDetails();
-    
+
     /**
      * A page is about to be shown.
      */
@@ -1269,7 +1282,7 @@ class KDialogBase : public KDialog
     virtual void keyPressEvent( QKeyEvent *e );
 
     /**
-     * Emits the @ref hidden signal. You can connect to that signal to
+     * Emits the #hidden signal. You can connect to that signal to
      * detect when a dialog has been closed.
      */
     virtual void hideEvent( QHideEvent * );
@@ -1368,7 +1381,11 @@ class KDialogBase : public KDialog
     void updateGeometry();
 
     /**
-     * Deletes the dialog.
+     * Deletes the dialog immediately. If you want to delete the dialog
+     * delayed use delayedDestruct() or QObject::deleteLater().
+     *
+     * Attention: Do no use connect this slot to signals from user
+     * actions!
      */
     void slotDelayedDestruct();
 
