@@ -31,6 +31,8 @@
 #endif
 
 class QFrame;
+class KDockContainer;
+
 
 /**
  * Like QSplitter but specially designed for dockwidgets stuff.
@@ -68,19 +70,30 @@ public:
   void setHighResolution(bool b=true);
   bool highResolution() const;
 
+  void setForcedFixedWidth(KDockWidget *dw,int w);
+  void setForcedFixedHeight(KDockWidget *dw,int h);
+  void restoreFromForcedFixedSize(KDockWidget *dw);
+
+  Orientation orientation(){return m_orientation;}
+
 protected:
   int checkValue( int ) const;
   virtual void resizeEvent(QResizeEvent *);
-
+/*
+protected slots:
+  void delayedResize();*/
+  
 private:
   void setupMinMaxSize();
 
   QWidget *child0, *child1;
-  Orientation orientation;
+  Orientation m_orientation;
   bool initialised;
   QFrame* divider;
-  int xpos;
+  int xpos, savedXPos;
   bool mOpaqueResize, mKeepSize, mHighResolution;
+  int fixedWidth0,fixedWidth1;
+  int fixedHeight0,fixedHeight1;
 };
 
 /**
@@ -105,6 +118,12 @@ private:
   bool moveMouse;
 };
 
+/**
+ * resizing enum
+ **/
+ 
+
+
 /**
  * additional KDockWidget stuff (private)
 */
@@ -122,11 +141,17 @@ public slots:
   void slotFocusEmbeddedWidget(QWidget* w = 0L);
 
 public:
+ enum KDockWidgetResize 
+{ResizeLeft,ResizeTop,ResizeRight,ResizeBottom,ResizeBottomLeft,ResizeTopLeft,ResizeBottomRight,ResizeTopRight};
+
   int index;
   int splitPosInPercent;
   bool pendingFocusInEvent;
   bool blockHasUndockedSignal;
   bool pendingDtor;
+  int forcedWidth;
+  int forcedHeight;
+  bool isContainer;
 
 #ifndef NO_KDE2
   NET::WindowType windowType;
@@ -134,6 +159,30 @@ public:
 
   QWidget *_parent;
   bool transient;
+
+  QGuardedPtr<QWidget> container;
+
+  QPoint resizePos;
+  bool resizing;
+  KDockWidgetResize resizeMode;
+
+};
+
+class KDockWidgetHeaderPrivate
+   : public QObject
+{
+public:
+  KDockWidgetHeaderPrivate( QObject* parent )
+        : QObject( parent )
+  {
+    toDesktopButton = 0;
+    showToDesktopButton = true;
+    topLevel = false;
+  }
+  KDockButton_Private* toDesktopButton;
+
+  bool showToDesktopButton;
+  bool topLevel;
 };
 
 #endif
