@@ -1,5 +1,5 @@
 /*
-    $Id: kfontdialog.h,v 1.55 2002/03/13 20:56:48 pfeiffer Exp $
+    $Id: kfontdialog.h,v 1.61 2002/09/11 02:18:25 orlovich Exp $
 
     Requires the Qt widget libraries, available at no cost at
     http://www.troll.no
@@ -37,7 +37,7 @@ class QGroupBox;
 class QLabel;
 class QStringList;
 class KListBox;
-
+class KIntNumInput;
 /**
  * While KFontChooser as an ordinary widget can be embedded in
  * custom dialogs and therefore is very flexible, in most cases
@@ -46,7 +46,7 @@ class KListBox;
  *
  * @short A font selection widget.
  * @author Preston Brown <pbrown@kde.org>, Bernd Wuebben <wuebben@kde.org>
- * @version $Id: kfontdialog.h,v 1.55 2002/03/13 20:56:48 pfeiffer Exp $
+ * @version $Id: kfontdialog.h,v 1.61 2002/09/11 02:18:25 orlovich Exp $
  */
 class KFontChooser : public QWidget
 {
@@ -58,8 +58,7 @@ public:
    *  @li @p StyleList -  Identifies the style (center) list.
    *  @li @p SizeList -   Identifies the size (rightmost) list.
    */
-  enum FontColumn { FamilyList=0x01, StyleList=0x02, SizeList=0x04,
-    CharsetList=0x08 };
+  enum FontColumn { FamilyList=0x01, StyleList=0x02, SizeList=0x04};
 
   /**
    *  @li @p FontDiffFamily - Identifies a requested change in the font family.
@@ -70,8 +69,8 @@ public:
 
   /**
    * Constructs a font picker widget.
-   * It normally comes up with all font families present on the system; the 
-   * getFont method below does allow some more fine-tuning of the selection of fonts 
+   * It normally comes up with all font families present on the system; the
+   * getFont method below does allow some more fine-tuning of the selection of fonts
    * that will be displayed in the dialog.
    * <p>Consider the following code snippet;<pre>
    *
@@ -179,18 +178,6 @@ public:
   QButton::ToggleState sizeIsRelative() const;
 
 
-#if QT_VERSION < 300
-  /**
-   * Set the currently selected charset in the chooser.
-   */
-  void setCharset( const QString & charset );
-
-  /**
-   * @return The currently selected charset in the dialog.
-   */
-  QString charset() const;
-#endif
-
   /**
    * @return The current text in the sample text input area.
    */
@@ -221,14 +208,14 @@ public:
   static QString getXLFD( const QFont &theFont )
     { return theFont.rawName(); }
 
-  /** 
+  /**
    * The selection criteria for the font families shown in the dialog.
-   *  @li @p FixedWidthFont when included only fixed-width fonts are returned. 
+   *  @li @p FixedWidthFont when included only fixed-width fonts are returned.
    *        The fonts where the width of every character is equal.
-   *  @li @p ScalableFont when included only scalable fonts are returned; 
-   *        certain configurations allow bitmap fonts to remain unscaled and 
+   *  @li @p ScalableFont when included only scalable fonts are returned;
+   *        certain configurations allow bitmap fonts to remain unscaled and
    *        thus these fonts have limited number of sizes.
-   *  @li @p SmoothScalableFont when included only return smooth scalable fonts. 
+   *  @li @p SmoothScalableFont when included only return smooth scalable fonts.
    *        this will return only non-bitmap fonts which are scalable to any size requested.
    *        Setting this option to true will mean the "scalable" flag is irrelavant.
    */
@@ -260,12 +247,10 @@ private slots:
   void size_chosen_slot(const QString&);
   void style_chosen_slot(const QString&);
   void displaySample(const QFont &font);
-  void charset_chosen_slot(const QString&);
   void showXLFDArea(bool);
-
+  void size_value_slot(int);
 private:
   void fillFamilyListBox(bool onlyFixedFonts = false);
-  void fillCharsetsCombo();
   void fillSizeList();
   // This one must be static since getFontList( QStringList, char*) is so
   static void addFont( QStringList &list, const char *xfont );
@@ -276,7 +261,7 @@ private:
   // inserted into the fontdialog font-family combo-box
   QStringList  fontList;
 
-  QGroupBox    *xlfdBox;
+  KIntNumInput *sizeOfFont;
 
   QLineEdit    *sampleEdit;
   QLineEdit    *xlfdEdit;
@@ -325,11 +310,11 @@ private:
  *            ...
  * </pre>
  *
- * @image kfontdialog.png KFontDialog
+ * \image html kfontdialog.png "KDE Font Dialog"
  *
  * @short A font selection dialog.
  * @author Preston Brown <pbrown@kde.org>, Bernd Wuebben <wuebben@kde.org>
- * @version $Id: kfontdialog.h,v 1.55 2002/03/13 20:56:48 pfeiffer Exp $
+ * @version $Id: kfontdialog.h,v 1.61 2002/09/11 02:18:25 orlovich Exp $
  */
 class KFontDialog : public KDialogBase  {
     Q_OBJECT
@@ -394,19 +379,6 @@ public:
   QButton::ToggleState sizeIsRelative() const
     { return chooser->sizeIsRelative(); }
 
-#if QT_VERSION < 300
-  /**
-   * Sets the currently selected charset in the dialog.
-   */
-  void setCharset( const QString & charset )
-    { chooser->setCharset( charset ); }
-
-  /**
-   * @return The currently selected charset in the dialog.
-   */
-  QString charset() const { return chooser->charset(); }
-#endif
-
   /**
    * Creates a modal font dialog, lets the user choose a font,
    * and returns when the dialog is closed.
