@@ -19,25 +19,29 @@
 
 #include <kglobalsettings.h>
 #include <kcursor.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kipc.h>
 #include <kdebug.h>
 
 #include "klistbox.h"
 
+#ifdef Q_WS_X11
 #include <X11/Xlib.h>
+#endif
 
 KListBox::KListBox( QWidget *parent, const char *name, WFlags f )
     : QListBox( parent, name, f )
 {
-    oldCursor = viewport()->cursor();
     connect( this, SIGNAL( onViewport() ),
 	     this, SLOT( slotOnViewport() ) );
     connect( this, SIGNAL( onItem( QListBoxItem * ) ),
 	     this, SLOT( slotOnItem( QListBoxItem * ) ) );
     slotSettingsChanged(KApplication::SETTINGS_MOUSE);
-    connect( kapp, SIGNAL( settingsChanged(int) ), SLOT( slotSettingsChanged(int) ) );
-    kapp->addKipcEventMask( KIPC::SettingsChanged );
+    if (kapp)
+    {
+        connect( kapp, SIGNAL( settingsChanged(int) ), SLOT( slotSettingsChanged(int) ) );
+        kapp->addKipcEventMask( KIPC::SettingsChanged );
+    }
 
     m_pCurrentItem = 0L;
 
@@ -60,7 +64,7 @@ void KListBox::slotOnItem( QListBoxItem *item )
 void KListBox::slotOnViewport()
 {
     if ( m_bChangeCursorOverItem )
-        viewport()->setCursor( oldCursor );
+        viewport()->unsetCursor();
 
     m_pAutoSelect->stop();
     m_pCurrentItem = 0L;
@@ -101,36 +105,46 @@ void KListBox::slotSettingsChanged(int category)
     m_autoSelectDelay = KGlobalSettings::autoSelectDelay();
 
     if( !m_bUseSingle || !m_bChangeCursorOverItem )
-	viewport()->setCursor( oldCursor );
+        viewport()->unsetCursor();
 }
 
 void KListBox::slotAutoSelect()
 {
+  // check that the item still exists
+  if( index( m_pCurrentItem ) == -1 )
+    return;
+
   //Give this widget the keyboard focus.
   if( !hasFocus() )
     setFocus();
 
+#ifdef Q_WS_X11 //FIXME
   Window root;
   Window child;
   int root_x, root_y, win_x, win_y;
   uint keybstate;
   XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
 		 &root_x, &root_y, &win_x, &win_y, &keybstate );
+#endif
 
   QListBoxItem* previousItem = item( currentItem() ); 
   setCurrentItem( m_pCurrentItem );
 
   if( m_pCurrentItem ) {
+#ifndef Q_WS_QWS //FIXME
     //Shift pressed?
     if( (keybstate & ShiftMask) ) {
+#endif
       bool block = signalsBlocked();
       blockSignals( true );
 
+#ifndef Q_WS_QWS //FIXME
       //No Ctrl? Then clear before!
       if( !(keybstate & ControlMask) )  
 	clearSelection(); 
+#endif
 
-      bool select = !m_pCurrentItem->selected();
+      bool select = !m_pCurrentItem->isSelected();
       bool update = viewport()->isUpdatesEnabled();
       viewport()->setUpdatesEnabled( false );
 
@@ -157,40 +171,50 @@ void KListBox::slotAutoSelect()
       if( selectionMode() == QListBox::Single )
 	emit selectionChanged( m_pCurrentItem );
     }
+#ifndef Q_WS_QWS //FIXME
     else if( (keybstate & ControlMask) )
-      setSelected( m_pCurrentItem, !m_pCurrentItem->selected() );
+      setSelected( m_pCurrentItem, !m_pCurrentItem->isSelected() );
+#endif
     else {
       bool block = signalsBlocked();
       blockSignals( true );
 
-      if( !m_pCurrentItem->selected() )
+      if( !m_pCurrentItem->isSelected() )
 	clearSelection(); 
 
       blockSignals( block );
 
       setSelected( m_pCurrentItem, true );
     }
+#ifndef Q_WS_QWS //FIXME
   }
   else
     kdDebug() << "Thats not supposed to happen!!!!" << endl;
+#endif
 }
 
 void KListBox::emitExecute( QListBoxItem *item, const QPoint &pos )
 {
+#ifdef Q_WS_X11 //FIXME
   Window root;
   Window child;
   int root_x, root_y, win_x, win_y;
   uint keybstate;
   XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
 		 &root_x, &root_y, &win_x, &win_y, &keybstate );
+#endif
     
   m_pAutoSelect->stop();
   
+#ifndef Q_WS_QWS //FIXME
   //Dont emit executed if in SC mode and Shift or Ctrl are pressed
   if( !( m_bUseSingle && ((keybstate & ShiftMask) || (keybstate & ControlMask)) ) ) {
+#endif
     emit executed( item );
     emit executed( item, pos );
+#ifndef Q_WS_QWS //FIXME
   }
+#endif
 }
 
 //
@@ -263,3 +287,8 @@ void KListBox::slotMouseButtonClicked( int btn, QListBoxItem *item, const QPoint
   if( (btn == LeftButton) && item )
     emitExecute( item, pos );
 }
+
+void KListBox::virtual_hook( int, void* )
+{ /*BASE::virtual_hook( id, data );*/ }
+
+#include "klistbox.moc"
