@@ -514,13 +514,13 @@ void KMainWindow::slotStateChanged(const QString &newstate,
 
 void KMainWindow::closeEvent ( QCloseEvent *e )
 {
+    // Save settings if auto-save is enabled, and settings have changed
+    if (d->settingsDirty && d->autoSaveSettings)
+        saveAutoSaveSettings();
+
     if (queryClose()) {
         e->accept();
 
-        // Save settings if auto-save is enabled, and settings have changed
-        if (d->settingsDirty && d->autoSaveSettings)
-            saveAutoSaveSettings();
-
         int not_withdrawn = 0;
         QPtrListIterator<KMainWindow> it(*KMainWindow::memberList);
         for (it.toFirst(); it.current(); ++it){
@@ -529,7 +529,7 @@ void KMainWindow::closeEvent ( QCloseEvent *e )
         }
 
         if ( !no_query_exit && not_withdrawn <= 0 ) { // last window close accepted?
-            if ( queryExit() ) {            // Yes, Quit app?
+            if ( queryExit() && !kapp->sessionSaving()) {            // Yes, Quit app?
                 // We saved the toolbars already
                 disconnect(kapp, SIGNAL(shutDown()), this, SLOT(shuttingDown()));
                 kapp->deref();             // ...and quit aplication.
