@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kpixmapio.h,v 1.8.2.1 2003/02/14 08:47:54 lunakl Exp $
+ * $Id: kpixmapio.h,v 1.8.2.2 2003/06/05 23:42:37 mueller Exp $
  *
  * This file is part of the KDE project, module kdeui.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -14,11 +14,13 @@
 
 class QPixmap;
 class QImage;
+class QPoint;
+class QRect;
 class KPixmapIOPrivate;
 /**
  * @short Fast QImage to/from QPixmap conversion.
  * @author Geert Jansen <jansen@kde.org>
- * @version $Id: kpixmapio.h,v 1.8.2.1 2003/02/14 08:47:54 lunakl Exp $
+ * @version $Id: kpixmapio.h,v 1.8.2.2 2003/06/05 23:42:37 mueller Exp $
  *
  * KPixmapIO implements a fast path for QPixmap to/from QImage conversions.
  * It uses the MIT-SHM shared memory extension for this. If this extension is
