@@ -1,6 +1,6 @@
 /*
  *
- * $Id: krestrictedline.cpp,v 1.9.6.1 2001/10/17 20:05:14 neundorf Exp $
+ * $Id: krestrictedline.cpp,v 1.11 2002/03/04 00:51:51 lunakl Exp $
  *
  * Implementation of KRestrictedLine
  *
@@ -44,7 +44,7 @@ void KRestrictedLine::keyPressEvent( QKeyEvent *e )
 {
   // let QLineEdit process "special" keys and return/enter
   // so that we still can use the default key binding
-  if (e->key() == Key_Enter || e->key() == Key_Return ||  e->key() == Key_Delete || e->ascii() < 32)
+  if (e->key() == Key_Enter || e->key() == Key_Return || e->key() == Key_Delete || e->ascii() < 32)
     {
       QLineEdit::keyPressEvent(e);
       return;
@@ -76,4 +76,7 @@ QString KRestrictedLine::validChars() const
   return qsValidChars;
 }
 
+void KRestrictedLine::virtual_hook( int id, void* data )
+{ KLineEdit::virtual_hook( id, data ); }
+
 #include "krestrictedline.moc"
