@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: krootpixmap.cpp,v 1.16 2002/03/14 21:26:42 binner Exp $
+ * $Id: krootpixmap.cpp,v 1.18 2002/08/04 14:07:53 coolo Exp $
  *
  * This file is part of the KDE project, module kdeui.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -16,7 +16,7 @@
 #include <qimage.h>
 
 #ifndef Q_WS_QWS //FIXME
-#include <kapp.h>
+#include <kapplication.h>
 #include <kimageeffect.h>
 #include <kpixmapio.h>
 #include <kwinmodule.h>
@@ -166,8 +166,7 @@ void KRootPixmap::repaint(bool force)
  	updateBackground( m_pPixmap );
 	return;
     }
-    if (!force)
-      m_Rect = QRect(p1, p2);
+    m_Rect = QRect(p1, p2);
     m_Desk = currentDesktop();
 
     // KSharedPixmap will correctly generate a tile for us.
