@@ -129,8 +129,6 @@ void KXYSelector::mouseMoveEvent( QMouseEvent *e )
 
 void KXYSelector::setPosition( int xp, int yp )
 {
-	QPainter painter;
-
 	if ( xp < 2 )
 		xp = 2;
 	else if ( xp > width() - 2 )
@@ -141,6 +139,7 @@ void KXYSelector::setPosition( int xp, int yp )
 	else if ( yp > height() - 2 )
 		yp = height() - 2;
 
+	QPainter painter;
 	painter.begin( this );
 
 	bitBlt( this, px - STORE_W, py - STORE_W, &store, 0, 0,
@@ -466,5 +465,14 @@ void KGradientSelector::drawContents( QPainter *painter )
 
 //-----------------------------------------------------------------------------
 
+void KXYSelector::virtual_hook( int, void* )
+{ /*BASE::virtual_hook( id, data );*/ }
+
+void KSelector::virtual_hook( int, void* )
+{ /*BASE::virtual_hook( id, data );*/ }
+
+void KGradientSelector::virtual_hook( int id, void* data )
+{ KSelector::virtual_hook( id, data ); }
+
 #include "kselect.moc"
 
