@@ -77,12 +77,6 @@ KURLLabel::~KURLLabel ()
   delete d;
 }
 
-// BCI: remove in KDE 3.0
-void KURLLabel::mousePressEvent (QMouseEvent* e)
-{
-  QLabel::mousePressEvent (e);
-}
-
 void KURLLabel::mouseReleaseEvent (QMouseEvent* e)
 {
   QLabel::mouseReleaseEvent (e);
@@ -303,4 +297,7 @@ void KURLLabel::leaveEvent (QEvent* e)
   emit leftURL (d->URL);
 }
 
+void KURLLabel::virtual_hook( int, void* )
+{ /*BASE::virtual_hook( id, data );*/ }
+
 #include "kurllabel.moc"
