@@ -5,11 +5,12 @@
 #include <qmultilineedit.h>
 #include <qkeycode.h>
 #include <qpixmap.h>
+#include <qcursor.h>
 
 #include <stdlib.h>
 
 #include "kstatusbar.h"
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmainwindow.h>
 #include <kmenubar.h>
 #include "kstatusbartest.h"
