@@ -24,6 +24,7 @@
 #include <kdebug.h>
 #include <qtextcodec.h>
 #include <qfileinfo.h>
+#include <kprocess.h>
 
 extern int xmlLoadExtDtdDefaultValue;
 
@@ -87,7 +88,7 @@ int main(int argc, char **argv) {
     // xsltSetGenericDebugFunc(stderr, NULL);
 
     KAboutData aboutData( "meinproc", I18N_NOOP("XML-Translator" ),
-	"$Id: meinproc.cpp,v 1.25 2002/01/03 10:21:26 coolo Exp $",
+	"$Id: meinproc.cpp,v 1.26.2.1 2002/12/05 23:09:05 waba Exp $",
 	I18N_NOOP("KDE Translator for XML"));
 
     KCmdLineArgs::init(argc, argv, &aboutData);
@@ -133,7 +134,7 @@ int main(int argc, char **argv) {
 
         QString catalogs;
         catalogs += locate( "dtd", "customization/catalog" );
-        catalogs += ":";
+        catalogs += " ";
         catalogs += locate( "dtd", "docbook/xml-dtd-4.1.2/docbook.cat" );
 
         setenv( "SGML_CATALOG_FILES", QFile::encodeName( catalogs ).data(), 1);
@@ -147,7 +148,11 @@ int main(int argc, char **argv) {
                 exe = locate( "exe", "xmllint" );
         }
         if ( !::access( QFile::encodeName( exe ), X_OK ) ) {
-            FILE *xmllint = popen( QString( exe + " --catalogs --valid --noout %1 2>&1" ).arg( file.fileName() ).local8Bit().data(), "r");
+            QString cmd = exe;
+            cmd += " --catalogs --valid --noout ";
+            cmd += KProcess::quote(file.fileName());
+            cmd += " 2>&1";
+            FILE *xmllint = popen( QFile::encodeName( cmd ), "r");
             bool noout = true;
             while ( !feof( xmllint ) ) {
                 int c;
