@@ -12,7 +12,7 @@
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
 #include <qstring.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kinstance.h>
 #include <xslt.h>
 #include <qfile.h>
@@ -39,7 +39,7 @@ int main(int argc, char **argv) {
     //    xsltSetGenericDebugFunc(stderr, NULL);
 
     KAboutData aboutData( "xml2man", I18N_NOOP("XML2MAN Processor" ),
-	"$Id: xml2man.cpp,v 1.2.2.2 2001/11/09 07:50:49 rkrusty Exp $",
+	"$Id: xml2man.cpp,v 1.7 2002/01/03 10:21:26 coolo Exp $",
 	I18N_NOOP("KDE Translator for XML"));
 
     KCmdLineArgs::init(argc, argv, &aboutData);
@@ -57,7 +57,6 @@ int main(int argc, char **argv) {
     LIBXML_TEST_VERSION
     xmlSubstituteEntitiesDefault(1);
     xmlLoadExtDtdDefaultValue = 1;
-    xmlSetExternalEntityLoader(meinExternalEntityLoader);
 
     QString tss = locate( "dtd", "db2man.xsl" );
 
