@@ -5,8 +5,6 @@
 
 QString transform(const QString &file, const QString& stylesheet);
 QString transform(xmlParserCtxtPtr ctxt, const QString &tss);
-xmlParserInputPtr meinExternalEntityLoader(const char *URL, const char *ID,
-					   xmlParserCtxtPtr ctxt);
 QString splitOut(const QString &parsed, int index);
 void fillInstance(KInstance &ins);
 bool saveToCache( const QString &contents, const QString &filename );
