@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: css_valueimpl.h,v 1.41 2002/11/03 18:03:37 faure Exp $
+ * $Id: css_valueimpl.h,v 1.41.2.2 2003/08/17 14:38:51 mueller Exp $
  */
 #ifndef _CSS_css_valueimpl_h_
 #define _CSS_css_valueimpl_h_
@@ -34,7 +34,7 @@
 namespace khtml {
     class RenderStyle;
     class CachedImage;
-};
+}
 
 namespace DOM {
 
@@ -316,7 +316,7 @@ public:
     CSSValueImpl *value() { return m_value; }
 
     // make sure the following fits in 4 bytes.
-    int  m_id 		: 29;
+    signed int  m_id 	: 29;
     bool m_bImportant 	: 1;
     bool nonCSSHint 	: 1;
 protected:
@@ -324,6 +324,6 @@ protected:
 };
 
 
-}; // namespace
+} // namespace
 
 #endif
