@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: cssparser.h,v 1.60 2002/10/22 04:44:08 pletourn Exp $
+ * $Id: cssparser.h,v 1.60.2.1 2003/05/18 12:34:36 mueller Exp $
  */
 #ifndef _CSS_cssparser_h_
 #define _CSS_cssparser_h_
@@ -233,5 +233,5 @@ public:
 	QPtrList<StyleBaseImpl> *m_lstChildren;
     };
 
-}; // namespace
+} // namespace
 #endif
