@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: css_extensions.cpp,v 1.2 2000/04/01 18:32:24 knoll Exp $
+ * $Id: css_extensions.cpp,v 1.3 2001/10/04 10:34:17 faure Exp $
  */
 #include "dom_exception.h"
 #include "dom_string.h"
@@ -224,10 +224,10 @@ void CSS2BorderSpacing::setVerticalSpacing( const unsigned short verticalType, c
         ((CSS2BorderSpacingImpl *)impl)->setVerticalSpacing( verticalType, value );
 }
 
-void CSS2BorderSpacing::setInherit()(  )
+void CSS2BorderSpacing::setInherit()
 {
     if(impl)
-        ((CSS2BorderSpacingImpl *)impl)->setInherit()(  );
+        ((CSS2BorderSpacingImpl *)impl)->setInherit();
 }
 
 
