@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom2_events.h,v 1.9 2002/11/07 13:47:07 faure Exp $
+ * $Id: dom2_events.h,v 1.9.2.1 2003/05/18 12:34:37 mueller Exp $
  */
 
 #ifndef _DOM_Events_h_
@@ -832,5 +832,5 @@ protected:
 
 
 
-}; //namespace
+} //namespace
 #endif
