@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom_doc.cpp,v 1.42.2.1 2003/01/03 21:09:23 mueller Exp $
+ * $Id: dom_doc.cpp,v 1.42.2.2 2003/06/24 21:34:00 faure Exp $
  */
 
 #include "dom/dom_exception.h"
@@ -228,14 +228,24 @@ Element Document::documentElement() const
 
 Element Document::createElement( const DOMString &tagName )
 {
-    if (impl) return ((DocumentImpl *)impl)->createElement(tagName);
-    return 0;
+    if (!impl)
+        return 0;
+    int exceptioncode = 0;
+    Element el = ((DocumentImpl *)impl)->createElement(tagName, &exceptioncode);
+    if (exceptioncode)
+        throw DOMException(exceptioncode);
+    return el;
 }
 
 Element Document::createElementNS( const DOMString &namespaceURI, const DOMString &qualifiedName )
 {
-    if (impl) return ((DocumentImpl *)impl)->createElementNS(namespaceURI,qualifiedName);
-    return 0;
+    if (!impl)
+        return 0;
+    int exceptioncode = 0;
+    Element el = ((DocumentImpl *)impl)->createElementNS(namespaceURI, qualifiedName, &exceptioncode);
+    if (exceptioncode)
+        throw DOMException(exceptioncode);
+    return el;
 }
 
 DocumentFragment Document::createDocumentFragment(  )
@@ -288,11 +298,12 @@ Attr Document::createAttributeNS( const DOMString &namespaceURI, const DOMString
         localName.remove(0, colonpos+1);
     }
 
-    // ### check correctness of parameters
-
-    NodeImpl::Id id = static_cast<DocumentImpl*>(impl)->attrId(namespaceURI.implementation(), localName.implementation(), false /* allocate */);
-    Attr r = static_cast<DocumentImpl*>(impl)->createAttribute(id);
     int exceptioncode = 0;
+    NodeImpl::Id id = static_cast<DocumentImpl*>(impl)->attrId(namespaceURI.implementation(), localName.implementation(), false /* allocate */, &exceptioncode);
+    if (exceptioncode)
+        throw DOMException(exceptioncode);
+
+    Attr r = static_cast<DocumentImpl*>(impl)->createAttribute(id);
     if (r.handle() && prefix.implementation())
         r.handle()->setPrefix(prefix.implementation(), exceptioncode);
     if (exceptioncode)
