@@ -79,9 +79,9 @@ DOMString::~DOMString()
 DOMString &DOMString::operator =(const DOMString &other)
 {
     if ( impl != other.impl ) {
-    if(impl) impl->deref();
-    impl = other.impl;
-    if(impl) impl->ref();
+        if(impl) impl->deref();
+        impl = other.impl;
+        if(impl) impl->ref();
     }
     return *this;
 }
@@ -207,14 +207,14 @@ QString DOMString::string() const
 {
     if(!impl) return QString::null;
 
-    return QConstString(impl->s, impl->l).string();
+    return QString(impl->s, impl->l);
 }
 
 int DOMString::toInt() const
 {
     if(!impl) return 0;
 
-    return QConstString(impl->s, impl->l).string().toInt();
+    return impl->toInt();
 }
 
 DOMString DOMString::copy() const
