@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: dom_text.h,v 1.9 2000/08/21 13:46:01 pmk Exp $
+ * $Id: dom_text.h,v 1.9.12.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef _DOM_CharacterData_h_
 #define _DOM_CharacterData_h_
@@ -305,5 +305,5 @@ protected:
 
 };
 
-}; //namespace
+} //namespace
 #endif
