@@ -18,12 +18,12 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_document.cpp,v 1.33.2.1 2002/04/16 17:43:04 mueller Exp $
+ * $Id: html_document.cpp,v 1.36.2.1 2003/01/03 21:09:23 mueller Exp $
  */
 // --------------------------------------------------------------------------
 
 #include "html_document.h"
-
+#include "css/csshelper.h"
 #include "dom/html_misc.h"
 #include "xml/dom_textimpl.h"
 #include "html/html_documentimpl.h"
@@ -63,9 +63,9 @@ HTMLDocument &HTMLDocument::operator = (const Node &other)
 	DocumentImpl *d = static_cast<DocumentImpl *>(other.handle());
 	if(!d->isHTMLDocument()) {
 	    if ( impl ) impl->deref();
-	impl = 0;
+            impl = 0;
 	} else {
-	Node::operator =(other);
+            Node::operator =(other);
 	}
     }
     return *this;
@@ -87,9 +87,10 @@ DOMString HTMLDocument::title() const
     return static_cast<HTMLDocumentImpl *>(impl)->title();
 }
 
-void HTMLDocument::setTitle( const DOMString &/*value*/ )
+void HTMLDocument::setTitle( const DOMString &value )
 {
-    // ###
+    if (impl)
+        static_cast<HTMLDocumentImpl *>(impl)->setTitle(value);
 }
 
 DOMString HTMLDocument::referrer() const
@@ -101,7 +102,8 @@ DOMString HTMLDocument::referrer() const
 DOMString HTMLDocument::completeURL(const DOMString& str) const
 {
     if(!impl) return str;
-    return ((HTMLDocumentImpl *)impl)->completeURL(str.string());
+    DOMString parsed = khtml::parseURL(str);
+    return ((HTMLDocumentImpl *)impl)->completeURL(parsed.string());
 }
 
 DOMString HTMLDocument::domain() const
