@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_element.cpp,v 1.19.2.1 2002/04/16 17:43:04 mueller Exp $
+ * $Id: html_element.cpp,v 1.22 2002/10/30 10:17:48 faure Exp $
  */
 #include "dom/dom_exception.h"
 #include "dom/html_misc.h"
@@ -167,12 +167,18 @@ HTMLCollection HTMLElement::children() const
     return HTMLCollection(impl, HTMLCollectionImpl::NODE_CHILDREN);
 }
 
+HTMLCollection HTMLElement::all() const
+{
+    if(!impl) return HTMLCollection();
+    return HTMLCollection(impl, HTMLCollectionImpl::DOC_ALL /*it's called "doc" but it works from any node */);
+}
+
 void HTMLElement::assignOther( const Node &other, int elementId )
 {
-    if(other.elementId() != elementId) {
+    if (other.elementId() != static_cast<Q_UINT32>(elementId)) {
 	if ( impl ) impl->deref();
 	impl = 0;
     } else {
 	Node::operator = (other);
-    }   
+    }
 }
