@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: html_form.h,v 1.14.2.1 2003/01/03 21:09:24 mueller Exp $
+ * $Id: html_form.h,v 1.14.2.2 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef HTML_FORM_H
 #define HTML_FORM_H
@@ -1309,6 +1309,6 @@ public:
     void setPrompt( const DOMString & );
 };
 
-}; //namespace
+} //namespace
 
 #endif
