@@ -238,8 +238,8 @@ namespace KJS {
   private: \
     int id; \
   }; \
-  };
+  }
 
-}; // namespace
+} // namespace
 
 #endif
