@@ -233,6 +233,6 @@ namespace KJS {
   Value getSelectHTMLCollection(ExecState *exec, const DOM::HTMLCollection& c, const DOM::HTMLSelectElement& e);
 
 
-}; // namespace
+} // namespace
 
 #endif
