@@ -83,14 +83,20 @@ void HTMLBodyElementImpl::parseAttribute(AttributeImpl *attr)
             m_bgSet = false;
         break;
     }
-    case ATTR_MARGINWIDTH:
+    case ATTR_MARGINWIDTH: {
+	KHTMLView* w = getDocument()->view();
+	w->setMarginWidth( -1 ); // unset this, so it doesn't override the setting here
         addCSSLength(CSS_PROP_MARGIN_RIGHT, attr->value() );
+    }
         /* nobreak; */
     case ATTR_LEFTMARGIN:
         addCSSLength(CSS_PROP_MARGIN_LEFT, attr->value() );
         break;
-    case ATTR_MARGINHEIGHT:
+    case ATTR_MARGINHEIGHT: {
+	KHTMLView* w = getDocument()->view();
+	w->setMarginHeight( -1 ); // unset this, so it doesn't override the setting here
         addCSSLength(CSS_PROP_MARGIN_BOTTOM, attr->value());
+    }
         /* nobreak */
     case ATTR_TOPMARGIN:
         addCSSLength(CSS_PROP_MARGIN_TOP, attr->value());
@@ -125,8 +131,6 @@ void HTMLBodyElementImpl::parseAttribute(AttributeImpl *attr)
 	aStr += " { color: " + attr->value().string() + "; }";
         m_styleSheet->parseString(aStr);
         m_styleSheet->setNonCSSHints();
-        if (attached())
-            getDocument()->updateStyleSelector();
         break;
     }
     case ATTR_ONLOAD:
@@ -156,9 +160,9 @@ void HTMLBodyElementImpl::parseAttribute(AttributeImpl *attr)
     }
 }
 
-void HTMLBodyElementImpl::init()
+void HTMLBodyElementImpl::insertedIntoDocument()
 {
-    HTMLElementImpl::init();
+    HTMLElementImpl::insertedIntoDocument();
 
     KHTMLView* w = getDocument()->view();
     if(w->marginWidth() != -1) {
@@ -177,7 +181,16 @@ void HTMLBodyElementImpl::init()
     if ( m_bgSet && !m_fgSet )
         addCSSProperty(CSS_PROP_COLOR, "#000000");
 
-    getDocument()->updateStyleSelector();
+    if (m_styleSheet)
+        getDocument()->updateStyleSelector();
+}
+
+void HTMLBodyElementImpl::removedFromDocument()
+{
+    HTMLElementImpl::removedFromDocument();
+
+    if (m_styleSheet)
+        getDocument()->updateStyleSelector();
 }
 
 void HTMLBodyElementImpl::attach()
@@ -203,8 +216,6 @@ void HTMLBodyElementImpl::attach()
 HTMLFrameElementImpl::HTMLFrameElementImpl(DocumentPtr *doc)
     : HTMLElementImpl(doc)
 {
-    parentWidget = 0;
-
     frameBorder = true;
     frameBorderSet = false;
     marginWidth = -1;
@@ -229,43 +240,64 @@ void HTMLFrameElementImpl::parseAttribute(AttributeImpl *attr)
     {
     case ATTR_SRC:
         url = khtml::parseURL(attr->val());
+        // FIXME_APPLE: load new url in the iframe
+        setChanged();
         break;
     case ATTR_ID:
     case ATTR_NAME:
+        // FIXME: if already attached, doesn't change the frame name
+        // FIXME: frame name conflicts, no unique frame name anymore
         name = attr->value();
         break;
     case ATTR_FRAMEBORDER:
     {
         frameBorder = attr->value().toInt();
         frameBorderSet = ( attr->val() != 0 );
+        // FIXME: when attached, has no effect
     }
     break;
     case ATTR_MARGINWIDTH:
         marginWidth = attr->val()->toInt();
+        // FIXME: when attached, has no effect
         break;
     case ATTR_MARGINHEIGHT:
         marginHeight = attr->val()->toInt();
+        // FIXME: when attached, has no effect
         break;
     case ATTR_NORESIZE:
         noresize = true;
+        // FIXME: when attached, has no effect
         break;
     case ATTR_SCROLLING:
-        kdDebug( 6031 ) << "set scroll mode" << endl;
         if( strcasecmp( attr->value(), "auto" ) == 0 )
             scrolling = QScrollView::Auto;
         else if( strcasecmp( attr->value(), "yes" ) == 0 )
             scrolling = QScrollView::AlwaysOn;
         else if( strcasecmp( attr->value(), "no" ) == 0 )
             scrolling = QScrollView::AlwaysOff;
+        // when attached, has no effect
+        break;
+    case ATTR_ONLOAD:
+        static_cast<HTMLDocumentImpl*>( getDocument() )->body()
+              ->setHTMLEventListener(EventImpl::LOAD_EVENT,
+            getDocument()->createHTMLEventListener(attr->value().string()));
+        break;
+    case ATTR_ONUNLOAD:
+        static_cast<HTMLDocumentImpl*>( getDocument() )->body()
+              ->setHTMLEventListener(EventImpl::UNLOAD_EVENT,
+            getDocument()->createHTMLEventListener(attr->value().string()));
+        break;
 
     default:
         HTMLElementImpl::parseAttribute(attr);
     }
 }
 
-void HTMLFrameElementImpl::init()
+void HTMLFrameElementImpl::attach()
 {
-    HTMLElementImpl::init();
+    assert(!attached());
+    assert(parentNode());
+    assert(parentNode()->renderer());
 
     // we should first look up via id, then via name.
     // this shortterm hack fixes the ugly case. ### rewrite needed for next release
@@ -286,27 +318,11 @@ void HTMLFrameElementImpl::init()
         }
         node = static_cast<HTMLElementImpl*>(node->parentNode());
     }
-}
-
-void HTMLFrameElementImpl::attach()
-{
-    assert(!attached());
-    assert(parentNode());
-    assert(parentNode()->renderer());
 
     // ignore display: none for this element!
     KHTMLView* w = getDocument()->view();
-    // avoid endless recursion
-    KURL u;
-    if (!url.isEmpty()) u = getDocument()->completeURL( url.string() );
-    bool selfreference = false;
-    for (KHTMLPart* part = w->part(); part; part = part->parentPart())
-        if (part->url() == u) {
-            selfreference = true;
-            break;
-        }
 
-    if (!selfreference)  {
+    if (isURLAllowed(url.string()))  {
         m_render = new RenderFrame(this);
         m_render->setStyle(getDocument()->styleSelector()->styleForElement(this));
         parentNode()->renderer()->addChild(m_render, nextRenderer());
@@ -322,14 +338,7 @@ void HTMLFrameElementImpl::attach()
       name = DOMString(w->part()->requestFrameName());
 
     // load the frame contents
-    if ( !url.isEmpty() && !(w->part()->onlyLocalReferences() && u.protocol() != "file"))
-        w->part()->requestFrame( static_cast<RenderFrame*>(m_render), url.string(), name.string() );
-}
-
-void HTMLFrameElementImpl::detach()
-{
-    HTMLElementImpl::detach();
-    parentWidget = 0;
+    w->part()->requestFrame( static_cast<RenderFrame*>(m_render), url.string(), name.string() );
 }
 
 void HTMLFrameElementImpl::setLocation( const DOMString& str )
@@ -435,11 +444,11 @@ void HTMLFrameSetElementImpl::parseAttribute(AttributeImpl *attr)
             frameborder = false;
         break;
     case ATTR_ONLOAD:
-        setHTMLEventListener(EventImpl::LOAD_EVENT,
+        getDocument()->setHTMLEventListener(EventImpl::LOAD_EVENT,
 	    getDocument()->createHTMLEventListener(attr->value().string()));
         break;
     case ATTR_ONUNLOAD:
-        setHTMLEventListener(EventImpl::UNLOAD_EVENT,
+        getDocument()->setHTMLEventListener(EventImpl::UNLOAD_EVENT,
 	    getDocument()->createHTMLEventListener(attr->value().string()));
         break;
     default:
@@ -447,9 +456,11 @@ void HTMLFrameSetElementImpl::parseAttribute(AttributeImpl *attr)
     }
 }
 
-void HTMLFrameSetElementImpl::init()
+void HTMLFrameSetElementImpl::attach()
 {
-    HTMLElementImpl::init();
+    assert(!m_render);
+    assert(parentNode());
+    assert(parentNode()->renderer());
 
     // inherit default settings from parent frameset
     HTMLElementImpl* node = static_cast<HTMLElementImpl*>(parentNode());
@@ -464,13 +475,6 @@ void HTMLFrameSetElementImpl::init()
         }
         node = static_cast<HTMLElementImpl*>(node->parentNode());
     }
-}
-
-void HTMLFrameSetElementImpl::attach()
-{
-    assert(!m_render);
-    assert(parentNode());
-    assert(parentNode()->renderer());
 
     // ignore display: none
     m_render = new RenderFrameSet(this);
@@ -493,7 +497,7 @@ void HTMLFrameSetElementImpl::detach()
 {
     if(attached())
         // ### send the event when we actually get removed from the doc instead of here
-        dispatchHTMLEvent(EventImpl::UNLOAD_EVENT,false,false);
+        getDocument()->dispatchHTMLEvent(EventImpl::UNLOAD_EVENT,false,false);
 
     HTMLElementImpl::detach();
 }
@@ -511,15 +515,6 @@ void HTMLFrameSetElementImpl::recalcStyle( StyleChange ch )
 
 // -------------------------------------------------------------------------
 
-HTMLHeadElementImpl::HTMLHeadElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc)
-{
-}
-
-HTMLHeadElementImpl::~HTMLHeadElementImpl()
-{
-}
-
 NodeImpl::Id HTMLHeadElementImpl::id() const
 {
     return ID_HEAD;
@@ -540,15 +535,6 @@ void HTMLHtmlElementImpl::attach()
 
 // -------------------------------------------------------------------------
 
-HTMLHtmlElementImpl::HTMLHtmlElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc)
-{
-}
-
-HTMLHtmlElementImpl::~HTMLHtmlElementImpl()
-{
-}
-
 NodeImpl::Id HTMLHtmlElementImpl::id() const
 {
     return ID_HTML;
@@ -599,25 +585,9 @@ void HTMLIFrameElementImpl::attach()
     assert(!m_render);
     assert(parentNode());
 
-    KHTMLView* w = getDocument()->view();
-    // avoid endless recursion
-    KURL u;
-    if (!url.isEmpty()) u = getDocument()->completeURL( url.string() );
-    bool selfreference = false;
-    for (KHTMLPart* part = w->part(); part; part = part->parentPart())
-        if (part->url() == u) {
-            selfreference = true;
-            break;
-        }
-
-    KHTMLPart *part = w->part();
-    int depth = 0;
-    while ((part = part->parentPart()))
-	depth++;
-
     RenderStyle* _style = getDocument()->styleSelector()->styleForElement(this);
     _style->ref();
-    if (!selfreference && !(w->part()->onlyLocalReferences() && u.protocol() != "file") &&
+    if (isURLAllowed(url.string()) &&
         parentNode()->renderer() && _style->display() != NONE) {
         m_render = new RenderPartObject(this);
         m_render->setStyle(_style);
