@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_blockimpl.h,v 1.32.4.2 2003/01/13 22:04:47 mueller Exp $
+ * $Id: html_blockimpl.h,v 1.32.4.3 2003/05/18 12:34:39 mueller Exp $
  */
 
 // -------------------------------------------------------------------------
@@ -67,5 +67,5 @@ public:
     void setWidth( long w );
 };
 
-}; //namespace
+} //namespace
 #endif
