@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_elementimpl.cpp,v 1.143 2002/02/28 11:33:47 mueller Exp $
+ * $Id: html_elementimpl.cpp,v 1.148.2.2 2003/01/13 22:04:47 mueller Exp $
  */
 // -------------------------------------------------------------------------
 //#define DEBUG
@@ -47,16 +47,12 @@
 #include "xml/dom_textimpl.h"
 #include "xml/dom2_eventsimpl.h"
 
+#include <kapplication.h>
 #include <kdebug.h>
 
 using namespace DOM;
 using namespace khtml;
 
-HTMLElementImpl::HTMLElementImpl(DocumentPtr *doc)
-    : ElementImpl(doc)
-{
-}
-
 HTMLElementImpl::~HTMLElementImpl()
 {
 }
@@ -80,10 +76,11 @@ void HTMLElementImpl::parseAttribute(AttributeImpl *attr)
     case ATTR_ID:
         // unique id
         setHasID();
+        setChanged(); // in case of a CSS selector on id
         break;
     case ATTR_CLASS:
-        // class
-        setHasClass();
+    case ATTR_NAME:
+        setChanged(); // in case of a CSS selector on class/name
         break;
     case ATTR_STYLE:
         // ### we need to remove old style info in case there was any!
@@ -108,11 +105,11 @@ void HTMLElementImpl::parseAttribute(AttributeImpl *attr)
         break;
 // standard events
     case ATTR_ONCLICK:
-	setHTMLEventListener(EventImpl::KHTML_CLICK_EVENT,
+	setHTMLEventListener(EventImpl::KHTML_ECMA_CLICK_EVENT,
 	    getDocument()->createHTMLEventListener(attr->value().string()));
         break;
     case ATTR_ONDBLCLICK:
-	setHTMLEventListener(EventImpl::KHTML_DBLCLICK_EVENT,
+	setHTMLEventListener(EventImpl::KHTML_ECMA_DBLCLICK_EVENT,
 	    getDocument()->createHTMLEventListener(attr->value().string()));
         break;
     case ATTR_ONMOUSEDOWN:
@@ -161,6 +158,14 @@ void HTMLElementImpl::parseAttribute(AttributeImpl *attr)
     }
 }
 
+void HTMLElementImpl::recalcStyle( StyleChange ch )
+{
+    ElementImpl::recalcStyle( ch );
+
+    if (m_render /*&& changed*/)
+        m_render->updateFromElement();
+}
+
 void HTMLElementImpl::addCSSProperty(int id, const DOMString &value)
 {
     if(!m_styleDecls) createDecl();
@@ -175,7 +180,7 @@ void HTMLElementImpl::addCSSProperty(int id, int value)
     setChanged();
 }
 
-void HTMLElementImpl::addCSSLength(int id, const DOMString &value)
+void HTMLElementImpl::addCSSLength(int id, const DOMString &value, bool numOnly, bool multiLength)
 {
     if(!m_styleDecls) createDecl();
 
@@ -188,17 +193,18 @@ void HTMLElementImpl::addCSSLength(int id, const DOMString &value)
 
         for ( ;l < v->l; l++ ) {
             char cc = v->s[l].latin1();
-            if ( cc > '9' || ( cc < '0' && cc != '*' && cc != '%' && cc != '.') )
+            if ( cc > '9' || ( cc < '0' && ( numOnly || (cc != '%' && cc != '.' &&
+							 !( multiLength && cc == '*') ) ) ) )
                 break;
         }
         if ( l != v->l ) {
-            m_styleDecls->setLengthProperty( id, DOMString( v->s, l ), false, true );
+            m_styleDecls->setLengthProperty( id, DOMString( v->s, l ), false, true, multiLength );
             setChanged();
             return;
         }
     }
 
-    m_styleDecls->setLengthProperty(id, value, false, true);
+    m_styleDecls->setLengthProperty(id, value, false, true, multiLength);
     setChanged();
 }
 
@@ -312,7 +318,7 @@ bool HTMLElementImpl::setInnerText( const DOMString &text )
 
     removeChildren();
 
-    TextImpl *t = new TextImpl( docPtr(), text );
+    TextImpl *t = new TextImpl( docPtr(), text.implementation() );
     int ec = 0;
     appendChild( t, ec );
     if ( !ec )
@@ -365,6 +371,38 @@ void HTMLElementImpl::addHTMLAlignment( DOMString alignment )
 	addCSSProperty( CSS_PROP_VERTICAL_ALIGN, propvalign );
 }
 
+bool HTMLElementImpl::isURLAllowed(const QString& url) const
+{
+    KHTMLView *w = getDocument()->view();
+
+    KURL newURL(getDocument()->completeURL(url));
+    newURL.setRef(QString::null);
+
+    // Prohibit non-file URLs if we are asked to.
+    if (!w || w->part()->onlyLocalReferences() && newURL.protocol() != "file")
+        return false;
+
+    // do we allow this suburl ?
+    if ( !kapp || !kapp->kapp->authorizeURLAction("redirect", w->part()->url(), newURL) )
+        return false;
+
+    // We allow one level of self-reference because some sites depend on that.
+    // But we don't allow more than one.
+    bool foundSelfReference = false;
+    for (KHTMLPart *part = w->part(); part; part = part->parentPart()) {
+        KURL partURL = part->url();
+        partURL.setRef(QString::null);
+        if (partURL == newURL) {
+            if (foundSelfReference)
+                return false;
+            foundSelfReference = true;
+        }
+    }
+
+    return true;
+}
+
+
 
 // -------------------------------------------------------------------------
 HTMLGenericElementImpl::HTMLGenericElementImpl(DocumentPtr *doc, ushort i)
