@@ -42,15 +42,6 @@
 
 using namespace khtml;
 
-HTMLBaseElementImpl::HTMLBaseElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc)
-{
-}
-
-HTMLBaseElementImpl::~HTMLBaseElementImpl()
-{
-}
-
 NodeImpl::Id HTMLBaseElementImpl::id() const
 {
     return ID_BASE;
@@ -105,13 +96,6 @@ void HTMLBaseElementImpl::process()
 
 // -------------------------------------------------------------------------
 
-HTMLLinkElementImpl::HTMLLinkElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc)
-{
-    m_sheet = 0;
-    m_loading = false;
-    m_cachedSheet = 0;
-}
 
 HTMLLinkElementImpl::~HTMLLinkElementImpl()
 {
@@ -238,14 +222,6 @@ void HTMLLinkElementImpl::sheetLoaded()
 
 // -------------------------------------------------------------------------
 
-HTMLMetaElementImpl::HTMLMetaElementImpl(DocumentPtr *doc) : HTMLElementImpl(doc)
-{
-}
-
-HTMLMetaElementImpl::~HTMLMetaElementImpl()
-{
-}
-
 NodeImpl::Id HTMLMetaElementImpl::id() const
 {
     return ID_META;
@@ -286,26 +262,33 @@ void HTMLMetaElementImpl::process()
 
 // -------------------------------------------------------------------------
 
-HTMLScriptElementImpl::HTMLScriptElementImpl(DocumentPtr *doc) : HTMLElementImpl(doc)
-{
-}
-
-HTMLScriptElementImpl::~HTMLScriptElementImpl()
-{
-}
-
 NodeImpl::Id HTMLScriptElementImpl::id() const
 {
     return ID_SCRIPT;
 }
 
-// -------------------------------------------------------------------------
-
-HTMLStyleElementImpl::HTMLStyleElementImpl(DocumentPtr *doc) : HTMLElementImpl(doc)
+DOMString HTMLScriptElementImpl::text() const
 {
-    m_sheet = 0;
+    if (firstChild() && firstChild()->nodeType() == Node::TEXT_NODE) {
+        return firstChild()->nodeValue();
+    }
+    return "";
 }
 
+void HTMLScriptElementImpl::setText(const DOMString& str)
+{
+    int exceptioncode = 0;
+    if (firstChild() && firstChild()->nodeType() == Node::TEXT_NODE) {
+        static_cast<DOM::TextImpl *>(firstChild())->setData(str, exceptioncode);
+        return;
+    }
+    // No child text node found, creating one
+    DOM::TextImpl* t = getDocument()->createTextNode(str.implementation());
+    appendChild(t, exceptioncode);
+}
+
+// -------------------------------------------------------------------------
+
 HTMLStyleElementImpl::~HTMLStyleElementImpl()
 {
     if(m_sheet) m_sheet->deref();
@@ -343,6 +326,8 @@ void HTMLStyleElementImpl::removedFromDocument()
 
 void HTMLStyleElementImpl::childrenChanged()
 {
+    HTMLElementImpl::childrenChanged();
+
     DOMString text = "";
 
     for (NodeImpl *c = firstChild(); c != 0; c = c->nextSibling()) {
@@ -373,15 +358,6 @@ void HTMLStyleElementImpl::sheetLoaded()
 
 // -------------------------------------------------------------------------
 
-HTMLTitleElementImpl::HTMLTitleElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc)
-{
-}
-
-HTMLTitleElementImpl::~HTMLTitleElementImpl()
-{
-}
-
 NodeImpl::Id HTMLTitleElementImpl::id() const
 {
     return ID_TITLE;
@@ -404,6 +380,7 @@ void HTMLTitleElementImpl::removedFromDocument()
 void HTMLTitleElementImpl::childrenChanged()
 {
     HTMLElementImpl::childrenChanged();
+
     m_title = "";
     for (NodeImpl *c = firstChild(); c != 0; c = c->nextSibling()) {
 	if ((c->nodeType() == Node::TEXT_NODE) || (c->nodeType() == Node::CDATA_SECTION_NODE))
@@ -412,3 +389,31 @@ void HTMLTitleElementImpl::childrenChanged()
     if (inDocument())
 	getDocument()->setTitle(m_title);
 }
+
+DOMString HTMLTitleElementImpl::text()
+{
+    if (firstChild() && firstChild()->nodeType() == Node::TEXT_NODE) {
+        return firstChild()->nodeValue();
+    }
+    return "";
+}
+
+void HTMLTitleElementImpl::setText( const DOMString& str )
+{
+    int exceptioncode = 0;
+    // Look for an existing text child node
+    DOM::NodeListImpl* nl(childNodes());
+    if (nl)
+    {
+        for (unsigned int i = 0; i < nl->length(); i++) {
+            if (nl->item(i)->nodeType() == DOM::Node::TEXT_NODE) {
+                static_cast<DOM::TextImpl *>(nl->item(i))->setData(str, exceptioncode);
+                return;
+            }
+        }
+        delete nl;
+    }
+    // No child text node found, creating one
+    DOM::TextImpl* t = getDocument()->createTextNode(str.implementation());
+    appendChild(t, exceptioncode);
+}
