@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_listimpl.h,v 1.26.4.1 2003/01/03 21:09:27 mueller Exp $
+ * $Id: html_listimpl.h,v 1.26.4.2 2003/05/18 12:34:39 mueller Exp $
  */
 #ifndef HTML_LISTIMPL_H
 #define HTML_LISTIMPL_H
@@ -108,6 +108,6 @@ public:
     virtual Id id() const;
 };
 
-}; //namespace
+} //namespace
 
 #endif
