@@ -360,7 +360,7 @@ bool KHTMLParser::insertNode(NodeImpl *n, bool flat)
             break;
         case ID_HEAD:
             // ### alllow not having <HTML> in at all, as per HTML spec
-            if (!current->isDocumentNode() && !current->id() == ID_HTML )
+            if (!current->isDocumentNode() && current->id() != ID_HTML )
                 return false;
             break;
         case ID_META:
@@ -927,7 +927,7 @@ NodeImpl *KHTMLParser::getElement(Token* t)
 
 // images
     case ID_IMG:
-        n = new HTMLImageElementImpl(document);
+        n = new HTMLImageElementImpl(document, form);
         break;
     case ID_MAP:
         map = new HTMLMapElementImpl(document);
