@@ -24,7 +24,7 @@
 //----------------------------------------------------------------------------
 //
 // KDE HTML Widget -- HTML Parser
-// $Id: htmlparser.h,v 1.59.2.2 2003/01/13 22:04:48 mueller Exp $
+// $Id: htmlparser.h,v 1.59.2.3 2003/05/18 12:34:39 mueller Exp $
 
 #ifndef HTMLPARSER_H
 #define HTMLPARSER_H
@@ -55,7 +55,7 @@ namespace DOM {
     class HTMLMapElementImpl;
     class HTMLHeadElementImpl;
     class DocumentFragmentImpl;
-};
+}
 
 namespace khtml {
 
@@ -174,7 +174,7 @@ protected:
 #endif
 };
 
-}; // namespace khtml
+} // namespace khtml
 
 #endif // HTMLPARSER_H
 
