@@ -24,7 +24,7 @@
 //----------------------------------------------------------------------------
 //
 // KDE HTML Widget -- Tokenizers
-// $Id: htmltokenizer.h,v 1.62.2.2 2003/01/13 22:04:48 mueller Exp $
+// $Id: htmltokenizer.h,v 1.62.2.4 2003/06/24 21:34:00 faure Exp $
 
 #ifndef HTMLTOKENIZER_H
 #define HTMLTOKENIZER_H
@@ -79,7 +79,7 @@ namespace khtml {
             if(buffer->unicode())
                 a = new AttributeImpl(buffer->unicode(), v.implementation());
             else if ( !attrName.isEmpty() && attrName != "/" )
-                a = new AttributeImpl(doc->attrId(0, DOMString(attrName).implementation(), false),
+                a = new AttributeImpl(doc->attrId(0, DOMString(attrName).implementation(), false, 0),
                                       v.implementation());
 
             if (a) {
@@ -337,7 +337,7 @@ protected:
     KHTMLView *view;
 };
 
-}; // namespace
+} // namespace
 
 #endif // HTMLTOKENIZER
 
