@@ -37,7 +37,7 @@
  * the Applet class files, and set the proper size of the Applet.  It also
  * has an interface for applets to resize themselves.
  *
- * @version $Id: kjavaapplet.h,v 1.21.2.1 2003/01/04 01:25:18 vriezen Exp $
+ * @version $Id: kjavaapplet.h,v 1.21.2.2 2003/05/06 20:56:39 vriezen Exp $
  * @author Richard J. Moore, rich@kde.org
  * @author Wynn Wilkes, wynnw@kde.org
  */
@@ -91,6 +91,11 @@ public:
     KJavaApplet( KJavaAppletWidget* _parent, KJavaAppletContext* _context = 0 );
     ~KJavaApplet();
 
+    /**
+     * Set the applet context'.
+     */
+    void setAppletContext( KJavaAppletContext* _context );
+
     /**
      * Specify the name of the class file to run. For example 'Lake.class'.
      */
@@ -230,6 +235,24 @@ public:
     
     KJavaAppletContext* getContext() const { return context; }
     
+    /**
+     * Get/Set the user name
+     */
+    void setUser(const QString & _user) { username = _user; }
+    const QString & user () const { return username; }
+
+    /**
+     * Get/Set the user password
+     */
+    void setPassword(const QString & _password) { userpassword = _password; }
+    const QString & password () const { return userpassword; }
+
+    /**
+     * Get/Set the auth name
+     */
+    void setAuthName(const QString & _auth) { authname = _auth; }
+    const QString & authName () const { return authname; }
+
     /**
     * called from the protocol engine
     * changes the status according to the one on the java side.
@@ -248,6 +271,9 @@ private:
     KJavaAppletContext*    context;
     KJavaLiveConnect*      liveconnect;
     int                    id;
+    QString                username;
+    QString                userpassword;
+    QString                authname;
 };
 
 #endif // KJAVAAPPLET_H
