@@ -33,7 +33,7 @@
  * on contexts).  Currently, each document in KHTML creates one context, in
  * which multiple applets can run.
  *
- * @version $Id: kjavaappletcontext.h,v 1.17.2.1 2003/01/04 01:25:18 vriezen Exp $
+ * @version $Id: kjavaappletcontext.h,v 1.17.2.2 2003/05/06 20:56:39 vriezen Exp $
  * @author Richard J. Moore, rich@kde.org
  * @author Wynn Wilkes, wynnw@caldera.com
  */
@@ -69,7 +69,7 @@ public:
     /**
      * Sends a message to create the applet.
      */
-    void create( KJavaApplet* );
+    bool create( KJavaApplet* );
 
     /**
      * Sends a message to destroy the applet.
