@@ -24,15 +24,17 @@
 #include <kio/job.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <khtml_ext.h>
+#include "khtml_ext.h"
 #include <qwidget.h>
 
 KHTMLRun::KHTMLRun( KHTMLPart *part, khtml::ChildFrame *child, const KURL &url,
                     const KParts::URLArgs &args, bool hideErrorDialog )
     : KParts::BrowserRun( url, args, part, part->widget() ? part->widget()->topLevelWidget() : 0,
-                          false, false ),
-  m_child( child ), m_bHideErrorDialog( hideErrorDialog )
+                          false, false, hideErrorDialog ),
+  m_child( child )
 {
+    // get the wheel to start spinning
+    part->started(0L);
 }
 
 //KHTMLPart *KHTMLRun::htmlPart() const
@@ -40,6 +42,7 @@ KHTMLRun::KHTMLRun( KHTMLPart *part, khtml::ChildFrame *child, const KURL &url,
 
 void KHTMLRun::foundMimeType( const QString &_type )
 {
+    Q_ASSERT(!m_bFinished);
     QString mimeType = _type; // this ref comes from the job, we lose it when using KIO again
     if ( static_cast<KHTMLPart *>(m_part)->processObjectRequest( m_child, m_strURL, mimeType ) )
         m_bFinished = true;
@@ -51,6 +54,8 @@ void KHTMLRun::foundMimeType( const QString &_type )
         if ( res == KParts::BrowserRun::Delayed )
             return;
         m_bFinished = ( res == KParts::BrowserRun::Handled );
+        if ( m_bFinished ) // saved or canceled -> stop the wheel
+            emit static_cast<KHTMLPart *>(m_part)->canceled(QString::null);
     }
 
     if ( m_bFinished )
@@ -70,16 +75,18 @@ void KHTMLRun::save( const KURL & url, const QString & suggestedFilename )
 
 void KHTMLRun::handleError( KIO::Job *job )
 {
-    Q_ASSERT( job->error() ); // there's always an error if we're here
-    if ( m_bHideErrorDialog ) {
+    if ( hideErrorDialog() ) {
         // pass an empty url and mimetype to indicate a loading error
         static_cast<KHTMLPart *>(m_part)->processObjectRequest( m_child, KURL(), QString::null );
         m_job = 0;
         m_bFault = true;
         m_bFinished = true;
         m_timer.start( 0, true );
-    } else
+    } else {
+        Q_ASSERT( job );
+        Q_ASSERT( job->error() );
         KRun::slotScanFinished( job ); // standard "show the error dialog" code
+    }
 }
 
 #include "khtml_run.moc"
