@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_body.cpp,v 1.20.2.2 2003/01/13 22:04:48 mueller Exp $
+ * $Id: render_body.cpp,v 1.20.2.3 2003/02/04 08:15:04 mueller Exp $
  */
 #include "render_body.h"
 #include "render_root.h"
@@ -107,9 +107,9 @@ int RenderBody::availableHeight() const
     int h = RenderFlow::availableHeight();
 
     if( style()->marginTop().isFixed() )
-        h  -= style()->marginTop().value;
+        h  -= style()->marginTop().value();
     if( style()->marginBottom().isFixed() )
-        h -= style()->marginBottom().value;
+        h -= style()->marginBottom().value();
 
     return kMax(0, h);
 }
