@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_form.cpp,v 1.198.2.8 2003/01/18 20:02:52 mueller Exp $
+ * $Id: render_form.cpp,v 1.198.2.9 2003/05/20 06:18:31 staikos Exp $
  */
 
 #include <kdebug.h>
@@ -1232,7 +1232,7 @@ void RenderTextArea::calcMinMaxWidth()
     w->setTabStopWidth(8 * m.width(" "));
     QSize size( QMAX(element()->cols(), 1)*m.width('x') + w->frameWidth() +
                 w->verticalScrollBar()->sizeHint().width(),
-                QMAX(element()->rows(), 1)*m.height() + w->frameWidth()*2 +
+                QMAX(element()->rows(), 1)*m.lineSpacing() + w->frameWidth()*4 +
                 (w->wordWrap() == QTextEdit::NoWrap ?
                  w->horizontalScrollBar()->sizeHint().height() : 0)
         );
