@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_form.h,v 1.74.2.4 2003/01/18 01:09:31 mueller Exp $
+ * $Id: render_form.h,v 1.74.2.5 2003/05/18 12:34:40 mueller Exp $
  */
 #ifndef RENDER_FORM_H
 #define RENDER_FORM_H
@@ -53,7 +53,7 @@ namespace DOM {
     class HTMLSelectElementImpl;
     class HTMLGenericFormElementImpl;
     class HTMLTextAreaElementImpl;
-};
+}
 
 namespace khtml {
 
@@ -426,6 +426,6 @@ protected:
 
 // -------------------------------------------------------------------------
 
-}; //namespace
+} //namespace
 
 #endif
