@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_image.cpp,v 1.100.2.3 2003/02/04 08:15:05 mueller Exp $
+ * $Id: render_image.cpp,v 1.100.2.5 2003/04/19 16:53:04 mueller Exp $
  */
 //#define DEBUG_LAYOUT
 
@@ -113,7 +113,7 @@ void RenderImage::setPixmap( const QPixmap &p, const QRect& r, CachedImage *o)
             setIntrinsicHeight( ih );
             iwchanged = true;
         }
-        if ( element()->id() == ID_OBJECT ) {
+        if ( element() && element()->id() == ID_OBJECT ) {
             static_cast<HTMLObjectElementImpl*>(  element() )->renderAlternative();
             return;
         }
@@ -330,7 +330,9 @@ void RenderImage::notifyFinished(CachedObject *finishedObj)
 {
     if (image == finishedObj && !loadEventSent && element()) {
         loadEventSent = true;
-        element()->dispatchHTMLEvent(EventImpl::LOAD_EVENT,false,false);
+        element()->dispatchHTMLEvent(
+            image->isErrorImage() ? EventImpl::ERROR_EVENT : EventImpl::LOAD_EVENT,
+            false,false);
     }
 }
 
