@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_object.h,v 1.137.2.2 2003/01/13 22:13:19 mueller Exp $
+ * $Id: render_object.h,v 1.137.2.3 2003/05/18 12:34:40 mueller Exp $
  */
 #ifndef render_object_h
 #define render_object_h
@@ -56,7 +56,7 @@ namespace DOM {
     class NodeImpl;
     class ElementImpl;
     class EventImpl;
-};
+}
 
 namespace khtml {
     class RenderFlow;
@@ -495,5 +495,5 @@ enum VerticalPositionHint {
     PositionUndefined = 0x3fff
 };
 
-}; //namespace
+} //namespace
 #endif
