@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_replaced.cpp,v 1.105.2.3 2003/01/13 22:04:49 mueller Exp $
+ * $Id: render_replaced.cpp,v 1.105.2.4 2003/07/31 15:04:27 mueller Exp $
  */
 #include "render_replaced.h"
 #include "render_root.h"
@@ -166,7 +166,7 @@ RenderWidget::~RenderWidget()
 class QWidgetResizeEvent : public QEvent
 {
 public:
-    enum { Type = 0xfeedabee };
+    enum { Type = QEvent::User + 0xbee };
     QWidgetResizeEvent( int _w,  int _h ) :
 	QEvent( (QEvent::Type)Type ),  w( _w ), h( _h ) {}
     int w;
@@ -190,7 +190,7 @@ void  RenderWidget::resizeWidget( int w, int h )
 
 bool RenderWidget::event( QEvent *e )
 {
-    if ( m_widget && (e->type() == (int)QWidgetResizeEvent::Type) ) {
+    if ( m_widget && (e->type() == (QEvent::Type)QWidgetResizeEvent::Type) ) {
 	QWidgetResizeEvent *re = static_cast<QWidgetResizeEvent *>(e);
 	m_widget->resize( re->w,  re->h );
     }
