@@ -19,12 +19,12 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_text.cpp,v 1.180.2.7 2002/07/02 09:31:21 mueller Exp $
+ * $Id: render_text.cpp,v 1.195.2.1 2003/01/10 18:01:38 knoll Exp $
  */
+
 //#define DEBUG_LAYOUT
 //#define BIDI_DEBUG
 
-#include "rendering/render_root.h"
 #include "rendering/render_text.h"
 #include "rendering/render_root.h"
 #include "rendering/break_lines.h"
@@ -39,7 +39,7 @@
 using namespace khtml;
 using namespace DOM;
 
-void TextSlave::printSelection(const Font *f, RenderText *text, QPainter *p, RenderStyle* style, int tx, int ty, int startPos, int endPos)
+void TextSlave::paintSelection(const Font *f, RenderText *text, QPainter *p, RenderStyle* style, int tx, int ty, int startPos, int endPos)
 {
     if(startPos > m_len) return;
     if(startPos < 0) startPos = 0;
@@ -50,13 +50,13 @@ void TextSlave::printSelection(const Font *f, RenderText *text, QPainter *p, Ren
 
     ty += m_baseline;
 
-    //kdDebug( 6040 ) << "textSlave::printing(" << s.string() << ") at(" << x+_tx << "/" << y+_ty << ")" << endl;
+    //kdDebug( 6040 ) << "textSlave::painting(" << s.string() << ") at(" << x+_tx << "/" << y+_ty << ")" << endl;
     f->drawText(p, m_x + tx, m_y + ty, text->str->s, text->str->l, m_start, m_len,
 		m_toAdd, m_reversed ? QPainter::RTL : QPainter::LTR, startPos, endPos, c);
     p->restore();
 }
 
-void TextSlave::printDecoration( QPainter *pt, RenderText* p, int _tx, int _ty, int deco, bool begin, bool end)
+void TextSlave::paintDecoration( QPainter *pt, RenderText* p, int _tx, int _ty, int deco, bool begin, bool end)
 {
     _tx += m_x;
     _ty += m_y;
@@ -82,7 +82,7 @@ void TextSlave::printDecoration( QPainter *pt, RenderText* p, int _tx, int _ty,
     // support it. Lars
 }
 
-void TextSlave::printBoxDecorations(QPainter *pt, RenderStyle* style, RenderText *p, int _tx, int _ty, bool begin, bool end)
+void TextSlave::paintBoxDecorations(QPainter *pt, RenderStyle* style, RenderText *p, int _tx, int _ty, bool begin, bool end)
 {
     int topExtra = p->borderTop() + p->paddingTop();
     int bottomExtra = p->borderBottom() + p->paddingBottom();
@@ -103,7 +103,7 @@ void TextSlave::printBoxDecorations(QPainter *pt, RenderStyle* style, RenderText
     QColor c = style->backgroundColor();
     CachedImage *i = style->backgroundImage();
     if(c.isValid() && (!i || i->tiled_pixmap(c).mask()))
-         pt->fillRect(_tx, _ty, width, height, c);
+        pt->fillRect(_tx, _ty, width, height, c);
 
     if(i) {
         // ### might need to add some correct offsets
@@ -116,7 +116,7 @@ void TextSlave::printBoxDecorations(QPainter *pt, RenderStyle* style, RenderText
 #endif
 
     if(style->hasBorder())
-        p->printBorder(pt, _tx, _ty, width, height, style, begin, end);
+        p->paintBorder(pt, _tx, _ty, width, height, style, begin, end);
 }
 
 FindSelectionResult TextSlave::checkSelectionPoint(int _x, int _y, int _tx, int _ty, const Font *f, RenderText *text, int & offset, short lineHeight)
@@ -297,13 +297,13 @@ TextSlave * RenderText::findTextSlave( int offset, int &pos )
     TextSlave* s = m_lines[0];
     uint si = 0;
     int off = s->m_len;
-    while(offset > off && si < m_lines.count())
+    while(offset > off && ++si < m_lines.count())
     {
-        s = m_lines[++si];
+        s = m_lines[si];
         off = s->m_start + s->m_len;
     }
     // we are now in the correct text slave
-    pos = (offset > off ? s->m_len : s->m_len - (off - offset) );
+    pos = (offset > off ? s->m_len : offset - s->m_start );
     return s;
 }
 
@@ -318,16 +318,18 @@ bool RenderText::nodeAtPoint(NodeInfo& /*info*/, int _x, int _y, int _tx, int _t
                  borderBottom() + paddingBottom();
 
     bool inside = false;
-    TextSlave *s = m_lines.count() ? m_lines[0] : 0;
-    int si = 0;
-    while(s) {
-        if((_y >=_ty + s->m_y) && (_y < _ty + s->m_y + height) &&
-           (_x >= _tx + s->m_x) && (_x <_tx + s->m_x + s->m_width) ) {
-            inside = true;
-            break;
-        }
+    if (style()->visibility() != HIDDEN) {
+        TextSlave *s = m_lines.count() ? m_lines[0] : 0;
+        int si = 0;
+        while(s) {
+            if((_y >=_ty + s->m_y) && (_y < _ty + s->m_y + height) &&
+               (_x >= _tx + s->m_x) && (_x <_tx + s->m_x + s->m_width) ) {
+                inside = true;
+                break;
+            }
 
-        s = si < (int) m_lines.count()-1 ? m_lines[++si] : 0;
+            s = si < (int) m_lines.count()-1 ? m_lines[++si] : 0;
+        }
     }
 
     setMouseInside(inside);
@@ -355,7 +357,7 @@ FindSelectionResult RenderText::checkSelectionPoint(int _x, int _y, int _tx, int
             //kdDebug(6040) << "RenderText::checkSelectionPoint inside -> " << offset << endl;
             node = element();
             return SelectionPointInside;
-        } else if ( result == SelectionPointBefore ) {
+        } else if ( result == SelectionPointBefore || result == SelectionPointBeforeInLine ) {
             // x,y is before the textslave -> stop here
             if ( si > 0 && lastPointAfterInline ) {
                 offset = lastPointAfterInline->m_start + lastPointAfterInline->m_len;
@@ -427,28 +429,23 @@ bool RenderText::absolutePosition(int &xPos, int &yPos, bool)
     return false;
 }
 
-void RenderText::posOfChar(int chr, int &x, int &y)
+bool RenderText::posOfChar(int chr, int &x, int &y)
 {
     if (!parent())
-    {
-       x = -1;
-       y = -1;
-       return;
-    }
+        return false;
     parent()->absolutePosition( x, y, false );
 
-    //if( chr > (int) str->l )
-    //chr = str->l;
-
     int pos;
     TextSlave * s = findTextSlave( chr, pos );
 
-    if ( s )
-    {
+    if ( s ) {
         // s is the line containing the character
         x += s->m_x; // this is the x of the beginning of the line, but it's good enough for now
         y += s->m_y;
+        return true;
     }
+
+    return false;
 }
 
 int RenderText::rightmostPosition() const
@@ -459,24 +456,24 @@ int RenderText::rightmostPosition() const
     return 0;
 }
 
-void RenderText::printObject( QPainter *p, int /*x*/, int y, int /*w*/, int h,
+void RenderText::paintObject( QPainter *p, int /*x*/, int y, int /*w*/, int h,
                       int tx, int ty)
 {
     int ow = style()->outlineWidth();
-    RenderStyle* pseudoStyle = style()->getPseudoStyle(RenderStyle::FIRST_LINE);
+    RenderStyle* pseudoStyle = hasFirstLine() ? style()->getPseudoStyle(RenderStyle::FIRST_LINE) : 0;
     int d = style()->textDecoration();
     TextSlave f(0, y-ty);
     int si = m_lines.findFirstMatching(&f);
-    // something matching found, find the first one to print
+    // something matching found, find the first one to paint
     bool isPrinting = (p->device()->devType() == QInternal::Printer);
     if(si >= 0)
     {
-        // Move up until out of area to be printed
+        // Move up until out of area to be painted
         while(si > 0 && m_lines[si-1]->checkVerticalPoint(y, ty, h, m_lineHeight))
             si--;
 
-        // Now calculate startPos and endPos, for printing selection.
-        // We print selection while endPos > 0
+        // Now calculate startPos and endPos, for painting selection.
+        // We paint selection while endPos > 0
         int endPos, startPos;
         if (!isPrinting && (selectionState() != SelectionNone)) {
             if (selectionState() == SelectionInside) {
@@ -515,7 +512,7 @@ void RenderText::printObject( QPainter *p, int /*x*/, int y, int /*w*/, int h,
                 int lh = lineHeight( false ) + paddingBottom() + borderBottom();
                 if (ty+s->m_y < y)
                 {
-                   // This has been printed already we suppose.
+                   // This has been painted already we suppose.
                    continue;
                 }
 
@@ -536,11 +533,9 @@ void RenderText::printObject( QPainter *p, int /*x*/, int y, int /*w*/, int h,
 		font = &_style->htmlFont();
 	    }
 
-            if((hasSpecialObjects()  &&
-                (parent()->isInline() || pseudoStyle)) &&
-               (!pseudoStyle || s->m_firstLine))
-                s->printBoxDecorations(p, _style, this, tx, ty, si == 0, si == (int)m_lines.count()-1);
-
+            if ((pseudoStyle && s->m_firstLine) ||
+                (!pseudoStyle && hasSpecialObjects() && parent()->isInline()))
+                s->paintBoxDecorations(p, _style, this, tx, ty, si == 0, si == (int)m_lines.count()-1);
 
             if(_style->color() != p->pen().color())
                 p->setPen(_style->color());
@@ -552,16 +547,16 @@ void RenderText::printObject( QPainter *p, int /*x*/, int y, int /*w*/, int h,
             if(d != TDNONE)
             {
                 p->setPen(_style->textDecorationColor());
-                s->printDecoration(p, this, tx, ty, d, si == 0, si == ( int ) m_lines.count()-1);
+                s->paintDecoration(p, this, tx, ty, d, si == 0, si == ( int ) m_lines.count()-1);
             }
 
             if (!isPrinting && (selectionState() != SelectionNone)) {
 		int offset = s->m_start;
 		int sPos = QMAX( startPos - offset, 0 );
 		int ePos = QMIN( endPos - offset, s->m_len );
-                //kdDebug(6040) << this << " printSelection with startPos=" << sPos << " endPos=" << ePos << endl;
+                //kdDebug(6040) << this << " paintSelection with startPos=" << sPos << " endPos=" << ePos << endl;
 		if ( sPos < ePos )
-		    s->printSelection(font, this, p, _style, tx, ty, sPos, ePos);
+		    s->paintSelection(font, this, p, _style, tx, ty, sPos, ePos);
 
             }
             if(renderOutline) {
@@ -587,9 +582,9 @@ void RenderText::printObject( QPainter *p, int /*x*/, int y, int /*w*/, int h,
             {
                 int h = lineHeight( false ) + paddingTop() + paddingBottom() + borderTop() + borderBottom();
                 QColor c2 = QColor("#0000ff");
-                drawBorder(p, tx, ty, tx+1, ty + h,
+                drawBorder(p, tx + s->m_x, ty + s->m_y, tx + s->m_x + 1, ty + s->m_y + h,
                               RenderObject::BSLeft, c2, c2, SOLID, 1, 1);
-                drawBorder(p, tx + s->m_width, ty, tx + s->m_width + 1, ty + h,
+                drawBorder(p, tx + s->m_x + s->m_width, ty + s->m_y, tx + s->m_x + s->m_width + 1, ty + s->m_y + h,
                               RenderObject::BSRight, c2, c2, SOLID, 1, 1);
             }
 #endif
@@ -601,12 +596,12 @@ void RenderText::printObject( QPainter *p, int /*x*/, int y, int /*w*/, int h,
 	    linerects.append(new QRect(minx, outlinebox_y, maxx-minx, m_lineHeight));
 	    linerects.append(new QRect());
 	    for (unsigned int i = 1; i < linerects.count() - 1; i++)
-                printTextOutline(p, tx, ty, *linerects.at(i-1), *linerects.at(i), *linerects.at(i+1));
+                paintTextOutline(p, tx, ty, *linerects.at(i-1), *linerects.at(i), *linerects.at(i+1));
 	  }
     }
 }
 
-void RenderText::print( QPainter *p, int x, int y, int w, int h,
+void RenderText::paint( QPainter *p, int x, int y, int w, int h,
                       int tx, int ty)
 {
     if (style()->visibility() != VISIBLE) return;
@@ -618,7 +613,7 @@ void RenderText::print( QPainter *p, int x, int y, int w, int h,
     if ( ty + m_lines[0]->m_y > y + h + 64 ) return;
     if ( ty + m_lines[s]->m_y + m_lines[s]->m_baseline + m_lineHeight + 64 < y ) return;
 
-    printObject(p, x, y, w, h, tx, ty);
+    paintObject(p, x, y, w, h, tx, ty);
 }
 
 void RenderText::calcMinMaxWidth()
@@ -629,17 +624,22 @@ void RenderText::calcMinMaxWidth()
     m_minWidth = 0;
     m_maxWidth = 0;
 
-    int currMinWidth = 0;
-    int currMaxWidth = 0;
+    int add = (parent()->isInline() && parent()->firstChild()==this) ? paddingLeft() + borderLeft() : 0;
+
+    int currMinWidth = add;
+    int currMaxWidth = add;
     m_hasReturn = false;
     m_hasBreakableChar = false;
 
     // ### not 100% correct for first-line
     const Font *f = htmlFont( false );
     int len = str->l;
+    m_startMin = 0;
+    m_endMin = 0;
     bool isPre = style()->whiteSpace() == PRE;
     if ( len == 1 && str->s->latin1() == '\n' )
 	m_hasReturn = true;
+    bool first = true;
     for(int i = 0; i < len; i++)
     {
         int wordlen = 0;
@@ -647,26 +647,27 @@ void RenderText::calcMinMaxWidth()
             while( i+wordlen < len && str->s[i+wordlen] != '\n' )
                 wordlen++;
         else
-        while( i+wordlen < len && !(isBreakable( str->s, i+wordlen, str->l )) )
-            wordlen++;
+            while( i+wordlen < len && !(isBreakable( str->s, i+wordlen, str->l )) )
+                wordlen++;
 
         if (wordlen) {
             int w = f->width(str->s, str->l, i, wordlen);
             currMinWidth += w;
             currMaxWidth += w;
-        }
+        } else {
+	    first = false;
+	}
         if(i+wordlen < len) {
 	    m_hasBreakableChar = true;
-            if ( (*(str->s+i+wordlen)).latin1() == '\n' )
-            {
+            if ( (*(str->s+i+wordlen)).latin1() == '\n' ) {
 		m_hasReturn = true;
+		if ( first ) m_startMin = QMIN( currMinWidth, 0x1ff );
                 if(currMinWidth > m_minWidth) m_minWidth = currMinWidth;
                 currMinWidth = 0;
                 if(currMaxWidth > m_maxWidth) m_maxWidth = currMaxWidth;
                 currMaxWidth = 0;
-            }
-            else
-            {
+            } else {
+		if ( first ) m_startMin = QMIN( currMinWidth , 0x1ff );
                 if(currMinWidth > m_minWidth) m_minWidth = currMinWidth;
                 currMinWidth = 0;
                 currMaxWidth += f->width( str->s, str->l, i + wordlen );
@@ -678,14 +679,23 @@ void RenderText::calcMinMaxWidth()
                 currMinWidth = 0;
                 currMaxWidth += minus_width;
             }*/
+	    first = false;
         }
         i += wordlen;
     }
+    add = (parent()->isInline() && parent()->lastChild()==this) ? borderRight() + paddingRight() : 0;
+    currMinWidth += add;
+    currMaxWidth += add;
+    if ( first ) m_startMin = QMIN( currMinWidth, 0x1ff );
     if(currMinWidth > m_minWidth) m_minWidth = currMinWidth;
     if(currMaxWidth > m_maxWidth) m_maxWidth = currMaxWidth;
+    m_endMin = QMIN( currMinWidth , 0x1ff );
 
-    if (style()->whiteSpace() == NOWRAP)
+    if (style()->whiteSpace() == NOWRAP) {
+	m_startMin = QMIN( m_minWidth, 0x1ff );
+	m_endMin = m_startMin;
         m_minWidth = m_maxWidth;
+    }
 
     setMinMaxKnown();
     //kdDebug( 6040 ) << "Text::calcMinMaxWidth(): min = " << m_minWidth << " max = " << m_maxWidth << endl;
@@ -750,6 +760,7 @@ void RenderText::setText(DOMStringImpl *text, bool force)
     KHTMLAssert(!str->l || str->s);
 
     setLayouted(false);
+    setMinMaxKnown(false);
 #ifdef BIDI_DEBUG
     QConstString cstr(str->s, str->l);
     kdDebug( 6040 ) << "RenderText::setText( " << cstr.string().length() << " ) '" << cstr.string() << "'" << endl;
@@ -787,7 +798,9 @@ short RenderText::baselinePosition( bool firstLine ) const
 void RenderText::position(int x, int y, int from, int len, int width, bool reverse, bool firstLine, int spaceAdd)
 {
     // ### should not be needed!!!
-    assert(!(len == 0 || (str->l && len == 1 && *(str->s+from) == '\n') ));
+    // asserts sometimes with pre (that unibw-hamburg testcase). ### find out why
+    //KHTMLAssert(!(len == 0 || (str->l && len == 1 && *(str->s+from) == '\n') ));
+    if (len == 0 || (str->l && len == 1 && *(str->s+from) == '\n') ) return;
 
     reverse = reverse && !style()->visuallyOrdered();
 
@@ -804,7 +817,6 @@ void RenderText::position(int x, int y, int from, int len, int width, bool rever
 #ifdef DEBUG_LAYOUT
     QChar *ch = str->s+from;
     QConstString cstr(ch, len);
-    qDebug("setting slave text to *%s*, len=%d, w)=%d" , cstr.string().latin1(), len, width );//" << y << ")" << " height=" << lineHeight(false) << " fontHeight=" << metrics(false).height() << " ascent =" << metrics(false).ascent() << endl;
 #endif
 
     TextSlave *s = new TextSlave(x, y, from, len,
@@ -832,15 +844,23 @@ unsigned int RenderText::width(unsigned int from, unsigned int len, const Font *
     if ( from + len > str->l ) len = str->l - from;
 
     int w;
-    if ( f == &style()->htmlFont() && from == 0 && len == str->l )
+    if ( f == &style()->htmlFont() && from == 0 && len == str->l ) {
  	 w = m_maxWidth;
-    else
-	w = f->width(str->s, str->l, from, len );
+	 // m_maxWidth already contains borders and paddings.
+	 if(parent()->isInline()) {
+	     if( parent()->firstChild() == static_cast<const RenderObject*>(this) )
+		 w += marginLeft();
+	     if( parent()->lastChild() == static_cast<const RenderObject*>(this) )
+		 w += marginRight();
+	 }
+	 return w;
+    }
+
+    w = f->width(str->s, str->l, from, len );
 
     // ### add margins and support for RTL
 
-    if(parent()->isInline())
-    {
+    if(parent()->isInline()) {
         if(from == 0 && parent()->firstChild() == static_cast<const RenderObject*>(this))
             w += borderLeft() + paddingLeft() + marginLeft();
         if(from + len == str->l &&
@@ -919,7 +939,7 @@ const Font *RenderText::htmlFont(bool firstLine) const
     return f;
 }
 
-void RenderText::printTextOutline(QPainter *p, int tx, int ty, const QRect &lastline, const QRect &thisline, const QRect &nextline)
+void RenderText::paintTextOutline(QPainter *p, int tx, int ty, const QRect &lastline, const QRect &thisline, const QRect &nextline)
 {
   int ow = style()->outlineWidth();
   EBorderStyle os = style()->outlineStyle();
