@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom2_viewsimpl.h,v 1.5 2002/04/11 08:56:40 knoll Exp $
+ * $Id: dom2_viewsimpl.h,v 1.5.2.1 2003/05/18 12:34:40 mueller Exp $
  */
 
 #ifndef _DOM_ViewsImpl_h_
@@ -47,5 +47,5 @@ protected:
     DocumentImpl *m_document;
 };
 
-}; //namespace
+} //namespace
 #endif
