@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom_textimpl.h,v 1.53.4.1 2003/01/03 21:09:29 mueller Exp $
+ * $Id: dom_textimpl.h,v 1.53.4.2 2003/05/18 12:34:41 mueller Exp $
  */
 #ifndef _DOM_CharacterDataImpl_h_
 #define _DOM_CharacterDataImpl_h_
@@ -149,5 +149,5 @@ protected:
 
 
 
-}; //namespace
+} //namespace
 #endif
