@@ -177,27 +177,55 @@ void KDirOperator::resetCursor()
 
 void KDirOperator::insertViewDependentActions()
 {
-    // If we have a new view actionCollection(), insert its actions
-    //  into viewActionMenu.
+   // If we have a new view actionCollection(), insert its actions
+   // into viewActionMenu.
+  
+   if( !m_fileView )
+      return;
+       
+   if ( (viewActionMenu->popupMenu()->count() == 0) || 			// Not yet initialized or...
+        (viewActionCollection != m_fileView->actionCollection()) )	// ...changed since.
+   {
+      if (viewActionCollection)
+      {
+         disconnect( viewActionCollection, SIGNAL( inserted( KAction * )),
+               this, SLOT( slotViewActionAdded( KAction * )));
+         disconnect( viewActionCollection, SIGNAL( removed( KAction * )),
+               this, SLOT( slotViewActionRemoved( KAction * )));
+      }
+    
+      viewActionMenu->popupMenu()->clear();
+//      viewActionMenu->insert( shortAction );
+//      viewActionMenu->insert( detailedAction );
+//      viewActionMenu->insert( actionSeparator );
+      viewActionMenu->insert( myActionCollection->action( "short view" ) );
+      viewActionMenu->insert( myActionCollection->action( "detailed view" ) );
+      viewActionMenu->insert( actionSeparator );
+      viewActionMenu->insert( showHiddenAction );
+//      viewActionMenu->insert( myActionCollection->action( "single" ));
+      viewActionMenu->insert( separateDirsAction );
+      // Warning: adjust slotViewActionAdded() and slotViewActionRemoved()
+      // when you add/remove actions here!
 
-    if( m_fileView && viewActionCollection != m_fileView->actionCollection() )
-    {
-        viewActionCollection = m_fileView->actionCollection();
+      viewActionCollection = m_fileView->actionCollection();
+      if (!viewActionCollection)
+         return;
 
-        if ( !viewActionCollection->isEmpty() ) {
-            viewActionMenu->insert( d->viewActionSeparator );
+      if ( !viewActionCollection->isEmpty() ) 
+      {
+         viewActionMenu->insert( d->viewActionSeparator );
 
-            for ( uint i = 0; i < viewActionCollection->count(); i++ )
-                viewActionMenu->insert( viewActionCollection->action( i ));
-        }
+         for ( uint i = 0; i < viewActionCollection->count(); i++ )
+            viewActionMenu->insert( viewActionCollection->action( i ));
+      }
 
-        connect( viewActionCollection, SIGNAL( inserted( KAction * )),
-                 SLOT( slotViewActionAdded( KAction * )));
-        connect( viewActionCollection, SIGNAL( removed( KAction * )),
-                 SLOT( slotViewActionRemoved( KAction * )));
-    }
+      connect( viewActionCollection, SIGNAL( inserted( KAction * )),
+               SLOT( slotViewActionAdded( KAction * )));
+      connect( viewActionCollection, SIGNAL( removed( KAction * )),
+               SLOT( slotViewActionRemoved( KAction * )));
+   }
 }
-
+  
 void KDirOperator::activatedMenu( const KFileItem *, const QPoint& pos )
 {
     updateSelectionDependentActions();
@@ -1193,19 +1221,6 @@ void KDirOperator::setupMenu(int whichActions)
     sortActionMenu->insert( dirsFirstAction );
     sortActionMenu->insert( caseInsensitiveAction );
 
-    viewActionMenu->popupMenu()->clear();
-//     viewActionMenu->insert( shortAction );
-//     viewActionMenu->insert( detailedAction );
-//     viewActionMenu->insert( actionSeparator );
-    viewActionMenu->insert( myActionCollection->action( "short view" ) );
-    viewActionMenu->insert( myActionCollection->action( "detailed view" ) );
-    viewActionMenu->insert( actionSeparator );
-    viewActionMenu->insert( showHiddenAction );
-//    viewActionMenu->insert( myActionCollection->action( "single" ));
-    viewActionMenu->insert( separateDirsAction );
-    // Warning: adjust slotViewActionAdded() and slotViewActionRemoved()
-    // when you add/remove actions here!
-
     // now plug everything into the popupmenu
     actionMenu->popupMenu()->clear();
     if (whichActions & NavActions)
