@@ -1,21 +1,21 @@
 /* This file is part of the KDE libraries
- * Copyright (C) 2001, 2002 Rolf Magnus <ramagnus@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation version 2.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- *  $Id: kmetaprops.cpp,v 1.18.2.2 2002/04/13 01:55:13 nhasan Exp $
+    Copyright (C) 2001,2002 Rolf Magnus <ramagnus@kde.org>
+
+    library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License version 2 as published by the Free Software Foundation.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+    Boston, MA 02111-1307, USA.
+  
+    $Id: kmetaprops.cpp,v 1.26 2002/06/18 08:25:21 ramagnus Exp $
  */
 
 #include "kmetaprops.h"
@@ -34,8 +34,6 @@
 #include <qstylesheet.h>
 #include <qvgroupbox.h>
 
-#include <iostream.h>
-
 #undef Bool
 
 class MetaPropsScrollView : public QScrollView
@@ -115,6 +113,17 @@ void KFileMetaPropsPlugin::createLayout()
     if ( !d->m_info.isValid() || (d->m_info.preferredKeys()).isEmpty() )
         return;
 
+    // now get a list of groups
+    KFileMetaInfoProvider* prov = KFileMetaInfoProvider::self();
+    QStringList groupList = d->m_info.preferredGroups();
+
+    const KFileMimeTypeInfo* mtinfo = prov->mimeTypeInfo(d->m_info.mimeType());
+    if (!mtinfo) 
+    {
+        kdDebug(7034) << "no mimetype info there\n";
+        return;
+    }
+
     // let the dialog create the page frame
     QFrame* topframe = properties->dialog()->addPage(i18n("&Meta Info"));
     topframe->setFrameStyle(QFrame::NoFrame);
@@ -130,28 +139,26 @@ void KFileMetaPropsPlugin::createLayout()
     QVBoxLayout *toplayout = new QVBoxLayout(d->m_frame);
     toplayout->setSpacing(KDialog::spacingHint());
 
-    // now get a list of groups
-    KFileMetaInfoProvider* prov = KFileMetaInfoProvider::self();
-    QStringList groupList = d->m_info.preferredGroups();
-
-    const KFileMimeTypeInfo* mtinfo = prov->mimeTypeInfo(d->m_info.mimeType());
-    if (!mtinfo) kdDebug(7034) << "no mimetype info there\n";
-
-    for (QStringList::Iterator git=groupList.begin(); git!=groupList.end(); ++git)
+    for (QStringList::Iterator git=groupList.begin(); 
+            git!=groupList.end(); ++git)
     {
         kdDebug(7033) << *git << endl;
 
-        QStringList itemList=d->m_info.group(*git).preferredKeys();
+        QStringList itemList = d->m_info.group(*git).preferredKeys();
         if (itemList.isEmpty())
             continue;
 
-	    QGroupBox *groupBox = new QGroupBox(2, Qt::Horizontal, "", d->m_frame);
-    	toplayout->addWidget(groupBox);
+        QGroupBox *groupBox = new QGroupBox(2, Qt::Horizontal, 
+            QStyleSheet::escape(mtinfo->groupInfo(*git)->translatedName()), 
+            d->m_frame);
+
+        toplayout->addWidget(groupBox);
 
         QValueList<KFileMetaInfoItem> readItems;
         QValueList<KFileMetaInfoItem> editItems;
 
-        for (QStringList::Iterator iit = itemList.begin(); iit!=itemList.end(); ++iit)
+        for (QStringList::Iterator iit = itemList.begin(); 
+                iit!=itemList.end(); ++iit)
         {
             KFileMetaInfoItem item = d->m_info[*git][*iit];
             if ( !item.isValid() ) continue;
@@ -166,22 +173,22 @@ void KFileMetaPropsPlugin::createLayout()
 
         KFileMetaInfoWidget* w = 0L;
         // then first add the editable items to the layout
-        for (QValueList<KFileMetaInfoItem>::Iterator iit= editItems.begin(); iit!=editItems.end(); ++iit)
+        for (QValueList<KFileMetaInfoItem>::Iterator iit= editItems.begin(); 
+                iit!=editItems.end(); ++iit)
         {
             (new QLabel((*iit).translatedKey() + ":", groupBox));
-
             QValidator* val = mtinfo->createValidator(*git, (*iit).key());
             if (!val) kdDebug(7033) << "didn't get a validator for " << *git << "/" << (*iit).key() << endl;
             w = new KFileMetaInfoWidget(*iit, val, groupBox);
             d->m_editWidgets.append( w );
-            connect(w, SIGNAL(valueChanged(const QVariant&)),
-                    this, SIGNAL(changed()));
+            connect(w, SIGNAL(valueChanged(const QVariant&)), this, SIGNAL(changed()));
         }
 
         // and then the read only items
-        for (QValueList<KFileMetaInfoItem>::Iterator iit= readItems.begin(); iit!=readItems.end(); ++iit)
+        for (QValueList<KFileMetaInfoItem>::Iterator iit= readItems.begin(); 
+                iit!=readItems.end(); ++iit)
         {
-            (new QLabel((*iit).translatedKey()+ ":", groupBox));
+            (new QLabel((*iit).translatedKey() + ":", groupBox));
             (new KFileMetaInfoWidget(*iit, 0L, groupBox));
         }
     }
