@@ -94,7 +94,7 @@ namespace KNotify
             return KNotifyClient::None;
         }
     };
-};
+}
 
 
 int KNotifyDialog::configure( QWidget *parent, const char *name,
@@ -118,7 +118,7 @@ KNotifyDialog::KNotifyDialog( QWidget *parent, const char *name, bool modal,
 
     connect( this, SIGNAL( okClicked() ), m_notifyWidget, SLOT( save() ));
     connect( this, SIGNAL( applyClicked() ), m_notifyWidget, SLOT( save() ));
-};
+}
 
 KNotifyDialog::~KNotifyDialog()
 {
@@ -757,11 +757,9 @@ Event * KNotifyWidget::currentEvent()
 
 void KNotifyWidget::openSoundDialog( KURLRequester *requester )
 {
-    static bool init = true;
-    if ( !init )
-        return;
-
-    init = false;
+    // only need to init this once
+    requester->disconnect( SIGNAL( openFileDialog( KURLRequester * )),
+                           this, SLOT( openSoundDialog( KURLRequester * )));
 
     KFileDialog *fileDialog = requester->fileDialog();
     fileDialog->setCaption( i18n("Select Sound File") );
@@ -795,11 +793,9 @@ void KNotifyWidget::openSoundDialog( KURLRequester *requester )
 
 void KNotifyWidget::openLogDialog( KURLRequester *requester )
 {
-    static bool init = true;
-    if ( !init )
-        return;
-
-    init = false;
+    // only need to init this once
+    requester->disconnect( SIGNAL( openFileDialog( KURLRequester * )),
+                           this, SLOT( openLogDialog( KURLRequester * )));
 
     KFileDialog *fileDialog = requester->fileDialog();
     fileDialog->setCaption( i18n("Select Log File") );
@@ -810,11 +806,10 @@ void KNotifyWidget::openLogDialog( KURLRequester *requester )
 
 void KNotifyWidget::openExecDialog( KURLRequester *requester )
 {
-    static bool init = true;
-    if ( !init )
-        return;
+    // only need to init this once
+    requester->disconnect( SIGNAL( openFileDialog( KURLRequester * )),
+                           this, SLOT( openExecDialog( KURLRequester * )));
 
-    init = false;
 
     KFileDialog *fileDialog = requester->fileDialog();
     fileDialog->setCaption( i18n("Select File to Execute") );
@@ -977,9 +972,9 @@ void Application::reloadEvents( bool revertToDefaults )
                 // default to passive popups over plain messageboxes
                 int default_rep = kc->readNumEntry("default_presentation", 
                                                    0 | KNotifyClient::PassivePopup);
-                QString default_logfile = kc->readEntry("default_logfile");
-                QString default_soundfile = kc->readEntry("default_sound");
-                QString default_commandline = kc->readEntry("default_commandline");
+                QString default_logfile = kc->readPathEntry("default_logfile");
+                QString default_soundfile = kc->readPathEntry("default_sound");
+                QString default_commandline = kc->readPathEntry("default_commandline");
                 config->setGroup(*it);
                 e->dontShow = config->readNumEntry("nopresentation", 0 );
 
@@ -995,11 +990,11 @@ void Application::reloadEvents( bool revertToDefaults )
                 {
                     e->presentation = config->readNumEntry("presentation",
                                                            default_rep);
-                    e->logfile = config->readEntry("logfile",
+                    e->logfile = config->readPathEntry("logfile",
                                                    default_logfile);
-                    e->soundfile = config->readEntry("soundfile",
+                    e->soundfile = config->readPathEntry("soundfile",
                                                      default_soundfile);
-                    e->commandline = config->readEntry("commandline",
+                    e->commandline = config->readPathEntry("commandline",
                                                        default_commandline);
                 }
 
