@@ -62,6 +62,12 @@ int main(int argc, char **argv)
         qDebug("filename=%s",name.latin1());
     }
 
+    else if (argv1 == QString::fromLatin1("existingURL")) {
+        KURL url = KFileDialog::getExistingURL();
+        qDebug("URL=%s",url.url().latin1());
+        name1 = url.url();
+    }
+
     else if (argv1 == QString::fromLatin1("preview")) {
         KURL u =  KFileDialog::getImageOpenURL();
         qDebug("filename=%s", u.url().latin1());
@@ -93,8 +99,8 @@ int main(int argc, char **argv)
 
     else if (argv1 == QString::fromLatin1("save")) {
         KURL u = KFileDialog::getSaveURL();
-//          QString(QDir::homeDirPath() + QString::fromLatin1("/testfile")),
-//          QString::null, 0L);
+//        QString(QDir::homeDirPath() + QString::fromLatin1("/testfile")),
+//        QString::null, 0L);
         name1 = u.url();
     }
 
@@ -117,7 +123,7 @@ int main(int argc, char **argv)
 			QString::fromLatin1("*|All files\n"
 					    "*.lo *.o *.la|All libtool files"),
 			0, 0, true);
-//        dlg.setFilter( "*.kdevelop" );
+//    dlg.setFilter( "*.kdevelop" );
 	dlg.setMode( (KFile::Mode) (KFile::Files |
                                     KFile::Directory |
                                     KFile::ExistingOnly |
