@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: connection.cpp,v 1.47 2002/06/19 17:46:00 domi Exp $
+// $Id: connection.cpp,v 1.47.2.1 2003/02/12 00:43:57 pfeiffer Exp $
 
 #include <config.h>
 
@@ -81,8 +81,8 @@ void Connection::close()
     notifier = 0;
     delete socket;
     socket = 0;
-    if (f_out)
-       fclose(f_out);
+//    if (f_out) // causes double close, as KSocket already closed it for us
+//       fclose(f_out);
     f_out = 0;
     fd_in = -1;
     tasks.clear();
