@@ -26,26 +26,42 @@
 #include <pwd.h>
 #include <assert.h>
 
+#include <qptrlist.h>
+#include <qptrstack.h>
+#include <qvaluestack.h>
+#include <qmap.h>
 #include <qcstring.h>
 #include <qdir.h>
 #include <qfile.h>
-#include <kdebug.h>
-#include <kurl.h>
-#include <kmimetype.h>
 
+#include <kdebug.h>
 #include <kfilterdev.h>
 #include <kfilterbase.h>
 
 #include "karchive.h"
+#include "klimitediodevice.h"
 
 template class QDict<KArchiveEntry>;
 
+
 class KArchive::KArchivePrivate
 {
 public:
     KArchiveDirectory* rootDir;
 };
 
+class PosSortedPtrList : public QPtrList<KArchiveFile> {
+protected:
+    int compareItems( QPtrCollection::Item i1,
+                      QPtrCollection::Item i2 )
+    {
+        int pos1 = static_cast<KArchiveFile*>( i1 )->position();
+        int pos2 = static_cast<KArchiveFile*>( i2 )->position();
+        return ( pos1 - pos2 );
+    }
+};
+
+
 ////////////////////////////////////////////////////////////////////////
 /////////////////////////// KArchive ///////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
@@ -90,14 +106,15 @@ void KArchive::close()
 {
     if ( !m_open )
         return;
+    // moved by holger to allow kzip to write the zip central dir
+    // to the file in closeArchive()
+    closeArchive();
 
     m_dev->close();
-    //m_dirList.clear();
 
     delete d->rootDir;
     d->rootDir = 0;
     m_open = false;
-    closeArchive();
 }
 
 const KArchiveDirectory* KArchive::directory() const
@@ -268,85 +285,20 @@ QByteArray KArchiveFile::data() const
   return arr;
 }
 
-/**
- * A readonly device that reads from an underlying device
- * from a given point to another (e.g. to give access to a single
- * file inside an archive)
- * @author David Faure <david@mandrakesoft.com>
- */
-class KLimitedIODevice : public QIODevice
-{
-public:
-    /**
-     * @param dev the underlying device, opened or not
-     * This device itself auto-opens (in readonly mode), no need to open it.
-     */
-    KLimitedIODevice( QIODevice *dev, int start, int length )
-        : m_dev( dev ), m_start( start ), m_length( length )
-    {
-        //kdDebug(7005) << "KLimitedIODevice::KLimitedIODevice start=" << start << " length=" << length << endl;
-        setType( IO_Direct ); // we support sequential too, but then atEnd() tries getch/ungetch !
-        open( IO_ReadOnly );
-    }
-    virtual ~KLimitedIODevice() {}
-
-    virtual bool open( int m ) {
-        //kdDebug(7005) << "KLimitedIODevice::open m=" << m << endl;
-        if ( m & IO_ReadOnly ) {
-            /*bool ok = false;
-            if ( m_dev->isOpen() )
-                ok = ( m_dev->mode() == IO_ReadOnly );
-            else
-                ok = m_dev->open( m );
-            if ( ok )*/
-                m_dev->at( m_start ); // No concurrent access !
-        }
-        else
-            kdWarning(7005) << "KLimitedIODevice::open only supports IO_ReadOnly!" << endl;
-        setState( IO_Open );
-        setMode( m );
-        return true;
-    }
-    virtual void close() {}
-    virtual void flush() {}
-
-    virtual Offset size() const { return m_length; }
-
-    virtual Q_LONG readBlock ( char * data, Q_ULONG maxlen )
-    {
-        maxlen = QMIN( maxlen, m_length - at() ); // Apply upper limit
-        return m_dev->readBlock( data, maxlen );
-    }
-    virtual Q_LONG writeBlock ( const char *, Q_ULONG ) { return -1; } // unsupported
-    virtual int putch( int ) { return -1; } // unsupported
-
-    virtual int getch() {
-        char c[2];
-        if ( readBlock(c, 1) == -1)
-            return -1;
-        else
-            return c[0];
-    }
-    virtual int ungetch( int c ) { return m_dev->ungetch(c); } // ## apply lower limit ?
-    virtual Offset at() const { return m_dev->at() - m_start; }
-    virtual bool at( Offset pos ) {
-        Q_ASSERT( pos <= m_length );
-        pos = QMIN( pos, m_length ); // Apply upper limit
-        return m_dev->at( m_start + pos );
-    }
-    virtual bool atEnd() const { return m_dev->at() >= m_start + m_length; }
-private:
-    QIODevice* m_dev;
-    Q_ULONG m_start;
-    Q_ULONG m_length;
-};
-
-
+// ** This should be a virtual method, and this code should be in ktar.cpp
 QIODevice *KArchiveFile::device() const
 {
     return new KLimitedIODevice( archive()->device(), m_pos, m_size );
 }
 
+void KArchiveFile::copyTo(const QString& dest) const
+{
+  QFile f( dest + "/"  + name() );
+  f.open( IO_ReadWrite | IO_Truncate );
+  f.writeBlock( data() );
+  f.close();
+}
+
 ////////////////////////////////////////////////////////////////////////
 //////////////////////// KArchiveDirectory /////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
@@ -416,9 +368,65 @@ const KArchiveEntry* KArchiveDirectory::entry( QString name ) const
 
 void KArchiveDirectory::addEntry( KArchiveEntry* entry )
 {
+  Q_ASSERT( !entry->name().isEmpty() );
   m_entries.insert( entry->name(), entry );
 }
 
+void KArchiveDirectory::copyTo(const QString& dest, bool recursiveCopy ) const
+{
+  QDir root;
+
+  PosSortedPtrList fileList;
+  QMap<int, QString> fileToDir;
+
+  QStringList::Iterator it;
+
+  // placeholders for iterated items
+  KArchiveDirectory* curDir;
+  QString curDirName;
+
+  QStringList dirEntries;
+  KArchiveEntry* curEntry;
+  KArchiveFile* curFile;
+
+
+  QPtrStack<KArchiveDirectory> dirStack;
+  QValueStack<QString> dirNameStack;
+
+  dirStack.push( this );     // init stack at current directory
+  dirNameStack.push( dest ); // ... with given path
+  do {
+    curDir = dirStack.pop();
+    curDirName = dirNameStack.pop();
+    root.mkdir(curDirName);
+
+    dirEntries = curDir->entries();
+    for ( it = dirEntries.begin(); it != dirEntries.end(); ++it ) {
+      curEntry = curDir->entry(*it);
+      if ( curEntry->isFile() ) {
+        curFile = dynamic_cast<KArchiveFile*>( curEntry );
+        fileList.append( curFile );
+        fileToDir.insert( curFile->position(), curDirName );
+      }
+
+      if ( curEntry->isDirectory() )
+        if ( recursiveCopy ) {
+          dirStack.push( dynamic_cast<KArchiveDirectory*>( curEntry ) );
+          dirNameStack.push( curDirName + "/" + curEntry->name() );
+        }
+    }
+  } while (!dirStack.isEmpty());
+
+  fileList.sort();  // sort on m_pos, so we have a linear access
+
+  KArchiveFile* f;
+  for ( f = fileList.first(); f; f = fileList.next() ) {
+    int pos = f->position();
+    f->copyTo( fileToDir[pos] );
+  }
+}
+
+
 void KArchive::virtual_hook( int, void* )
 { /*BASE::virtual_hook( id, data );*/ }
 
