@@ -3,7 +3,7 @@
 * kimgio.h -- Implementation of interface to the KDE Image IO library.
 * Sirtaj Singh Kang <taj@kde.org>, 23 Sep 1998.
 *
-* $Id: kimageio.cpp,v 1.33 2002/09/04 20:26:43 tjansen Exp $
+* $Id: kimageio.cpp,v 1.33.2.1 2003/06/29 21:43:01 deller Exp $
 *
 * This library is distributed under the conditions of the GNU LGPL.
 */
@@ -48,8 +48,8 @@ KImageIOFormat::KImageIOFormat( const QString &path)
    mSuffices = config.readListEntry("Suffices");
    mPattern = config.readEntry("Name");
    mMimetype = config.readEntry("Mimetype");
-   mLib = config.readEntry("Library");
-   rPaths = config.readListEntry("rPaths");
+   mLib = config.readPathEntry("Library");
+   rPaths = config.readPathListEntry("rPaths");
 }
 
 KImageIOFormat::KImageIOFormat( QDataStream& _str, int offset) :
