@@ -1,5 +1,5 @@
 /*
- * $Id: tcpslavebase.cpp,v 1.116.2.2 2003/01/10 04:28:24 staikos Exp $
+ * $Id: tcpslavebase.cpp,v 1.116.2.3 2003/05/27 01:34:53 staikos Exp $
  *
  * Copyright (C) 2000 Alex Zepeda <zipzippy@sonic.net
  * Copyright (C) 2001 George Staikos <staikos@kde.org>
@@ -980,24 +980,22 @@ int TCPSlaveBase::verifyCertificate()
              setMetaData("ssl_action", "accept");
              rc = 1;
              cp = KSSLCertificateCache::Accept;
-             d->cc->addHost(pc, ourHost);
-                result = messageBox( WarningYesNo,
+             result = messageBox( WarningYesNo,
                                i18n("Would you like to accept this "
                                     "certificate forever without "
                                     "being prompted?"),
                                i18n("Server Authentication"),
                                i18n("&Forever"),
                                i18n("&Current Sessions Only"));
-                if (result == KMessageBox::Yes)
-                   permacache = true;
-                else
-                   permacache = false;
+             permacache = (result == KMessageBox::Yes);
+             d->cc->addCertificate(pc, cp, permacache);
+             d->cc->addHost(pc, ourHost);
           } else {
              setMetaData("ssl_action", "reject");
              rc = -1;
              cp = KSSLCertificateCache::Prompt;
+             d->cc->addCertificate(pc, cp, permacache);
           }
-          d->cc->addCertificate(pc, cp, permacache);
         }
       }
     }
