@@ -38,7 +38,7 @@ KSSLKeyGen::KSSLKeyGen(QWidget *parent, const char *name, bool modal)
 :KWizard(parent,name,modal) {
 	_idx = -1;
 
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
 	page1 = new KGWizardPage1(this, "Wizard Page 1");
 	addPage(page1, i18n("KDE Certificate Request"));
 	page2 = new KGWizardPage2(this, "Wizard Page 2");
@@ -70,7 +70,7 @@ void KSSLKeyGen::slotGenerate() {
 
 // FOR NOW, it's DISABLED
 
-	KMessageBox::sorry(NULL, i18n("Sorry, certificate request generation has been disabled for this release due to incomplete code."), i18n("KDE SSL Information"));
+	KMessageBox::sorry(NULL, i18n("Certificate request generation has been disabled for this release due to incomplete code."), i18n("KDE SSL Information"));
 	return;
 
 
@@ -92,12 +92,12 @@ void KSSLKeyGen::slotGenerate() {
 		return;
 	}
 
-	int rc = generateCSR("This CSR", page2->_password1->text(), bits, 0x10001);
+	generateCSR("This CSR", page2->_password1->text(), bits, 0x10001);
 }
 
 
 int KSSLKeyGen::generateCSR(QString name, QString pass, int bits, int e) {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
 KOSSL *kossl = KOSSL::self();
 X509_REQ *req;
 int rc;
@@ -150,12 +150,12 @@ return -1;
 QStringList KSSLKeyGen::supportedKeySizes() {
 QStringList x;
 
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
    x << "1024"
      << "768"
      << "512";
 #else
-   x << i18n("Sorry, no SSL support.");
+   x << i18n("No SSL support.");
 #endif
 
 return x;
