@@ -1,4 +1,4 @@
-// $Id: file.cc,v 1.124.2.4 2003/02/06 22:43:20 binner Exp $
+// $Id: file.cc,v 1.124.2.5 2003/07/24 11:01:43 waba Exp $
 
 #include <config.h>
 
@@ -686,7 +686,7 @@ bool FileProtocol::createUDSEntry( const QString & filename, const QCString & pa
             }
 
             atom.m_uds = KIO::UDS_LINK_DEST;
-            atom.m_str = QString::fromLocal8Bit( buffer2 );
+            atom.m_str = QFile::decodeName( buffer2 );
             entry.append( atom );
 
             // A symlink -> follow it only if details>1
