@@ -17,7 +17,7 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: array_object.h,v 1.16 2002/06/19 08:20:59 domi Exp $
+ *  $Id: array_object.h,v 1.16.2.1 2003/05/17 11:19:24 mueller Exp $
  */
 
 #ifndef _ARRAY_OBJECT_H_
@@ -79,6 +79,6 @@ namespace KJS {
 
   };
 
-}; // namespace
+} // namespace
 
 #endif
