@@ -17,7 +17,7 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: error_object.h,v 1.10 2002/06/19 08:20:59 domi Exp $
+ *  $Id: error_object.h,v 1.10.2.1 2003/05/17 11:19:24 mueller Exp $
  */
 
 #ifndef _ERROR_OBJECT_H_
@@ -84,6 +84,6 @@ namespace KJS {
     ObjectImp *proto;
   };
 
-}; // namespace
+} // namespace
 
 #endif
