@@ -4,21 +4,21 @@
  *  Copyright (C) 1999-2000 Harri Porten (porten@kde.org)
  *
  *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
+ *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
  *  version 2 of the License, or (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
  *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
  *
- *  $Id: lexer.cpp,v 1.43.2.1 2002/06/10 08:19:26 porten Exp $
+ *  $Id: lexer.cpp,v 1.47 2002/11/19 22:47:27 faure Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -180,6 +180,15 @@ int Lexer::lex()
         skipCR = false;
         shift(1);
     }
+
+    bool cr = (current == '\r');
+    bool lf = (current == '\n');
+    if (cr)
+      skipLF = true;
+    else if (lf)
+      skipCR = true;
+    bool isLineTerminator = cr || lf;
+
     switch (state) {
     case Start:
       if (isWhiteSpace()) {
@@ -198,7 +207,7 @@ int Lexer::lex()
           setDone(Other);
         } else
           setDone(Eof);
-      } else if (isLineTerminator()) {
+      } else if (isLineTerminator) {
         nextLine();
         terminator = true;
         if (restrKeyword) {
@@ -245,7 +254,7 @@ int Lexer::lex()
       if (current == stringType) {
         shift(1);
         setDone(String);
-      } else if (current == 0 || isLineTerminator()) {
+      } else if (current == 0 || isLineTerminator) {
         setDone(Bad);
       } else if (current == '\\') {
         state = InEscapeSequence;
@@ -310,7 +319,7 @@ int Lexer::lex()
       }
       break;
     case InSingleLineComment:
-      if (isLineTerminator()) {
+      if (isLineTerminator) {
         nextLine();
         terminator = true;
         if (restrKeyword) {
@@ -325,7 +334,7 @@ int Lexer::lex()
     case InMultiLineComment:
       if (current == 0) {
         setDone(Bad);
-      } else if (isLineTerminator()) {
+      } else if (isLineTerminator) {
         nextLine();
       } else if (current == '*' && next1 == '/') {
         state = Start;
@@ -512,8 +521,11 @@ int Lexer::lex()
 
     eatNextIdentifier = false;
     // Hack for "f = function somename() { ... }", too hard to get into the grammar
-    if (token == FUNCTION && lastToken == '=' )
-      eatNextIdentifier = true;
+    // Same for building an array with function pointers ( 'name', func1, 'name2', func2 )
+    // There are lots of other uses, we really have to get this into the grammar
+    if ( token == FUNCTION &&
+         ( lastToken == '=' || lastToken == ',' ) )
+            eatNextIdentifier = true;
 
     if (token == CONTINUE || token == BREAK ||
         token == RETURN || token == THROW)
@@ -528,7 +540,7 @@ int Lexer::lex()
     token = NUMBER;
     break;
   case Bad:
-    fprintf(stderr, "yylex: ERROR.\n");
+    fprintf(stderr, "KJS: yylex: ERROR.\n");
     return -1;
   default:
     assert(!"unhandled numeration value in switch");
@@ -544,17 +556,6 @@ bool Lexer::isWhiteSpace() const
           current == 0x0b || current == 0x0c);
 }
 
-bool Lexer::isLineTerminator()
-{
-  bool cr = (current == '\r');
-  bool lf = (current == '\n');
-  if (cr)
-      skipLF = true;
-  else if (lf)
-      skipCR = true;
-  return cr || lf;
-}
-
 bool Lexer::isIdentLetter(unsigned short c)
 {
   /* TODO: allow other legitimate unicode chars */
@@ -786,7 +787,7 @@ bool Lexer::scanRegExp()
   bool inBrackets = false;
 
   while (1) {
-    if (isLineTerminator() || current == 0)
+    if (current == '\r' || current == '\n' || current == 0)
       return false;
     else if (current != '/' || lastWasEscape == true || inBrackets == true)
     {
