@@ -18,7 +18,7 @@
  *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
  *
- *  $Id: lexer.h,v 1.22 2002/11/21 09:33:56 faure Exp $
+ *  $Id: lexer.h,v 1.22.2.1 2003/05/17 11:19:24 mueller Exp $
  */
 
 #ifndef _KJSLEXER_H_
@@ -137,6 +137,6 @@ namespace KJS {
     LexerPrivate *priv;
   };
 
-}; // namespace
+} // namespace
 
 #endif
