@@ -17,7 +17,7 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: number_object.cpp,v 1.21 2002/01/28 13:03:05 porten Exp $
+ *  $Id: number_object.cpp,v 1.24 2002/10/24 17:03:16 faure Exp $
  */
 
 #include "value.h"
@@ -83,11 +83,7 @@ Value NumberProtoFuncImp::call(ExecState *exec, Object &thisObj, const List &/*a
   Value result;
 
   // no generic function. "this" has to be a Number object
-  if (!thisObj.inherits(&NumberInstanceImp::info)) {
-    Object err = Error::create(exec,TypeError);
-    exec->setException(err);
-    return err;
-  }
+  KJS_CHECK_THIS( NumberInstanceImp, thisObj );
 
   // execute "toString()" or "valueOf()", respectively
   Value v = thisObj.internalValue();
