@@ -4,16 +4,16 @@
  *  Copyright (C) 1999-2000 Harri Porten (porten@kde.org)
  *
  *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
+ *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
  *  version 2 of the License, or (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
  *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
@@ -33,6 +33,11 @@
 #include <math.h>
 #include <stdlib.h>
 
+// For declaration of isinf on Sun C++
+#ifdef __SUNPRO_CC
+#include <sunmath.h>
+#endif
+
 #ifndef HAVE_FUNC_ISINF
 #ifdef HAVE_IEEEFP_H
 #include <ieeefp.h>
@@ -244,17 +249,17 @@ Value KJS::add(ExecState *exec, const Value &v1, const Value &v2, char oper)
 // ECMA 11.5
 Value KJS::mult(ExecState *exec, const Value &v1, const Value &v2, char oper)
 {
-  Number n1 = v1.toNumber(exec);
-  Number n2 = v2.toNumber(exec);
+  double n1 = v1.toNumber(exec);
+  double n2 = v2.toNumber(exec);
 
   double result;
 
   if (oper == '*')
-    result = n1.value() * n2.value();
+    result = n1 * n2;
   else if (oper == '/')
-    result = n1.value() / n2.value();
+    result = n1 / n2;
   else
-    result = fmod(n1.value(), n2.value());
+    result = fmod(n1, n2);
 
   return Number(result);
 }
