@@ -18,7 +18,7 @@
  *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
  *
- *  $Id: property_map.h,v 1.8 2002/06/19 08:21:00 domi Exp $
+ *  $Id: property_map.h,v 1.8.2.1 2003/05/17 11:19:25 mueller Exp $
  */
 
 
@@ -98,6 +98,6 @@ namespace KJS {
 
   int uscompare(const UString &s1, const UString &s2);
 
-}; // namespace
+} // namespace
 
 #endif // _KJS_PROPERTY_MAP_H_
