@@ -30,6 +30,7 @@
 #include "regexp.h"
 #include "regexp_object.h"
 #include "error_object.h"
+#include "lookup.h"
 
 using namespace KJS;
 
@@ -69,11 +70,7 @@ bool RegExpProtoFuncImp::implementsCall() const
 
 Value RegExpProtoFuncImp::call(ExecState *exec, Object &thisObj, const List &args)
 {
-  if (!thisObj.inherits(&RegExpImp::info)) {
-    Object err = Error::create(exec,TypeError);
-    exec->setException(err);
-    return err;
-  }
+  KJS_CHECK_THIS( RegExpImp, thisObj );
 
   RegExpImp *reimp = static_cast<RegExpImp*>(thisObj.imp());
   RegExp *re = reimp->regExp();
@@ -85,6 +82,8 @@ Value RegExpProtoFuncImp::call(ExecState *exec, Object &thisObj, const List &arg
   {
     s = args[0].toString(exec);
     int length = s.value().size();
+
+    // Get values from the last time (in case of /g)
     Value lastIndex = thisObj.get(exec,"lastIndex");
     int i = lastIndex.isNull() ? 0 : lastIndex.toInt32(exec);
     bool globalFlag = thisObj.get(exec,"global").toBoolean(exec);
