@@ -305,7 +305,7 @@ void BrowserRun::simpleSave( const KURL & url, const QString & suggestedFilename
     // the empty key  means no integration
     KConfig cfg("konquerorrc", false, false);
     cfg.setGroup("HTML Settings");
-    QString downloadManger = cfg.readEntry("DownloadManager");
+    QString downloadManger = cfg.readPathEntry("DownloadManager");
     if (!downloadManger.isEmpty())
     {
         // then find the download manager location
@@ -324,8 +324,10 @@ void BrowserRun::simpleSave( const KURL & url, const QString & suggestedFilename
             // ### suggestedFilename not taken into account. Fix this (and
             // the duplicated code) with shiny new KDownload class for 3.2
             // (pfeiffer)
-            cmd += " " + KProcess::quote(url.url());
-            kdDebug(1000) << "Calling command  "<<cmd<<endl;
+            // Until the shiny new class comes about, send the suggestedFilename
+            // along with the actual URL to download. (DA)
+            cmd += " " + KProcess::quote(url.url()) + " " + KProcess::quote(suggestedFilename);
+            kdDebug(1000) << "Calling command  " << cmd << endl;
             // slave is already on hold (slotBrowserMimetype())
             KIO::Scheduler::publishSlaveOnHold();
             KRun::runCommand(cmd);
