@@ -54,7 +54,7 @@ Part *Factory::createPartObject( QWidget *, const char *, QObject *, const char
 
 QObject *Factory::createObject( QObject *parent, const char *name, const char *classname, const QStringList &args )
 {
-  assert( parent->isWidgetType() );
+  assert( !parent || parent->isWidgetType() );
   return createPart( static_cast<QWidget *>( parent ), name, parent, name, classname, args );
 }
 #include "factory.moc"
