@@ -52,7 +52,8 @@ enum Encoding {
 
 enum KSpellClients {
   KS_CLIENT_ISPELL=0,
-  KS_CLIENT_ASPELL=1
+  KS_CLIENT_ASPELL=1,
+  KS_CLIENT_HSPELL=2
 };
 
 /**
@@ -72,7 +73,7 @@ enum KSpellClients {
  * writing papers in their word processor.
  *
  * @author David Sweet <dsweet@kde.org>
- * @version $Id: ksconfig.h,v 1.37 2002/04/20 13:52:25 mlaurent Exp $
+ * @version $Id: ksconfig.h,v 1.37.2.1 2003/04/25 08:38:42 livne Exp $
  * @see KSpell
  */
 
