@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kspell.cpp,v 1.97.2.1 2003/02/17 05:52:56 wheeler Exp $
+// $Id: kspell.cpp,v 1.97.2.2 2003/04/25 08:38:42 livne Exp $
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -129,7 +129,7 @@ KSpell::KSpell (QWidget *_parent, const QString &_caption,
       codec = QTextCodec::codecForName("ISO 8859-7");
       break;
   case KS_E_LATIN8:
-      codec = QTextCodec::codecForName("ISO 8859-8");
+      codec = QTextCodec::codecForName("ISO 8859-8-i");
       break;
   case KS_E_LATIN9:
       codec = QTextCodec::codecForName("ISO 8859-9");
@@ -216,8 +216,14 @@ KSpell::startIspell()
       *proc << "aspell";
       kdDebug(750) << "Using aspell" << endl;
       break;
+    case KS_CLIENT_HSPELL:
+      *proc << "hspell";
+      kdDebug(750) << "Using hspell" << endl;
+      break;
     }
   // TODO: add option -h to ignore HTML (XML) code
+  if (ksconfig->client() == KS_CLIENT_ISPELL || ksconfig->client() == KS_CLIENT_ASPELL)
+  {
   *proc << "-a" << "-S";
   if (ksconfig->noRootAffix())
     {
@@ -298,6 +304,10 @@ KSpell::startIspell()
 
   // -a : pipe mode
   // -S : sort suggestions by probable correctness
+  } 
+  else       // hspell doesn't need all the rest of the options
+    *proc << "-a";
+
   if (trystart==0) //don't connect these multiple times
     {
       connect (proc, SIGNAL (  receivedStderr (KProcess *, char *, int)),
