@@ -17,7 +17,7 @@
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 */
-// $Id: gradients.h,v 1.2 2002/07/17 14:26:30 orlovich Exp $
+// $Id: gradients.h,v 1.2.2.2 2003/06/22 02:40:55 orlovich Exp $
 
 #ifndef KERAMIK_GRADIENTS_H
 #define KERAMIK_GRADIENTS_H
@@ -30,9 +30,12 @@ namespace Keramik
 	class GradientPainter
 	{
 	public:
-		static void renderGradient( QPainter* p, const QRect& r, QColor cr, bool horizontal, bool menu = false,
-													int px = 0, int py = 0, int pwidth = -1, int pheight = -1 );
+		static void renderGradient( QPainter* p, const QRect& r, QColor cr, 
+					    bool horizontal, bool menu = false,
+					    int px = 0, int py = 0, int pwidth = -1, int pheight = -1 );
+					    
+		static void releaseCache();
 	};
-};
+}
 
 #endif
