@@ -1,6 +1,6 @@
 /* Keramik Style for KDE3
    Copyright (c) 2002 Malte Starostik <malte@kde.org>
-             (c) 2002 Maksim Orlovich <mo002j@mail.rochester.edu>
+             (c) 2002,2003 Maksim Orlovich <mo002j@mail.rochester.edu>
 
    based on the KDE3 HighColor Style
 
@@ -30,7 +30,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: keramik.cpp,v 1.88.2.2 2003/02/22 18:10:58 orlovich Exp $
+// $Id: keramik.cpp,v 1.88.2.9 2003/08/01 01:12:54 orlovich Exp $
 
 #include <qbitmap.h>
 #include <qcheckbox.h>
@@ -64,6 +64,8 @@
 #include "bitmaps.h"
 #include "pixmaploader.h"
 
+#define loader Keramik::PixmapLoader::the()
+
 // -- Style Plugin Interface -------------------------
 class KeramikStylePlugin : public QStylePlugin
 {
@@ -81,7 +83,7 @@ public:
 
 	QStyle* create( const QString& key )
 	{
-		if ( key == "keramik" ) return new KeramikStyle;
+		if ( key == "keramik" ) return new KeramikStyle();
 		return 0;
 	}
 };
@@ -107,9 +109,10 @@ namespace
 	const int arrowHMargin    = 6;
 	const int rightBorder     = 12;
 	const char* kdeToolbarWidget = "kde toolbar widget";
-	
+
 	const int smallButMaxW    = 27;
 	const int smallButMaxH    = 20;
+	const int titleBarH       = 22;
 }
 // ---------------------------------------------------------------------------
 
@@ -162,7 +165,7 @@ namespace
 		}
 		p->restore();
 	}
-};
+}
 
 // XXX
 /* reimp. */
@@ -218,8 +221,8 @@ QRect KeramikStyle::subRect(SubRect r, const QWidget *widget) const
 			if (cb->text().isEmpty() && (cb->pixmap() == 0) )
 			{
 				QRect bounding = cb->rect();
-				QSize checkDim = Keramik::PixmapLoader::the().size( keramik_checkbox_on);
-				int   cw = checkDim.width();;
+				QSize checkDim = loader.size( keramik_checkbox_on);
+				int   cw = checkDim.width();
 				int   ch = checkDim.height();
 
 				QRect checkbox(bounding.x() + 1, bounding.y() + 1 + (bounding.height() - ch)/2,
@@ -243,20 +246,20 @@ QPixmap KeramikStyle::stylePixmap(StylePixmap stylepixmap,
 {
     switch (stylepixmap) {
 		case SP_TitleBarMinButton:
-			return Keramik::PixmapLoader::the().pixmap(keramik_title_iconify, 
+			return Keramik::PixmapLoader::the().pixmap(keramik_title_iconify,
 				Qt::black, Qt::black, false, false);
 			//return qpixmap_from_bits( iconify_bits, "title-iconify.png" );
 		case SP_TitleBarMaxButton:
-			return Keramik::PixmapLoader::the().pixmap(keramik_title_maximize, 
+			return Keramik::PixmapLoader::the().pixmap(keramik_title_maximize,
 				Qt::black, Qt::black, false, false);
 		case SP_TitleBarCloseButton:
 			if (widget && widget->inherits("KDockWidgetHeader"))
-				return Keramik::PixmapLoader::the().pixmap(keramik_title_close_tiny, 
+				return Keramik::PixmapLoader::the().pixmap(keramik_title_close_tiny,
 				Qt::black, Qt::black, false, false);
-			else	return Keramik::PixmapLoader::the().pixmap(keramik_title_close, 
+			else	return Keramik::PixmapLoader::the().pixmap(keramik_title_close,
 				Qt::black, Qt::black, false, false);
 		case SP_TitleBarNormalButton:
-			return Keramik::PixmapLoader::the().pixmap(keramik_title_restore, 
+			return Keramik::PixmapLoader::the().pixmap(keramik_title_restore,
 				Qt::black, Qt::black, false, false);
 		default:
 			break;
@@ -266,8 +269,6 @@ QPixmap KeramikStyle::stylePixmap(StylePixmap stylepixmap,
 }
 
 
-#define loader Keramik::PixmapLoader::the()
-
 KeramikStyle::KeramikStyle()
 	:KStyle( AllowMenuTransparency | FilledFrameWorkaround, ThreeButtonScrollBar ), maskMode(false),
 		toolbarBlendWidget(0), titleBarMode(None), flatMode(false), customScrollMode(false), kickerMode(false)
@@ -278,6 +279,7 @@ KeramikStyle::KeramikStyle()
 KeramikStyle::~KeramikStyle()
 {
 	Keramik::PixmapLoader::release();
+	Keramik::GradientPainter::releaseCache();
 	KeramikDbCleanup();
 }
 
@@ -289,7 +291,7 @@ void KeramikStyle::polish(QApplication* app)
 
 void KeramikStyle::polish(QWidget* widget)
 {
-	// Put in order of highest occurance to maximise hit rate
+	// Put in order of highest occurrence to maximise hit rate
 	if ( widget->inherits( "QPushButton" )  || widget->inherits( "QComboBox" ) )
 	{
 		widget->installEventFilter(this);
@@ -325,9 +327,7 @@ void KeramikStyle::unPolish(QWidget* widget)
 	{
 		if ( widget->inherits( "QComboBox" ) )
 			widget->setBackgroundMode( PaletteButton );
-
 		widget->removeEventFilter(this);
-
 	}
 	else if ( widget->inherits( "QMenuBar" ) || widget->inherits( "QPopupMenu" ) )
 		widget->setBackgroundMode( PaletteBackground );
@@ -351,11 +351,122 @@ void KeramikStyle::unPolish(QWidget* widget)
 	KStyle::unPolish(widget);
 }
 
+
 void KeramikStyle::polish( QPalette& )
 {
 	loader.clear();
 }
 
+/** 
+ Draws gradient background for toolbar buttons, handles and spacers
+*/
+static void renderToolbarEntryBackground(QPainter* paint,
+		 const QToolBar* parent, QRect r, const QColorGroup& cg, bool horiz)
+{
+	int  toolWidth, toolHeight;
+	
+	//Do we have a parent toolbar to use?
+	if (parent)
+	{
+		//Calculate the toolbar geometry.
+		//The initial guess is the size of the parent widget
+		toolWidth  = parent->width();
+		toolHeight = parent->height();
+					
+		//If we're floating, however, wee need to fiddle
+		//with height to skip the titlebar
+		if (parent->place() == QDockWindow::OutsideDock)
+		{
+			toolHeight = toolHeight - titleBarH - 2*parent->frameWidth() + 2;
+			//2 at the end = the 2 pixels of border of a "regular"
+			//toolbar we normally paint over.
+		}
+	}
+	else
+	{
+		//No info, make a guess.
+		//We take the advantage of the fact that the non-major
+		//sizing direction parameter is ignored
+		toolWidth  = r.width () + 2;
+		toolHeight = r.height() + 2;
+	}
+
+	//Calculate where inside the toolbar we're
+	int xoff = 0, yoff = 0;
+	if (horiz)
+		yoff = (toolHeight - r.height())/2;
+	else
+		xoff = (toolWidth - r.width())/2;
+						
+	Keramik::GradientPainter::renderGradient( paint, r, cg.button(),
+		horiz, false /*Not a menubar*/,
+		xoff, yoff,
+		toolWidth, toolHeight);
+}
+
+static void renderToolbarWidgetBackground(QPainter* painter, const QWidget* widget)
+{
+	// Draw a gradient background for custom widgets in the toolbar
+	// that have specified a "kde toolbar widget" name, or
+	// are caught as toolbar widgets otherwise
+
+	// Find the top-level toolbar of this widget, since it may be nested in other
+	// widgets that are on the toolbar.
+	QWidget *parent = static_cast<QWidget*>(widget->parentWidget());
+	int x_offset = widget->x(), y_offset = widget->y();
+	while (parent && parent->parent() && !qstrcmp( parent->name(), kdeToolbarWidget ) )
+	{
+		x_offset += parent->x();
+		y_offset += parent->y();
+		parent = static_cast<QWidget*>(parent->parent());
+	}
+
+	QRect pr = parent->rect();
+	bool horiz_grad = pr.width() > pr.height();
+
+	int  toolHeight = parent->height();
+	int  toolWidth  = parent->width ();
+
+	// Check if the parent is a QToolbar, and use its orientation, else guess.
+	//Also, get the height to use in the gradient from it.
+	QToolBar* tb = dynamic_cast<QToolBar*>(parent);
+	if (tb)
+	{
+		horiz_grad = tb->orientation() == Qt::Horizontal;
+
+		//If floating, we need to skip the titlebar.
+		if (tb->place() == QDockWindow::OutsideDock)
+		{
+			toolHeight = tb->height() - titleBarH - 2*tb->frameWidth() + 2;
+			//Calculate offset here by looking at the bottom edge difference, and height.
+			//First, calculate by how much the widget needs to be extended to touch
+			//the bottom edge, minus the frame (except we use the current y_offset
+			// to map to parent coordinates)
+			int needToTouchBottom = tb->height() - tb->frameWidth() -
+									(widget->rect().bottom() + y_offset);
+
+			//Now, with that, we can see which portion to skip in the full-height
+			//gradient -- which is the stuff other than the extended
+			//widget
+			y_offset = toolHeight - (widget->height() + needToTouchBottom) - 1;
+		}
+	}
+
+	if (painter)
+	{
+		Keramik::GradientPainter::renderGradient( painter, widget->rect(),
+			 widget->colorGroup().button(), horiz_grad, false,
+			 x_offset, y_offset, toolWidth, toolHeight);
+	}
+	else
+	{
+		QPainter p( widget );
+		Keramik::GradientPainter::renderGradient( &p, widget->rect(),
+			 widget->colorGroup().button(), horiz_grad, false,
+			 x_offset, y_offset, toolWidth, toolHeight);
+	}
+}
+
 // This function draws primitive elements as well as their masks.
 void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 									QPainter *p,
@@ -407,21 +518,21 @@ void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 					//### What should we draw at sides?
 					//nr = QRect(r.x(), r.y(),
 					//	QMIN(r.width(), r.height()), r.width() ) );
-					nr = QRect(r.x(), r.y(), r.width()-1, r.height() );;
-						
+					nr = QRect(r.x(), r.y(), r.width()-1, r.height() );
+
 				}
 				else
 				{
 					int offX = (r.width() - 15)/2;
 					int offY = (r.height() - 15)/2;
-				
+
 					if (flags & Style_Down)
 						offY += 1;
-						
+
 					nr = QRect(r.x()+offX, r.y()+offY, 15, 15);
 				}
-				
-				Keramik::ScaledPainter(flags & Style_Down ? keramik_titlebutton_pressed : keramik_titlebutton, 
+
+				Keramik::ScaledPainter(flags & Style_Down ? keramik_titlebutton_pressed : keramik_titlebutton,
 										Keramik::ScaledPainter::Both).draw( p, nr, cg.button(), cg.background());
 				return;
 			}
@@ -486,45 +597,21 @@ void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 
 			if (toolbarBlendWidget && !flatMode )
 			{
-				// Draw a gradient background for custom widgets in the toolbar
-				// that have specified a "kde toolbar widget" name.
-
-				// Find the top-level toolbar of this widget, since it may be nested in other
-				// widgets that are on the toolbar.
-				QWidget *parent = static_cast<QWidget*>(toolbarBlendWidget->parent());
-				int x_offset = toolbarBlendWidget->x(), y_offset = toolbarBlendWidget->y();
-				while (parent && parent->parent() && !qstrcmp( parent->name(), kdeToolbarWidget ) )
-				{
-					x_offset += parent->x();
-					y_offset += parent->y();
-					parent = static_cast<QWidget*>(parent->parent());
-				}
-
-				QRect pr = parent->rect();
-				bool horiz_grad = pr.width() > pr.height();
-
-				// Check if the parent is a QToolbar, and use its orientation, else guess.
-				QToolBar* tb = dynamic_cast<QToolBar*>(parent);
-				if (tb) horiz_grad = tb->orientation() == Qt::Horizontal;
-
-				Keramik::GradientPainter::renderGradient( p,
-						QRect(0, 0, pr.width(), pr.height()),
-						parent->colorGroup().button(), horiz_grad, false , x_offset, y_offset);
+				//Render the toolbar gradient.
+				renderToolbarWidgetBackground(p, toolbarBlendWidget);
 
 				//Draw and blend the actual bevel..
 				Keramik::RectTilePainter( name, false ).draw(p, r, cg.button(), cg.background(),
 					disabled, Keramik::TilePainter::PaintFullBlend  );
-
-
 			}
 			else if (!flatMode)
 				Keramik::RectTilePainter( name, false ).draw(p, r, cg.button(), cg.background(), disabled, pmode() );
 			else {
 				Keramik::ScaledPainter( name + KeramikTileCC, Keramik::ScaledPainter::Vertical).draw(
 					p, r, cg.button(), cg.background(), disabled, pmode() );
-				
+
 				p->setPen(cg.button().light(75));
-				
+
 				p->drawLine(x, y, x2, y);
 				p->drawLine(x, y, x, y2);
 				p->drawLine(x, y2, x2, y2);
@@ -572,7 +659,14 @@ void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 			// FOCUS RECT
 			// -------------------------------------------------------------------
 		case PE_FocusRect:
-			p->drawWinFocusRect( r );
+			//Qt may pass the background color to use for the focus indicator
+			//here. This particularly happens within the iconview.
+			//If that happens, pass it on to drawWinFocusRect() so it can
+			//honor it
+			if ( opt.isDefault() )
+				p->drawWinFocusRect( r );
+			else
+				p->drawWinFocusRect( r, opt.color() );
 			break;
 
 			// HEADER SECTION
@@ -653,7 +747,7 @@ void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 				painter.draw( p, r, down? cg.buttonText() : cg.button(), cg.background(), disabled, pmode() );
 
 				p->setPen( cg.buttonText() );
-				p->drawLine(r.x()+r.width()/2 - 4, r.y()+r.height()/2, 
+				p->drawLine(r.x()+r.width()/2 - 4, r.y()+r.height()/2,
 				            r.x()+r.width()/2 + 2, r.y()+r.height()/2);
 
 
@@ -692,6 +786,7 @@ void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 		// -------------------------------------------------------------------
 		case PE_Indicator:
 		case PE_IndicatorMask:
+
 			if (flags & Style_On)
 				Keramik::ScaledPainter( keramik_checkbox_on ).draw( p, r, cg.button(), cg.background(), disabled, pmode() );
 			else if (flags & Style_Off)
@@ -841,7 +936,7 @@ void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 				: opt.lineWidth();
 			if (lw)
 			{
-				p->setPen(cg.dark());
+				p->setPen(cg.mid());
 				p->drawLine(x2, y, x2, y2);
 			}
 
@@ -850,58 +945,69 @@ void KeramikStyle::drawPrimitive( PrimitiveElement pe,
 
 		case PE_PanelDockWindow:		// Toolbar
 		{
-			Keramik::GradientPainter::renderGradient( p, r, cg.button(), r.width() > r.height() );
-			//Keramik::ScaledPainter( keramik_toolbar , Keramik::ScaledPainter::Vertical).draw( p, r, cg.button(), cg.background() );
-			int x2 = r.x()+r.width()-1;
-			int y2 = r.y()+r.height()-1;
+			bool horiz = r.width() > r.height();
+
+			//Here, we just draw the border.
+			int x  = r.x();
+			int y  = r.y();
+			int x2 = r.x() + r.width()  - 1;
+			int y2 = r.y() + r.height() - 1;
 			int lw = opt.isDefault() ? pixelMetric(PM_DefaultFrameWidth)
 				: opt.lineWidth();
 
 			if (lw)
 			{
-				p->setPen(cg.dark());
-				p->drawLine(x2, y, x2, y2);
-			}
+				//Gradient border colors.
+				//(Same as in gradients.cpp)
+				QColor gradTop = Keramik::ColorUtil::lighten(cg.button(),110);
+				QColor gradBot = Keramik::ColorUtil::lighten(cg.button(),109);
+				if (horiz)
+				{
+					//Top line
+					p->setPen(gradTop);
+					p->drawLine(x, y, x2, y);
 
+					//Bottom line
+					p->setPen(gradBot);
+					p->drawLine(x, y2, x2, y2);
+
+					//Left line
+					Keramik::GradientPainter::renderGradient(
+						p, QRect(r.x(), r.y(), 1, r.height()),
+						cg.button(), true);
+
+					//Right end-line
+					p->setPen(cg.mid());
+					p->drawLine(x2, y, x2, y2);
+				}
+				else
+				{
+					//Left line
+					p->setPen(gradTop);
+					p->drawLine(x, y, x, y2);
+
+					//Right line
+					p->setPen(gradBot);
+					p->drawLine(x2, y, x2, y2);
+
+					//Top line
+					Keramik::GradientPainter::renderGradient(
+						p, QRect(r.x(), r.y(), r.width(), 1),
+						cg.button(), false);
+
+					//Bottom end-line
+					p->setPen(cg.mid());
+					p->drawLine(x, y2, x2, y2);
+				}
+			}
 			break;
 		}
 
-/*		case PE_PanelDockWindow:		// Toolbar
-		{
-			int x2 = r.x()+r.width()-1;
-			int y2 = r.y()+r.height()-1;
-			int lw = opt.isDefault() ? pixelMetric(PM_DefaultFrameWidth)
-				: opt.lineWidth();
-
-			if (lw)
-			{
-				p->setPen(cg.light());
-				p->drawLine(x, y, x2-1, y);
-				p->drawLine(x, y, x, y2-1);
-				p->setPen(cg.dark());
-				p->drawLine(x, y2, x2, y2);
-				p->drawLine(x2, y, x2, y2);
-
-				// ### Qt should specify Style_Horizontal where appropriate
-				renderGradient( p, QRect( x + 1, y, x2 - 1, y2 - 1),
-						cg.button(), (w < h) && (pe != PE_PanelMenuBar) );
-			}
-			else
-			{
-				renderGradient( p, QRect(x, y, x2, y2),
-						cg.button(), (w < h) && (pe != PE_PanelMenuBar) );
-			}
-			break;
-		}*/
-
-
-
-			// TOOLBAR SEPARATOR
-			// -------------------------------------------------------------------
+		// TOOLBAR SEPARATOR
+		// -------------------------------------------------------------------
 		case PE_DockWindowSeparator:
 		{
-			Keramik::GradientPainter::renderGradient( p, r, cg.button(),
-					(flags & Style_Horizontal));
+			renderToolbarEntryBackground(p, 0, r, cg, (flags & Style_Horizontal) );
 			if ( !(flags & Style_Horizontal) )
 			{
 				p->setPen(cg.mid());
@@ -1029,10 +1135,14 @@ void KeramikStyle::drawKStylePrimitive( KStylePrimitive kpe,
 			int x = r.x(); int y = r.y();
 			int x2 = r.x() + r.width()-1;
 			int y2 = r.y() + r.height()-1;
-
+			
+			QToolBar* parent = 0;
+			
+			if (widget && widget->parent() && widget->parent()->inherits("QToolBar"))
+				parent = static_cast<QToolBar*>(widget->parent());
+				
+			renderToolbarEntryBackground(p, parent, r, cg, (flags & Style_Horizontal));				
 			if (flags & Style_Horizontal) {
-
-				Keramik::GradientPainter::renderGradient( p, r, cg.button(), true);
 				p->setPen(cg.light());
 				p->drawLine(x+1, y+4, x+1, y2-4);
 				p->drawLine(x+3, y+4, x+3, y2-4);
@@ -1042,10 +1152,7 @@ void KeramikStyle::drawKStylePrimitive( KStylePrimitive kpe,
 				p->drawLine(x+2, y+4, x+2, y2-4);
 				p->drawLine(x+4, y+4, x+4, y2-4);
 				p->drawLine(x+6, y+4, x+6, y2-4);
-
 			} else {
-
-				Keramik::GradientPainter::renderGradient( p, r, cg.button(), false);
 				p->setPen(cg.light());
 				p->drawLine(x+4, y+1, x2-4, y+1);
 				p->drawLine(x+4, y+3, x2-4, y+3);
@@ -1126,7 +1233,7 @@ void KeramikStyle::drawControl( ControlElement element,
 
 			if ( btn->isFlat( ) )
 				flatMode = true;
-			
+
 			if ( btn->isDefault( ) && !flatMode )
 			{
 				drawPrimitive( PE_ButtonDefault, p, r, cg, flags );
@@ -1140,7 +1247,7 @@ void KeramikStyle::drawControl( ControlElement element,
 
 				toolbarBlendWidget = 0;
 			}
-			
+
 			flatMode = false;
 
 			break;
@@ -1167,7 +1274,7 @@ void KeramikStyle::drawControl( ControlElement element,
 			if ( button->isMenuButton() )
 			{
 				int dx = pixelMetric( PM_MenuButtonIndicator, widget );
-				if ( button->iconSet() && !button->iconSet()->isNull()  && 
+				if ( button->iconSet() && !button->iconSet()->isNull()  &&
 					(dx + button->iconSet()->pixmap (QIconSet::Small, QIconSet::Normal, QIconSet::Off ).width()) >= w )
 				{
 					cornArrow = true; //To little room. Draw the arrow in the corner, don't adjust the widget
@@ -1192,18 +1299,18 @@ void KeramikStyle::drawControl( ControlElement element,
 					state = QIconSet::On;
 
 				QPixmap pixmap = button->iconSet()->pixmap( QIconSet::Small, mode, state );
-				
+
 				if (button->text().isEmpty() && !button->pixmap())
-					p->drawPixmap( x + w/2 - pixmap.width()/2, y + h / 2 - pixmap.height() / 2, 
+					p->drawPixmap( x + w/2 - pixmap.width()/2, y + h / 2 - pixmap.height() / 2,
 									pixmap );
 				else
 					p->drawPixmap( x + 4, y + h / 2 - pixmap.height() / 2, pixmap );
-					
+
 				if (cornArrow) //Draw over the icon
 					drawPrimitive( PE_ArrowDown, p, visualRect( QRect(x + w - 6, x + h - 6, 7, 7), r ),
 							   cg, flags, opt );
 
-					
+
 				int  pw = pixmap.width();
 				x += pw + 4;
 				w -= pw + 4;
@@ -1213,7 +1320,7 @@ void KeramikStyle::drawControl( ControlElement element,
 			drawItem( p, QRect(x, y, w, h), AlignCenter | ShowPrefix, button->colorGroup(),
 						button->isEnabled(), button->pixmap(), button->text(), -1,
 						&button->colorGroup().buttonText() );
-						
+
 
 
 			if ( flags & Style_HasFocus )
@@ -1259,7 +1366,14 @@ void KeramikStyle::drawControl( ControlElement element,
 			              tabBar->shape() == QTabBar::TriangularBelow;
 
 			if ( flags & Style_Selected )
-				Keramik::ActiveTabPainter( bottom ).draw( p, r, cg.button(), cg.background(), !tabBar->isEnabled(), pmode());
+			{
+				QRect tabRect = r;
+				//If not the last tab, readjust the painting to be one pixel wider
+				//to avoid a doubled line
+				if (tabBar->indexOf( opt.tab()->identifier() ) != (tabBar->count() - 1))
+					tabRect.setWidth( tabRect.width() + 1);
+				Keramik::ActiveTabPainter( bottom ).draw( p, tabRect, cg.button().light(110), cg.background(), !tabBar->isEnabled(), pmode());
+			}
 			else
 			{
 				Keramik::InactiveTabPainter::Mode mode;
@@ -1285,13 +1399,33 @@ void KeramikStyle::drawControl( ControlElement element,
 			break;
 		}
 
-#if (QT_VERSION-0 >= 0x030100)
+		case CE_DockWindowEmptyArea:
+		{
+			QRect pr = r;
+			if (widget && widget->inherits("QToolBar"))
+			{
+				const QToolBar* tb = static_cast<const QToolBar*>(widget);
+				if (tb->place() == QDockWindow::OutsideDock)
+				{
+					//Readjust the paint rectangle to skip the titlebar
+					pr = QRect(r.x(), titleBarH + tb->frameWidth(),
+						r.width(), tb->height() - titleBarH - 2 * tb->frameWidth() + 2);
+					//2 at the end = the 2 pixels of border of a "regular"
+					//toolbar we normally paint over.
+				}
+				Keramik::GradientPainter::renderGradient( p, pr, cg.button(),
+										 tb->orientation() == Qt::Horizontal);
+			}
+			else
+				KStyle::drawControl( CE_DockWindowEmptyArea, p, 
+					widget, r, cg, flags, opt );
+			break;
+		}
 		case CE_MenuBarEmptyArea:
 		{
 			Keramik::GradientPainter::renderGradient( p, r, cg.button(), true, true);
 			break;
 		}
-#endif
 		// MENUBAR ITEM (sunken panel on mouse over)
 		// -------------------------------------------------------------------
 		case CE_MenuBarItem:
@@ -1624,26 +1758,35 @@ void KeramikStyle::drawComplexControl( ComplexControl control,
 		// -------------------------------------------------------------------
 		case CC_ComboBox:
 		{
+			bool toolbarMode = false;
 			const QComboBox* cb = static_cast< const QComboBox* >( widget );
-			QPixmap buf;
+			QPixmap * buf = 0;
 			QPainter* p2 = p;
 
 			QRect br = r;
+			
+			if (widget->parent() &&
+					( widget->parent()->inherits("QToolBar")|| !qstrcmp(widget->parent()->name(), kdeToolbarWidget) ) )
+				toolbarMode = true;
 
 			if (controls == SC_All)
 			{
-				buf.resize(r.width(), r.height() );
+				buf = new QPixmap( r.width(), r.height() );
 				br.setX(0);
 				br.setY(0);
-				p2 = new QPainter(&buf);
+				p2 = new QPainter(buf);
+				
+				//Ensure that we have clipping on, and have a sane base.
+				//If need be, Qt will shrink us to the paint region.
+				p->setClipping(true);
+				p->setClipRect(r);
 			}
 
 
 			if ( br.width() >= 28 && br.height() > 20 ) br.addCoords( 0, -2, 0, 0 );
 			if ( controls & SC_ComboBoxFrame )
 			{
-				if (widget->parent() &&
-						( widget->parent()->inherits("QToolBar")|| !qstrcmp(widget->parent()->name(), kdeToolbarWidget) ) )
+				if (toolbarMode)
 				{
 					toolbarBlendWidget = widget;
 				}
@@ -1675,12 +1818,10 @@ keramik_ripple ).width(), ar.height() - 8 ), widget );
 				QPointArray a;
 
 				a.setPoints(QCOORDARRLEN(keramik_combo_arrow), keramik_combo_arrow);
-				p2->save();
 
 				a.translate( ar.x() + ar.width() / 2, ar.y() + ar.height() / 2 );
 				p2->setPen( cg.buttonText() );
 				p2->drawLineSegments( a );
-				p2->restore();
 
 				Keramik::ScaledPainter( keramik_ripple ).draw( p2, rr, cg.button(), Qt::black, disabled, Keramik::TilePainter::PaintFullBlend );
 			}
@@ -1720,9 +1861,9 @@ keramik_ripple ).width(), ar.height() - 8 ), widget );
 			{
 				p2->end();
 				delete p2;
-				p->drawPixmap(r.x(), r.y(), buf);
+				p->drawPixmap(r.x(), r.y(), *buf);
+				delete buf;
 			}
-
 			break;
 		}
 
@@ -1814,7 +1955,7 @@ keramik_ripple ).width(), ar.height() - 8 ), widget );
 					drawPrimitive( PE_ScrollBarAddLine, p, addline, cg, flags | Style_Down );
 				}
 			}
-			
+
 			customScrollMode = false;
 
 
@@ -1826,8 +1967,10 @@ keramik_ripple ).width(), ar.height() - 8 ), widget );
 		case CC_ToolButton: {
 			const QToolButton *toolbutton = (const QToolButton *) widget;
 			bool onToolbar = widget->parentWidget() && widget->parentWidget()->inherits( "QToolBar" );
-			bool onExtender = !onToolbar && widget->parentWidget() && widget->parentWidget()->inherits( "QToolBarExtensionWidget" );
-			
+			bool onExtender = !onToolbar &&
+				widget->parentWidget() && widget->parentWidget()->inherits( "QToolBarExtensionWidget") &&
+				widget->parentWidget()->parentWidget()->inherits( "QToolBar" );
+
 			bool onControlButtons = false;
 			if (!onToolbar && !onExtender && widget->parentWidget() &&
 				 !qstrcmp(widget->parentWidget()->name(),"qt_maxcontrols" ) )
@@ -1835,9 +1978,6 @@ keramik_ripple ).width(), ar.height() - 8 ), widget );
 				onControlButtons = true;
 				titleBarMode = Maximized;
 			}
-				
-			
-				
 
 			QRect button, menuarea;
 			button   = querySubControlMetrics(control, widget, SC_ToolButton, opt);
@@ -1871,22 +2011,29 @@ keramik_ripple ).width(), ar.height() - 8 ), widget );
 				}
 				else if (onToolbar)
 				{
-					QToolBar* parent = (QToolBar*)widget->parent();
-					QRect pr = parent->rect();
-
-					Keramik::GradientPainter::renderGradient( p, r, cg.button(),
-												parent->orientation() == Qt::Horizontal, false /*Not a menubar*/,
-												r.x(), r.y(), pr.width()-2, pr.height()-2);
+					renderToolbarWidgetBackground(p, widget);
 				}
 				else if (onExtender)
 				{
-					QWidget* parent = (QWidget*)widget->parent();
-					QToolBar* toolbar = (QToolBar*)parent->parent();
-					QRect tr = toolbar->rect();
-					//QPainter p2(toolbar);
-					//p2.fillRect(tr, Qt::red);
-					//p2.end();
-					Keramik::GradientPainter::renderGradient( p, QRect(r.x(), r.y(), tr.width(), tr.height()), cg.button(), toolbar->orientation() != Qt::Vertical );
+					// This assumes floating toolbars can't have extenders,
+					//(so if we're on an extender, we're not floating)
+					QWidget*  parent  = static_cast<QWidget*> (widget->parent());
+					QToolBar* toolbar = static_cast<QToolBar*>(parent->parent());
+					QRect tr    = toolbar->rect();
+					bool  horiz = toolbar->orientation() == Qt::Horizontal;
+
+					//Calculate offset. We do this by translating our coordinates,
+					//which are relative to the parent, to be relative to the toolbar.
+					int xoff = 0, yoff = 0;
+					if (horiz)
+						yoff = parent->mapToParent(widget->pos()).y();
+					else
+						xoff = parent->mapToParent(widget->pos()).x();
+
+					Keramik::GradientPainter::renderGradient( p, r, cg.button(),
+							horiz, false, /*Not a menubar*/
+							xoff,  yoff,
+							tr.width(), tr.height());
 				}
 			}
 
@@ -1903,18 +2050,18 @@ keramik_ripple ).width(), ar.height() - 8 ), widget );
 				fr.addCoords(3, 3, -3, -3);
 				drawPrimitive(PE_FocusRect, p, fr, cg);
 			}
-			
+
 			titleBarMode = None;
 
 			break;
 		}
-		
+
 		case CC_TitleBar:
 			titleBarMode = Regular; //Handle buttons on titlebar different from toolbuttons
 		default:
 			KStyle::drawComplexControl( control, p, widget,
 						r, cg, flags, controls, active, opt );
-						
+
 			titleBarMode = None;
 	}
 }
@@ -1989,9 +2136,12 @@ int KeramikStyle::pixelMetric(PixelMetric m, const QWidget *widget) const
 
 		case PM_TabBarTabVSpace:
 			return 12;
-			
+
+		case PM_TabBarTabOverlap:
+			return 0;
+
 		case PM_TitleBarHeight:
-			return 22;
+			return titleBarH;
 
 		default:
 			return KStyle::pixelMetric(m, widget);
@@ -2045,7 +2195,7 @@ QSize KeramikStyle::sizeFromContents( ContentsType contents,
 			return QSize( contentSize.width() + arrow + (cb->editable() ? 26 : 22),
 					contentSize.height() + 10 );
 		}
-						  
+
 		// POPUPMENU ITEM SIZE
 		// -----------------------------------------------------------------
 		case CT_PopupMenuItem: {
@@ -2152,6 +2302,16 @@ QRect KeramikStyle::querySubControlMetrics( ComplexControl control,
 						return QRect( 6, 4, widget->width() - arrow - 22, widget->height() - 9 );
 				}
 
+				case SC_ComboBoxListBoxPopup:
+				{
+					QRect def = opt.rect();
+					if ( widget->inherits( "KCompletionBox" ) )
+						def.addCoords( -4, 4, 10, 8 );
+					else def.addCoords( 4, -4, -6, 4 );
+
+					return def;
+				}
+
 				default: break;
 			}
 			break;
@@ -2225,6 +2385,16 @@ QRect KeramikStyle::querySubControlMetrics( ComplexControl control,
 			int size = pixelMetric( PM_SliderControlThickness, widget );
 			int handleSize = pixelMetric( PM_SliderThickness, widget );
 			int len = pixelMetric( PM_SliderLength, widget );
+
+			//Shrink the metrics if the widget is too small
+			//to fit our normal values for them.
+			if (horizontal)
+				handleSize = QMIN(handleSize, sl->height());
+			else
+				handleSize = QMIN(handleSize, sl->width());
+
+			size = QMIN(size, handleSize);
+
 			switch ( subcontrol )
 			{
 				case SC_SliderGroove:
@@ -2286,6 +2456,7 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 
 	if ( !object->isWidgetType() ) return false;
 
+	//Hover highlight on buttons and combos
 	if ( object->inherits("QPushButton") || object->inherits("QComboBox") )
 	{
 		if ( (event->type() == QEvent::Enter) && static_cast<QWidget*>(object)->isEnabled())
@@ -2302,6 +2473,7 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 		}
 		return false;
 	}
+	//Combo line edits get special frames
 	else if ( event->type() == QEvent::Paint && object->inherits( "QLineEdit" ) )
 	{
 		static bool recursion = false;
@@ -2319,6 +2491,7 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 		return true;
 	}
 #ifdef HAVE_X11_EXTENSIONS_SHAPE_H
+	//Combo dropdowns are shaped
 	else if ( event->type() == QEvent::Resize && object->inherits("QListBox") )
 	{
 		QListBox* listbox = static_cast<QListBox*>(object);
@@ -2329,7 +2502,7 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 		//CHECKME: Not sure the rects are perfect..
 		XRectangle rects[5] = {
 			{0, 0, resize->size().width()-2, resize->size().height()-6},
-			{1, resize->size().height()-6, resize->size().width()-3, 1},
+			{0, resize->size().height()-6, resize->size().width()-2, 1},
 			{1, resize->size().height()-5, resize->size().width()-3, 1},
 			{2, resize->size().height()-4, resize->size().width()-5, 1},
 			{3, resize->size().height()-3, resize->size().width()-7, 1}
@@ -2339,6 +2512,7 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 			  rects, 5, ShapeSet, YXSorted);
 	}
 #endif
+	//Combo dropdowns get fancy borders
 	else if ( event->type() == QEvent::Paint && object->inherits("QListBox") )
 	{
 		static bool recursion = false;
@@ -2348,11 +2522,10 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 		QPaintEvent* paint = (QPaintEvent*) event;
 
 
-
 		if ( !listbox->contentsRect().contains( paint->rect() ) )
 		{
 			QPainter p( listbox );
-			Keramik::RectTilePainter( keramik_combobox_list, false ).draw( &p, 0, 0, listbox->width(), listbox->height(),
+			Keramik::RectTilePainter( keramik_combobox_list, false, false ).draw( &p, 0, 0, listbox->width(), listbox->height(),
 					listbox->palette().color( QPalette::Normal, QColorGroup::Button ),
 					listbox->palette().color( QPalette::Normal, QColorGroup::Background ) );
 
@@ -2363,45 +2536,13 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 			return true;
 		}
 	}
-	else if ( event->type() == QEvent::Show && object->inherits( "QListBox" ) )
-	{
-		QListBox* listbox = (QListBox*) object;
-		QRect geometry = listbox->geometry();
-		if ( listbox->inherits( "KCompletionBox" ) )
-			geometry.addCoords( -4, 4, 10, 8 );
-		else geometry.addCoords( 4, -4, -6, 4 );
-		listbox->setGeometry( geometry );
-	}
+	//Toolbar background gradient handling
 	else if (event->type() == QEvent::Paint &&
 			 object->parent() && !qstrcmp(object->name(), kdeToolbarWidget) )
 	{
 		// Draw a gradient background for custom widgets in the toolbar
 		// that have specified a "kde toolbar widget" name.
-
-		// Find the top-level toolbar of this widget, since it may be nested in other
-		// widgets that are on the toolbar.
-		QWidget *widget = static_cast<QWidget*>(object);
-		QWidget *parent = static_cast<QWidget*>(object->parent());
-		int x_offset = widget->x(), y_offset = widget->y();
-		while (parent && parent->parent() && !qstrcmp( parent->name(), kdeToolbarWidget ) )
-		{
-			x_offset += parent->x();
-			y_offset += parent->y();
-			parent = static_cast<QWidget*>(parent->parent());
-		}
-
-//		QRect r  = widget->rect();
-		QRect pr = parent->rect();
-		bool horiz_grad = pr.width() > pr.height();
-
-		// Check if the parent is a QToolbar, and use its orientation, else guess.
-		QToolBar* tb = dynamic_cast<QToolBar*>(parent);
-		if (tb) horiz_grad = tb->orientation() == Qt::Horizontal;
-		QPainter p( widget );
-
-		Keramik::GradientPainter::renderGradient( &p,
-				QRect(0, 0, pr.width(), pr.height()),
-			   	parent->colorGroup().button(), horiz_grad, false , x_offset, y_offset);
+		renderToolbarWidgetBackground(0, static_cast<QWidget*>(object));
 
 		return false;	// Now draw the contents
 	}
@@ -2414,9 +2555,22 @@ bool KeramikStyle::eventFilter( QObject* object, QEvent* event )
 		QRect wr = widget->rect (), tr = toolbar->rect();
 		QPainter p( widget );
 
-		Keramik::GradientPainter::renderGradient( &p, QRect(0 , 0, wr.width(), wr.height()),
-			widget->colorGroup().button(), tr.width() > tr.height() );
-		p.setPen( toolbar->colorGroup().dark() );
+		if ( toolbar->orientation() == Qt::Horizontal )
+		{
+			Keramik::GradientPainter::renderGradient( &p, wr, widget->colorGroup().button(),
+													  true /*horizontal*/, false /*not a menu*/,
+													  0, widget->y(), wr.width(), tr.height());
+		}
+		else
+		{
+			Keramik::GradientPainter::renderGradient( &p, wr, widget->colorGroup().button(),
+													  false /*vertical*/, false /*not a menu*/,
+													  widget->x(), 0, tr.width(), wr.height());
+		}
+
+		
+		//Draw terminator line, too
+		p.setPen( toolbar->colorGroup().mid() );
 		if ( toolbar->orientation() == Qt::Horizontal )
 			p.drawLine( wr.width()-1, 0, wr.width()-1, wr.height()-1 );
 		else
