@@ -1,4 +1,4 @@
-/* 
+/*
    Copyright (c) 2002 Malte Starostik <malte@kde.org>
 
    This library is free software; you can redistribute it and/or
@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: pixmaploader.h,v 1.20 2002/10/31 03:37:30 orlovich Exp $
+// $Id: pixmaploader.h,v 1.20.2.1 2003/06/20 01:29:06 orlovich Exp $
 
 #ifndef __pixmaploader_h__
 #define __pixmaploader_h__
@@ -40,8 +40,8 @@ namespace Keramik
 
 		QPixmap pixmap( int name, const QColor& color,  const QColor& bg,
 										 bool disabled = false, bool blend = true );
-										 
-		QPixmap scale( int name, int width, int height, const QColor& color,  const QColor& bg, 
+
+		QPixmap scale( int name, int width, int height, const QColor& color,  const QColor& bg,
 										bool disabled = false, bool blend = true );
 		QSize size( int id );
 
@@ -49,19 +49,19 @@ namespace Keramik
 
 		static PixmapLoader& the()
 		{
-			 if (!s_instance) 
+			 if (!s_instance)
 			 	s_instance = new PixmapLoader;
 			return *s_instance;
 		}
-		
+
 		static void release()
 		{
 			delete s_instance;
 			s_instance = 0;
 		}
-		
+
 	private:
-	
+
 		struct KeramikCacheEntry
 		{
 			int m_id;
@@ -71,44 +71,44 @@ namespace Keramik
 			QRgb m_bgCode;
 			bool    m_disabled;
 			bool    m_blended;
-			
+
 			QPixmap* m_pixmap;
-			
-			KeramikCacheEntry(int id, const QColor& color, const QColor& bg, bool disabled, 
+
+			KeramikCacheEntry(int id, const QColor& color, const QColor& bg, bool disabled,
 											bool blended, int width = -1 , int height = -1, QPixmap* pixmap = 0 ):
 				m_id(id), m_width(width), m_height(height), m_colorCode(color.rgb()),m_bgCode(bg.rgb()),
 				m_disabled(disabled),  m_blended(blended), m_pixmap(pixmap)
 			{}
-			
+
 			int key()
 			{
 				return m_disabled ^ (m_blended << 1) ^ (m_id<<2) ^ (m_width<<14) ^ (m_height<<24) ^ m_colorCode ^ (m_bgCode<<8);
 			}
-			
+
 			bool operator == (const KeramikCacheEntry& other)
 			{
 				return (m_id        == other.m_id) &&
 							(m_width   == other.m_width) &&
 							(m_height == other.m_height) &&
 							(m_blended == other.m_blended) &&
-							(m_bgCode == other.m_bgCode) && 
-							(m_colorCode == other.m_colorCode) && 
+							(m_bgCode == other.m_bgCode) &&
+							(m_colorCode == other.m_colorCode) &&
 							(m_disabled == other.m_disabled);
 			}
-						
+
 			~KeramikCacheEntry()
 			{
 				delete m_pixmap;
 			}
 		};
-		
 
-		
+
+
 		QImage* getColored(int id, const QColor& color, const QColor& bg, bool blended);
 		QImage* getDisabled(int id, const QColor& color, const QColor& bg, bool blended);
 		QIntCache <KeramikCacheEntry>  m_pixmapCache;
-		
-		
+
+
 		unsigned char clamp[540];
 
 		static PixmapLoader* s_instance;
@@ -119,7 +119,7 @@ namespace Keramik
 	public:
 		TilePainter( int name ) : m_columns(1),m_rows(1),m_name( name ) {};
 		virtual ~TilePainter() {};
-		
+
 		enum PaintMode
 		{
 			PaintNormal,
@@ -127,7 +127,7 @@ namespace Keramik
 			PaintFullBlend
 		};
 
-		void draw( QPainter *p, int x, int y, int width, int height, const QColor& color, const QColor& bg, 
+		void draw( QPainter *p, int x, int y, int width, int height, const QColor& color, const QColor& bg,
 		                 bool disabled = false, PaintMode mode = PaintNormal );
 		void draw( QPainter *p, const QRect& rect, const QColor& color, const QColor& bg, bool disabled = false, PaintMode mode = PaintNormal )
 		{
@@ -139,14 +139,36 @@ namespace Keramik
 
 		unsigned int columns() const { return m_columns; }
 		unsigned int rows() const { return m_rows; }
-		
+
+		/**
+		The idea behind all this stuff is that for performance reasons, we want to
+		use only integers to refer to widgets. So we give each widget a base ID
+		that's divisible by 256, and have all the various tiles be referred to as that ID +
+		some small number.
+
+		genembed generates and assigns the base widget IDs, and maps various pixmaps suffixes
+		into the adjustment numbers; using that info it writes out the tables mapping
+		the IDs to pixmaps, and keramikrc.h, which provides nice symbolic constants for base IDs.
+
+		When painting, however, we essentially represent the widget as a table, providing
+		fixed/tiled/stretched modes for each column and row. So to draw the widget knowing its
+		base ID, we need to know how many rows and columns there, what the scaling modes
+		are, and how to get to each of the tiles -- i.e. the tiles' offset from the base ID.
+
+		The various painter subclasses simply fill in most of that info into the members
+		here during their construction, and implement the virtual tileName to get the offsets.
+
+		Note that the IDs and offsets are separated since we can reuse the same code in many
+		cases by splitting the widget identify from tile identity (as there are many
+		different widgets that have the same or similar tile layout)
+		*/
 		virtual int tileName( unsigned int, unsigned int ) const { return 0; }
-		
+
 		TileMode columnMode( unsigned int col) const
 		{
 			return colMde[col];
 		}
-		
+
 		TileMode rowMode( unsigned int row) const
 		{
 			return rowMde[row];
@@ -157,23 +179,23 @@ namespace Keramik
 		unsigned int m_columns;
 		unsigned int m_rows;
 	private:
-	
+
 		int absTileName( unsigned int column, unsigned int row ) const
 		{
 			int name = tileName( column, row );
 			return m_name + name;
 		}
-		
-		
+
+
 		QPixmap tile( unsigned int column, unsigned int row, const QColor& color, const QColor& bg, bool disabled, bool blend)
 			{ return PixmapLoader::the().pixmap( absTileName( column, row ), color, bg, disabled, blend ); }
-		QPixmap scale( unsigned int column, unsigned int row, int width, int height, const QColor& color, const QColor& bg, 
+		QPixmap scale( unsigned int column, unsigned int row, int width, int height, const QColor& color, const QColor& bg,
 							bool disabled, bool blend )
-			{ return PixmapLoader::the().scale( absTileName( column, row ), width, height, color, 
+			{ return PixmapLoader::the().scale( absTileName( column, row ), width, height, color,
 							bg, disabled, blend ); }
 
 		int m_name;
-		
+
 	};
 
 	class ScaledPainter : public TilePainter
@@ -186,7 +208,7 @@ namespace Keramik
 			colMde[0] =  ( m_direction & Horizontal ) ? Scaled : Tiled;
 			rowMde[0] =  ( m_direction & Vertical ) ? Scaled : Tiled;
 		}
-		
+
 		virtual ~ScaledPainter() {};
 
 	private:
@@ -211,7 +233,7 @@ namespace Keramik
 		RectTilePainter( int name,
 		                 bool scaleH = true, bool scaleV = true,
 		                 unsigned int columns = 3, unsigned int rows = 3 );
-		
+
 		virtual ~RectTilePainter() {};
 
 	protected:
@@ -220,7 +242,7 @@ namespace Keramik
 		bool m_scaleH;
 		bool m_scaleV;
 	};
-	
+
 	class RowPainter: public TilePainter
 	{
 	public:
@@ -231,7 +253,7 @@ namespace Keramik
 			rowMde[0] = Scaled;
 			m_columns = 3;
 		}
-		
+
 		virtual ~RowPainter() {};
 	protected:
 		virtual int tileName( unsigned int column, unsigned int /*row*/) const
@@ -239,7 +261,7 @@ namespace Keramik
 			return column + 3; //So can use cl, cc, cr
 		}
 	};
-	
+
 	class ProgressBarPainter: public TilePainter
 	{
 	public:
@@ -257,10 +279,10 @@ namespace Keramik
 				colMde[1] = Fixed;
 			}
 			rowMde[0] = Scaled;
-			
+
 			m_columns = 2;
 		}
-		
+
 		virtual ~ProgressBarPainter() {};
 	protected:
 		virtual int tileName( unsigned int column, unsigned int /*row*/ ) const
@@ -271,9 +293,9 @@ namespace Keramik
 			}
 			else
 				return column + 4; //So can use cl, cc, cr + we start from cc.
-				
+
 		}
-		
+
 		bool m_reverse;
 	};
 
@@ -283,7 +305,7 @@ namespace Keramik
 	public:
 		ActiveTabPainter( bool bottom );
 		virtual ~ActiveTabPainter() {};
-	
+
 	protected:
 		virtual int tileName( unsigned int column, unsigned int row ) const;
 
@@ -336,7 +358,7 @@ namespace Keramik
 	protected:
 		virtual int tileName( unsigned int column, unsigned int row ) const;
 	};
-};
+}
 
 #endif
 
