@@ -1,5 +1,5 @@
 /*
- $Id: kthemebase.h,v 1.5 2002/01/21 03:46:43 orlovich Exp $
+ $Id: kthemebase.h,v 1.6 2002/09/29 00:34:00 orlovich Exp $
 
  This file is part of the KDE libraries
  Copyright (C) 1999 Daniel M. Duley <mosfet@kde.org>
@@ -268,10 +268,10 @@ public:
         SunkenArrowRight,
         // Everything else (indicators must have separate settings)
         HScrollGroove, VScrollGroove, Slider, SliderGroove, IndicatorOn,
-        IndicatorOff, ExIndicatorOn, ExIndicatorOff, HBarHandle, VBarHandle,
+        IndicatorOff, IndicatorTri, ExIndicatorOn, ExIndicatorOff, HBarHandle, VBarHandle,
         ToolBar, Splitter, CheckMark, MenuBar, DisArrowUp, DisArrowDown,
         DisArrowLeft, DisArrowRight, ProgressBar, ProgressBg, MenuBarItem,
-        Background, RotSliderGroove, WIDGETS};
+        Background, RotSliderGroove, RotInactiveTab, RotActiveTab, WIDGETS};
 
     /**
      * The scaling type specified by the KConfig file.
