@@ -1,5 +1,5 @@
 /*
- $Id: kthemestyle.cpp,v 1.34.2.1 2003/02/12 03:22:18 orlovich Exp $
+ $Id: kthemestyle.cpp,v 1.34.2.3 2003/07/15 00:40:52 mueller Exp $
 
  This file is part of the KDE libraries
  Copyright (C) 1999 Daniel M. Duley <mosfet@kde.org>
@@ -392,7 +392,7 @@ int KThemeStyle::pixelMetric ( PixelMetric metric, const QWidget * widget ) cons
         default:
             return KThemeBase::pixelMetric ( metric, widget );
     }
-};
+}
 
 
 
@@ -486,6 +486,13 @@ bool KThemeStyle::eventFilter( QObject* object, QEvent* event )
             w->setPalette(pal);
         }
     }
+    if (!qstrcmp(object->name(), "kde toolbar widget") && object->inherits("QLabel"))
+    {
+        QWidget* lb = static_cast<QWidget*>(object);
+        if (lb->backgroundMode() == Qt::PaletteButton)
+            lb->setBackgroundMode(Qt::PaletteBackground);
+        lb->removeEventFilter(this);
+    }
 
     return KStyle::eventFilter(object, event);
 }
@@ -494,6 +501,9 @@ void KThemeStyle::polish( QWidget *w )
 {
     if (w->inherits("QStatusBar"))
          w->setPaletteBackgroundColor(QApplication::palette().color(QPalette::Normal, QColorGroup::Background));
+    if (w->inherits("QLabel") && !qstrcmp(w->name(), "kde toolbar widget"))
+         w->installEventFilter(this);
+
 
     if (w->backgroundPixmap() && !w->isTopLevel())
     {
