@@ -26,14 +26,13 @@
 #include <qbitmap.h>
 #include <qtabbar.h>
 #include <qpointarray.h>
-#include <qtabbar.h>
 #include <qscrollbar.h>
 #include <qframe.h>
 #include <qpushbutton.h>
 #include <qdrawutil.h>
 #include <qpainter.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdrawutil.h>
 #include <klocale.h>
 #include <kiconloader.h>
